@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: DemoEnding.h,v 1.2 2008/09/08 08:38:59 bowkenken Exp $
+* $Id: DemoEnding.h,v 1.4 2009/01/25 05:13:21 bowkenken Exp $
 ***************************************************************/
 
 #ifndef DEMO_ENDING_H
@@ -75,7 +75,8 @@ private:
 	// ˥Ѻɸ
 	long len;
 	long w, h;
-	long baseX, baseY;
+	long baseX[EPILOGUE_LINE_MAX_N];
+	long baseY[EPILOGUE_LINE_MAX_N];
 	long mx[EPILOGUE_LINE_MAX_N][EPILOGUE_MAX_LEN];
 	long my[EPILOGUE_LINE_MAX_N][EPILOGUE_MAX_LEN];
 	long x[EPILOGUE_LINE_MAX_N][EPILOGUE_MAX_LEN];
