@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: DemoLastBoss.cpp,v 1.7 2008/10/07 02:34:44 bowkenken Exp $
+* $Id: DemoLastBoss.cpp,v 1.10 2009/01/04 00:26:03 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -125,6 +125,10 @@ void DemoLastBoss::reset()
 	//case LAST_SCENE_N_XEX_WORDS:
 	case LAST_SCENE_N_XEX_CUT_OUT:
 	case LAST_SCENE_N_XEX_CUT_END:
+	case LAST_SCENE_N_XX_ENTER:
+	case LAST_SCENE_N_XX_WORDS:
+	case LAST_SCENE_N_XX_BATTLE:
+	case LAST_SCENE_N_XX_DIE:
 	case LAST_SCENE_N_END:
 	case LAST_SCENE_N_MAX_N:
 		frame = 0;
@@ -227,6 +231,10 @@ bool DemoLastBoss::draw()
 		gui_end();
 		break;
 	case LAST_SCENE_N_XEX_CUT_END:
+	case LAST_SCENE_N_XX_ENTER:
+	case LAST_SCENE_N_XX_WORDS:
+	case LAST_SCENE_N_XX_BATTLE:
+	case LAST_SCENE_N_XX_DIE:
 		break;
 	case LAST_SCENE_N_END:
 	case LAST_SCENE_N_MAX_N:
@@ -329,6 +337,10 @@ bool DemoLastBoss::checkSkipFrame()
 	//case LAST_SCENE_N_XEX_WORDS:
 	case LAST_SCENE_N_XEX_CUT_OUT:
 	case LAST_SCENE_N_XEX_CUT_END:
+	case LAST_SCENE_N_XX_ENTER:
+	case LAST_SCENE_N_XX_WORDS:
+	case LAST_SCENE_N_XX_BATTLE:
+	case LAST_SCENE_N_XX_DIE:
 	case LAST_SCENE_N_END:
 	case LAST_SCENE_N_MAX_N:
 		break;
@@ -385,6 +397,10 @@ bool DemoLastBoss::checkDone()
 	case LAST_SCENE_N_XEX_WORDS:
 	//case LAST_SCENE_N_XEX_CUT_OUT:
 	case LAST_SCENE_N_XEX_CUT_END:
+	case LAST_SCENE_N_XX_ENTER:
+	case LAST_SCENE_N_XX_WORDS:
+	case LAST_SCENE_N_XX_BATTLE:
+	case LAST_SCENE_N_XX_DIE:
 	case LAST_SCENE_N_END:
 	case LAST_SCENE_N_MAX_N:
 		flagDone = true;
