@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: DemoSpace.h,v 1.3 2008/09/09 07:38:07 bowkenken Exp $
+* $Id: DemoSpace.h,v 1.7 2009/02/09 08:08:09 bowkenken Exp $
 ***************************************************************/
 
 #ifndef DEMO_SPACE_H
@@ -97,6 +97,15 @@ private:
 	long ny[NEBULA_MAX_N];
 	long nz[NEBULA_MAX_N];
 
+	// åա
+
+	long staffRollY;
+	long nStaffRollMaxLen;
+
+#ifdef D_MFC
+	long staffRollIdx;
+#endif // D_MFC
+
 #ifdef D_GTK
 	// եȤΥ
 	GtkStyle *pStyle;
@@ -116,7 +125,7 @@ public:
 	~DemoSpace();
 	void init();
 
-	bool draw( bool flagDrawTheEnd );
+	bool draw( bool flagDrawStaffRoll );
 
 private:
 	void initAnime();
@@ -126,7 +135,9 @@ private:
 	void drawStar( long x, long y, long z );
 	void drawNebula( Pcg *p, long x, long y, long z );
 
-	void drawString();
+	void drawStaffRoll();
+	void drawTheEnd();
+	void drawStaffRollLine( long x, long y, const char *str );
 	void drawCharStd( long x, long y, const char *str );
 	void drawChar(
 		long r, long g, long b,
