@@ -1,7 +1,7 @@
 
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -26,7 +26,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GameMusic.cpp,v 1.20 2008/10/06 23:03:53 bowkenken Exp $
+* $Id: GameMusic.cpp,v 1.26 2009/01/04 00:26:03 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -93,13 +93,7 @@ GameMusic::GameMusic()
 
 GameMusic::~GameMusic()
 {
-#ifdef	HAVE_SDL_SDL_MIXER_H
-	if( music != NULL ){
-		Mix_HaltMusic();
-		Mix_FreeMusic( music );
-		music = NULL;
-	}
-#endif
+	this->close();
 }
 
 ////////////////////////////////////////////////////////////////
@@ -228,6 +222,21 @@ void GameMusic::initLsMusic( LsMusic *ls, WSCstring dir )
 	}
 }
 
+////////////////////////////////////////////////////////////////
+// BGM λ
+////////////////////////////////////////////////////////////////
+
+void GameMusic::close()
+{
+#ifdef	HAVE_SDL_SDL_MIXER_H
+	if( music != NULL ){
+		Mix_HaltMusic();
+		Mix_FreeMusic( music );
+		music = NULL;
+	}
+#endif
+}
+
 ////////////////////////////////////////////////////////////////
 // ˹礻 BGM κ
 ////////////////////////////////////////////////////////////////
@@ -276,6 +285,8 @@ void GameMusic::playScene()
 		break;
 	case SCENE_N_ENDING_SPACE:
 		break;
+	case SCENE_N_ENDING_STAFF_ROLL:
+		break;
 	case SCENE_N_ENDING_END:
 		break;
 	case SCENE_N_SEL_MBR_GRAPH:
@@ -334,9 +345,14 @@ void GameMusic::playLastScene()
 	case LAST_SCENE_N_XEX_CUT_IN:
 	case LAST_SCENE_N_XEX_WORDS:
 	case LAST_SCENE_N_XEX_CUT_OUT:
-		break;
 	case LAST_SCENE_N_XEX_CUT_END:
+		break;
+	case LAST_SCENE_N_XX_ENTER:
+	case LAST_SCENE_N_XX_WORDS:
+		break;
+	case LAST_SCENE_N_XX_BATTLE:
 		play( MUSIC_KIND_BATTLE_LAST_BOSS );
+	case LAST_SCENE_N_XX_DIE:
 		break;
 	case LAST_SCENE_N_END:
 	case LAST_SCENE_N_MAX_N:
@@ -400,11 +416,28 @@ void GameMusic::play( music_kind_t kind, long idx )
 // 1 ζʤƱ
 ////////////////////////////////////////////////////////////////
 
-void GameMusic::replay()
+void GameMusic::replayPrev()
 {
 	play( prevKind, prevIdx );
 }
 
+////////////////////////////////////////////////////////////////
+// ߤζʤƱ
+////////////////////////////////////////////////////////////////
+
+void GameMusic::replay()
+{
+	music_kind_t kind = currentKind;
+	long idx = currentIdx;
+
+	currentKind = MUSIC_KIND_NULL;
+	currentIdx = 0;
+
+	currentName = "";
+
+	play( kind, idx );
+}
+
 ////////////////////////////////////////////////////////////////
 // ȥ̤ BGM κ
 // long idx : BGM ꥹȤΥǥå
@@ -628,12 +661,13 @@ void GameMusic::setCurrent( music_kind_t kind, long idx )
 ////////////////////////////////////////////////////////////////
 // ꥹȤ BGM 
 // LsMusic *p : BGM Υꥹ
+// long nRepeat : 
+// void (*func)() : λΥХå
 // return : BGM եΥѥ
 ////////////////////////////////////////////////////////////////
 
 WSCstring GameMusic::playRandm(
-	LsMusic *p, long nRepeat,
-	void (*func)() )
+	LsMusic *p, long nRepeat, void (*func)() )
 {
 	WSCstring name = "";
 	for( long i = 0; i < LOOP_MAX_1000; i++ ){
@@ -675,7 +709,7 @@ WSCstring GameMusic::playRandm(
 
 void donePlayEnding()
 {
-	change_scene( SCENE_N_ENDING_END );
+	change_scene( SCENE_N_ENDING_STAFF_ROLL );
 	gMusic.playTheEnd( 0 );
 }
 
@@ -685,5 +719,5 @@ void donePlayEnding()
 
 void donePlayEffect()
 {
-	gMusic.replay();
+	gMusic.replayPrev();
 }
