@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GlobalVar.cpp,v 1.25 2008/09/25 06:47:46 bowkenken Exp $
+* $Id: GlobalVar.cpp,v 1.28 2009/02/14 04:44:02 bowkenken Exp $
 ***************************************************************/
 
 #include "GlobalVar.h"
@@ -40,6 +40,7 @@ GuiInputString gGuiInpStr;
 GuiWords gGuiWords;
 GuiReplay gGuiReplay;
 GuiClassEdit gGuiClassEdit;
+GuiSkillEdit gGuiSkillEdit;
 GuiChrSheet gGuiChrSheet;
 SelMbrGraph *gSelMbrGraph;
 WinPos gWinPos[WIN_KIND_MAX_N];
@@ -47,6 +48,7 @@ WinPos gWinPos[WIN_KIND_MAX_N];
 PcgDun gPcgDun;
 
 GameMusic gMusic;
+GameSound gSound;
 GameJoystick gJoystick;
 
 Key gKey;
