@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GuiChrSheet.cpp,v 1.20 2009/03/04 11:47:40 bowkenken Exp $
+* $Id: GuiChrSheet.cpp,v 1.21 2009/05/14 08:33:26 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -2047,8 +2047,6 @@ void GuiChrSheet::destroy()
 #endif // D_GTK
 
 #ifdef D_MFC
-//@@@	delete ((CChrSheetDlg *)mChrSheetWin);
-//@@@	mChrSheetWin = NULL;
 #endif // D_MFC
 }
 
@@ -2130,7 +2128,6 @@ void GuiChrSheet::DdxToSheet()
 	mChrSheetWin->m_Stat.m_StrNameEdit = mbrData->name;
 	mChrSheetWin->m_Stat.m_StrFace = mbrData->face.mnr;
 	mChrSheetWin->m_Stat.m_StrRace = get_race_str( &(mbrData->race) );
-//@@@	mChrSheetWin->m_Stat.m_StrRaceName = get_race_name( &(mbrData->race) );
 	mChrSheetWin->m_Stat.m_StrRaceName = mbrData->race.name;
 	mChrSheetWin->m_Stat.m_StrSex = get_sex_name( mbrData->sex.cur );
 
@@ -2588,8 +2585,6 @@ void GuiChrSheet::DdxToSheet()
 
 void GuiChrSheet::DdxFromSheet()
 {
-#ifdef D_MFC
-#endif // D_MFC
 }
 
 ////////////////////////////////////////////////////////////////
