@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GuiChrSheet.h,v 1.11 2008/10/09 05:48:35 bowkenken Exp $
+* $Id: GuiChrSheet.h,v 1.14 2009/02/06 01:46:37 bowkenken Exp $
 ***************************************************************/
 
 #ifndef GUI_CHR_SHEET_H
@@ -85,6 +85,18 @@ private:
 
 	GtkWidget *mAblResi[3][3];
 
+	// 
+
+	GtkWidget *mSkillClass;
+
+	GtkWidget *mSkillName[SKILL_MAX_PAGE][SKILL_PER_PAGE_MAX_N];
+	GtkWidget *mSkillLev[SKILL_MAX_PAGE][SKILL_PER_PAGE_MAX_N];
+	GtkWidget *mSkillExp[SKILL_MAX_PAGE][SKILL_PER_PAGE_MAX_N];
+	GtkWidget *mSkillNeedExp[SKILL_MAX_PAGE][SKILL_PER_PAGE_MAX_N];
+
+	GtkWidget *mSkillTextScroll[SKILL_MAX_PAGE];
+	GtkWidget *mSkillTextView[SKILL_MAX_PAGE];
+
 	// ƥ
 
 	GtkWidget *mItemName[MBR_ITEM_MAX_N];
@@ -140,6 +152,7 @@ public:
 	bool tileClicked();
 
 	bool classClicked();
+	bool skillClicked( long n );
 	bool itemClicked( long n );
 	bool equipClicked( long n );
 
@@ -150,12 +163,15 @@ private:
 	void newWinMisc();
 	void newWinStatTab();
 	void newWinAblTab();
+	void newWinSkillTab( long page );
 	void newWinItemTab();
 	void newWinEquipTab();
 
 	void drawMisc( mbr_t *org, mbr_t *mbr );
 	void drawStat( mbr_t *org, mbr_t *mbr );
 	void drawAbl( mbr_t *org, mbr_t *mbr );
+	void drawSkill( mbr_t *org, mbr_t *mbr, long page );
+	void drawSkillHint( long nSlot );
 	void drawItem( mbr_t *org, mbr_t *mbr );
 	void drawEquip( mbr_t *org, mbr_t *mbr );
 
