@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GuiMenu.cpp,v 1.37 2008/09/20 22:36:14 bowkenken Exp $
+* $Id: GuiMenu.cpp,v 1.39 2009/03/04 11:47:40 bowkenken Exp $
 ***************************************************************/
 
 #include	"gmain.h"
@@ -122,33 +122,33 @@ void EpGuiMenuSel( WSCbase *obj );
 
 #ifdef D_GTK
 
-void handle_menu_win_destroy(
+gint handle_menu_win_destroy(
 	GtkWidget *widget, gpointer data
 );
 
-void handle_menu_page_release(
+gint handle_menu_page_release(
 	GtkWidget *widget, GdkEventButton *event, gpointer data
 );
-void handle_menu_cancel_release(
+gint handle_menu_cancel_release(
 	GtkWidget *widget, GdkEventButton *event, gpointer data
 );
-void handle_menu_cancel_all_release(
+gint handle_menu_cancel_all_release(
 	GtkWidget *widget, GdkEventButton *event, gpointer data
 );
 
-void handle_menu_button_clicked(
+gint handle_menu_button_clicked(
 	GtkWidget *widget, gpointer data
 );
-void handle_menu_button_press(
+gint handle_menu_button_press(
 	GtkWidget *widget, GdkEventButton *event, gpointer data
 );
-void handle_menu_button_release(
+gint handle_menu_button_release(
 	GtkWidget *widget, GdkEventButton *event, gpointer data
 );
-void handle_menu_button_enter(
+gint handle_menu_button_enter(
 	GtkWidget *widget, gpointer data
 );
-void handle_menu_button_leave(
+gint handle_menu_button_leave(
 	GtkWidget *widget, gpointer data
 );
 
@@ -925,17 +925,17 @@ void EpGuiMenuSel( WSCbase *obj )
 ////////////////////////////////////////////////////////////////
 
 #ifdef D_GTK
-
-void handle_menu_win_destroy(
+gint handle_menu_win_destroy(
 	GtkWidget *widget, gpointer data
 )
 {
 	if( data == NULL )
-		return;
+		return 0;
 
 	((GuiMenu *)data)->destroy();
-}
 
+	return 0;
+}
 #endif // D_GTK
 
 ////////////////////////////////////////////////////////////////
@@ -946,8 +946,7 @@ void handle_menu_win_destroy(
 ////////////////////////////////////////////////////////////////
 
 #ifdef D_GTK
-
-void handle_menu_page_release(
+gint handle_menu_page_release(
 	GtkWidget *widget, GdkEventButton *event, gpointer data
 )
 {
@@ -964,8 +963,9 @@ void handle_menu_page_release(
 		if( d >= +1 )
 			gKey.setString( "4" );
 	}
-}
 
+	return 0;
+}
 #endif // D_GTK
 
 ////////////////////////////////////////////////////////////////
@@ -976,14 +976,14 @@ void handle_menu_page_release(
 ////////////////////////////////////////////////////////////////
 
 #ifdef D_GTK
-
-void handle_menu_cancel_release(
+gint handle_menu_cancel_release(
 	GtkWidget *widget, GdkEventButton *event, gpointer data
 )
 {
 	gKey.setString( "0" );
-}
 
+	return 0;
+}
 #endif // D_GTK
 
 ////////////////////////////////////////////////////////////////
@@ -994,14 +994,14 @@ void handle_menu_cancel_release(
 ////////////////////////////////////////////////////////////////
 
 #ifdef D_GTK
-
-void handle_menu_cancel_all_release(
+gint handle_menu_cancel_all_release(
 	GtkWidget *widget, GdkEventButton *event, gpointer data
 )
 {
 	gKey.setString( "/" );
-}
 
+	return 0;
+}
 #endif // D_GTK
 
 ////////////////////////////////////////////////////////////////
@@ -1011,14 +1011,14 @@ void handle_menu_cancel_all_release(
 ////////////////////////////////////////////////////////////////
 
 #ifdef D_GTK
-
-void handle_menu_button_clicked(
+gint handle_menu_button_clicked(
 	GtkWidget *widget, gpointer data
 )
 {
 	gKey.setChar( gGuiMenu.getAccelKey( (long)data ) );
-}
 
+	return 0;
+}
 #endif // D_GTK
 
 ////////////////////////////////////////////////////////////////
@@ -1029,15 +1029,15 @@ void handle_menu_button_clicked(
 ////////////////////////////////////////////////////////////////
 
 #ifdef D_GTK
-
-void handle_menu_button_press(
+gint handle_menu_button_press(
 	GtkWidget *widget, GdkEventButton *event, gpointer data
 )
 {
 	gGuiMenu.nClickedButton = (long)data;
 	gGuiMenu.bFlagEnter = TRUE;
-}
 
+	return 0;
+}
 #endif // D_GTK
 
 ////////////////////////////////////////////////////////////////
@@ -1048,21 +1048,21 @@ void handle_menu_button_press(
 ////////////////////////////////////////////////////////////////
 
 #ifdef D_GTK
-
-void handle_menu_button_release(
+gint handle_menu_button_release(
 	GtkWidget *widget, GdkEventButton *event, gpointer data
 )
 {
 	if( !gGuiMenu.bFlagEnter )
-		return;
+		return 0;
 
 	if( event->button == GuiMenu::MOUSE_BUTTON_N_LEFT ){
 		gKey.setChar( gGuiMenu.getAccelKey( (long)data ) );
 	} else if( event->button == GuiMenu::MOUSE_BUTTON_N_RIGHT ){
 		gKey.setString( "0" );
 	}
-}
 
+	return 0;
+}
 #endif // D_GTK
 
 ////////////////////////////////////////////////////////////////
@@ -1073,15 +1073,15 @@ void handle_menu_button_release(
 ////////////////////////////////////////////////////////////////
 
 #ifdef D_GTK
-
-void handle_menu_button_enter(
+gint handle_menu_button_enter(
 	GtkWidget *widget, gpointer data
 )
 {
 	if( gGuiMenu.nClickedButton == (long)data )
 		gGuiMenu.bFlagEnter = TRUE;
-}
 
+	return 0;
+}
 #endif // D_GTK
 
 ////////////////////////////////////////////////////////////////
@@ -1092,12 +1092,12 @@ void handle_menu_button_enter(
 ////////////////////////////////////////////////////////////////
 
 #ifdef D_GTK
-
-void handle_menu_button_leave(
+gint handle_menu_button_leave(
 	GtkWidget *widget, gpointer data
 )
 {
 	gGuiMenu.bFlagEnter = FALSE;
-}
 
+	return 0;
+}
 #endif // D_GTK
