@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GuiNum.cpp,v 1.21 2008/08/18 08:25:38 bowkenken Exp $
+* $Id: GuiNum.cpp,v 1.26 2009/03/11 17:19:31 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -47,18 +47,19 @@
 ////////////////////////////////////////////////////////////////
 
 #ifdef D_GTK
-void handle_num_destroy( GtkWidget *widget, gpointer user_data );
+gint handle_num_delete( GtkWidget *widget, gpointer user_data );
+gint handle_num_destroy( GtkWidget *widget, gpointer user_data );
 gint handle_num_expose( GtkWidget *widget, GdkEventExpose *event );
 
-void handle_num_hscale_changed( GtkAdjustment *adj, gpointer user_data );
+gint handle_num_hscale_changed( GtkAdjustment *adj, gpointer user_data );
 
-void handle_num_spin_changed( GtkAdjustment *adj, gpointer user_data );
+gint handle_num_spin_changed( GtkAdjustment *adj, gpointer user_data );
 
-void handle_num_0_clicked( GtkButton *button, gpointer user_data );
-void handle_num_up_clicked( GtkButton *button, gpointer user_data );
-void handle_num_down_clicked( GtkButton *button, gpointer user_data );
+gint handle_num_0_clicked( GtkButton *button, gpointer user_data );
+gint handle_num_up_clicked( GtkButton *button, gpointer user_data );
+gint handle_num_down_clicked( GtkButton *button, gpointer user_data );
 
-void handle_num_ok_clicked( GtkButton *button, gpointer user_data );
+gint handle_num_ok_clicked( GtkButton *button, gpointer user_data );
 #endif // D_GTK
 
 ////////////////////////////////////////////////////////////////
@@ -67,6 +68,7 @@ void handle_num_ok_clicked( GtkButton *button, gpointer user_data );
 
 GuiNum::GuiNum()
 {
+	mFlagInitDone = false;
 	mNumWin = NULL;
 	mPN = NULL;
 	mOrg = 0;
@@ -101,6 +103,8 @@ void GuiNum::newWin()
 	if( mNumWin != NULL )
 		return;
 
+	mFlagInitDone = false;
+
 #ifdef D_WS
 	mNumWin = (void *)1;
 #endif // D_WS
@@ -120,6 +124,10 @@ void GuiNum::newWin()
 
 	// ϥɥؤΥ٥ȡϥɥ
 
+	gtk_signal_connect( GTK_OBJECT( mNumWin ),
+			"delete_event",
+			GTK_SIGNAL_FUNC( handle_num_delete ),
+			this );
 	gtk_signal_connect( GTK_OBJECT( mNumWin ),
 			"destroy",
 			GTK_SIGNAL_FUNC( handle_num_destroy ),
@@ -444,7 +452,29 @@ void GuiNum::draw( volatile long *n, long min, long max, long figure )
 	mMax = max;
 	mFigure = figure;
 
+	if( mNumWin == NULL )
+		newWin();
+
+#ifdef D_GTK
 	redraw();
+
+	gWinPos[WIN_KIND_INPUT_NUM].get( WIN_KIND_INPUT_NUM,
+			NULL, NULL, NULL, NULL );
+	gWinPos[WIN_KIND_INPUT_NUM].draw( WIN_KIND_INPUT_NUM );
+
+	mFlagInitDone = true;
+#endif // D_GTK
+
+#ifdef D_MFC
+	CInputNumDlg *dlg = (CInputNumDlg *)mNumWin;
+	dlg->m_Min = mMin;
+	dlg->m_Max = mMax;
+	dlg->m_Org = *mPN;
+	dlg->m_Cur = mPN;
+	mFlagInitDone = true;
+
+	dlg->DoModal();
+#endif // D_MFC
 }
 
 ////////////////////////////////////////////////////////////////
@@ -453,21 +483,8 @@ void GuiNum::draw( volatile long *n, long min, long max, long figure )
 
 void GuiNum::redraw()
 {
-	if( mNumWin == NULL ){
+	if( mNumWin == NULL )
 		newWin();
-	} else {
-#ifdef D_MFC
-		CInputNumDlg *dlg = (CInputNumDlg *)mNumWin;
-
-		WSCstring str;
-		str = (long)*mPN;
-		dlg->m_Edit.SetWindowText( str );
-
-		dlg->SetSldrPos( *mPN );
-
-		return;
-#endif // D_MFC
-	}
 
 	if( mPN == NULL )
 		return;
@@ -476,10 +493,10 @@ void GuiNum::redraw()
 	GtkAdjustment *adj;
 
 	adj = GTK_ADJUSTMENT( mHscaleAdjustment );
-	if( adj->value != *mPN ){
+	if( (long)(adj->value) != *mPN ){
 		long incPage = 1;
 
-		adj->value = *mPN;
+		adj->value = (gfloat)*mPN;
 		adj->lower = mMin;
 		adj->upper = mMax + incPage;
 		adj->step_increment = 1;
@@ -490,10 +507,10 @@ void GuiNum::redraw()
 	}
 
 	adj = GTK_ADJUSTMENT( mNumAdjustment );
-	if( adj->value != *mPN ){
+	if( (long)(adj->value) != *mPN ){
 		long incPage = 1;
 
-		adj->value = *mPN;
+		adj->value = (gfloat)*mPN;
 		adj->lower = mMin;
 		adj->upper = mMax + incPage;
 		adj->step_increment = 1;
@@ -504,18 +521,16 @@ void GuiNum::redraw()
 	}
 
 	cvUpDownFromN();
-
-	gWinPos[WIN_KIND_INPUT_NUM].draw( WIN_KIND_INPUT_NUM );
 #endif // D_GTK
 
 #ifdef D_MFC
 	CInputNumDlg *dlg = (CInputNumDlg *)mNumWin;
-	dlg->m_Min = mMin;
-	dlg->m_Max = mMax;
-	dlg->m_Org = *mPN;
-	dlg->m_Cur = mPN;
 
-	dlg->DoModal();
+	WSCstring str;
+	str = (long)*mPN;
+	dlg->m_Edit.SetWindowText( str );
+
+	dlg->SetSldrPos( *mPN );
 #endif // D_MFC
 }
 
@@ -546,10 +561,14 @@ void GuiNum::valueChanged( long n )
 	if( mPN == NULL )
 		return;
 
-	*mPN = n;
-	gKey.setChar( '|' );
+	if( *mPN == n )
+		return;
 
-	redraw();
+	if( mFlagInitDone ){
+		*mPN = n;
+		gKey.setChar( '|' );
+		redraw();
+	}
 }
 
 ////////////////////////////////////////////////////////////////
@@ -564,6 +583,8 @@ void GuiNum::up_down_num_label( long n, long d )
 		return;
 	if( n >= GUI_NUM_BUTTON_MAX_N )
 		return;
+	if( (n % 4) == 3 )
+		return;
 
 #ifdef D_WS
 #endif // D_WS
@@ -572,7 +593,7 @@ void GuiNum::up_down_num_label( long n, long d )
 	char *str = NULL;
 
 	GtkLabel *lbl = get_label_from_button(
-			GTK_BUTTON( gGuiNum.mButtonLabel[n] ) );
+			GTK_BUTTON( mButtonLabel[n] ) );
 
 	gtk_label_get( lbl, &str );
 #endif // D_GTK
@@ -594,25 +615,31 @@ void GuiNum::up_down_num_label( long n, long d )
 	num[0] = c;
 	num[1] = '\0';
 
-	if( (c == '+') || (c == '-') )
-		gKey.setChar( KEY_MENU_NUM_SGN );
-	else
-		gKey.setChar( 'A' + (n - n / 4) );
-
 #ifdef D_WS
 #endif // D_WS
 
 #ifdef D_GTK
-	gtk_label_set_text( lbl, num );
+	//gtk_label_set_text( lbl, num );
+
+	if( (c == '+') || (c == '-') )
+		gKey.setChar( KEY_MENU_NUM_SGN );
+	else
+		gKey.setChar( 'A' + (n - n / 4) );
+	if( d >= +1 )
+		gKey.setChar( '8' );
+	else if( d <= -1 )
+		gKey.setChar( '2' );
+	else
+		gKey.setChar( '5' );
 #endif // D_GTK
 
 #ifdef D_MFC
 	((CInputNumDlg *)mNumWin)->m_Clr[n]
 			.SetWindowText( num );
-#endif // D_MFC
 
 	cvUpDownToN();
 	redraw();
+#endif // D_MFC
 }
 
 ////////////////////////////////////////////////////////////////
@@ -697,11 +724,10 @@ void GuiNum::cvUpDownToN()
 		base *= 10;
 	}
 
-	if( mPN == NULL )
-		return;
-
-	*mPN = n;
-	gKey.setChar( '|' );
+	if( mPN != NULL ){
+		*mPN = n;
+		gKey.setChar( '|' );
+	}
 }
 
 ////////////////////////////////////////////////////////////////
@@ -717,7 +743,7 @@ void GuiNum::cvUpDownFromN()
 
 #ifdef D_GTK
 	GtkLabel *lbl;
-	gchar str[1 + 1]  = "";
+	char str[1 + 1] = "";
 
 	long n = labs( *mPN );
 	long f = 0;
@@ -872,14 +898,31 @@ void GuiNum::okClicked( menu_num_t n )
 	redraw();
 }
 
+////////////////////////////////////////////////////////////////
+// ϥɥĤΥϥɥ
+////////////////////////////////////////////////////////////////
+
+#ifdef D_GTK
+gint handle_num_delete( GtkWidget *widget, gpointer user_data )
+{
+	gKey.setChar( '0' );
+	gGuiNum.wipe();
+
+	return 0;
+}
+#endif // D_GTK
+
 ////////////////////////////////////////////////////////////////
 // ϥɥνλΥϥɥ
 ////////////////////////////////////////////////////////////////
 
 #ifdef D_GTK
-void handle_num_destroy( GtkWidget *widget, gpointer user_data )
+gint handle_num_destroy( GtkWidget *widget, gpointer user_data )
 {
+	gGuiNum.wipe();
 	gGuiNum.destroy();
+
+	return 0;
 }
 #endif // D_GTK
 
@@ -895,7 +938,7 @@ gint handle_num_expose( GtkWidget *widget, GdkEventExpose *event )
 {
 	gGuiNum.redraw();
 
-	return TRUE;
+	return 0;
 }
 #endif // D_GTK
 
@@ -906,12 +949,14 @@ gint handle_num_expose( GtkWidget *widget, GdkEventExpose *event )
 ////////////////////////////////////////////////////////////////
 
 #ifdef D_GTK
-void handle_num_hscale_changed( GtkAdjustment *adj, gpointer user_data )
+gint handle_num_hscale_changed( GtkAdjustment *adj, gpointer user_data )
 {
 	if( adj == NULL )
-		return;
+		return 0;
 
 	gGuiNum.valueChanged( (long)(adj->value) );
+
+	return 0;
 }
 #endif // D_GTK
 
@@ -922,12 +967,14 @@ void handle_num_hscale_changed( GtkAdjustment *adj, gpointer user_data )
 ////////////////////////////////////////////////////////////////
 
 #ifdef D_GTK
-void handle_num_spin_changed( GtkAdjustment *adj, gpointer user_data )
+gint handle_num_spin_changed( GtkAdjustment *adj, gpointer user_data )
 {
 	if( adj == NULL )
-		return;
+		return 0;
 
 	gGuiNum.valueChanged( (long)(adj->value) );
+
+	return 0;
 }
 #endif // D_GTK
 
@@ -938,9 +985,11 @@ void handle_num_spin_changed( GtkAdjustment *adj, gpointer user_data )
 ////////////////////////////////////////////////////////////////
 
 #ifdef D_GTK
-void handle_num_0_clicked( GtkButton *button, gpointer user_data )
+gint handle_num_0_clicked( GtkButton *button, gpointer user_data )
 {
 	gGuiNum.up_down_num_label( (long)user_data, +-0 );
+
+	return 0;
 }
 #endif // D_GTK
 
@@ -951,9 +1000,11 @@ void handle_num_0_clicked( GtkButton *button, gpointer user_data )
 ////////////////////////////////////////////////////////////////
 
 #ifdef D_GTK
-void handle_num_up_clicked( GtkButton *button, gpointer user_data )
+gint handle_num_up_clicked( GtkButton *button, gpointer user_data )
 {
 	gGuiNum.up_down_num_label( (long)user_data, +1 );
+
+	return 0;
 }
 #endif // D_GTK
 
@@ -964,9 +1015,11 @@ void handle_num_up_clicked( GtkButton *button, gpointer user_data )
 ////////////////////////////////////////////////////////////////
 
 #ifdef D_GTK
-void handle_num_down_clicked( GtkButton *button, gpointer user_data )
+gint handle_num_down_clicked( GtkButton *button, gpointer user_data )
 {
 	gGuiNum.up_down_num_label( (long)user_data, -1 );
+
+	return 0;
 }
 #endif // D_GTK
 
@@ -977,8 +1030,10 @@ void handle_num_down_clicked( GtkButton *button, gpointer user_data )
 ////////////////////////////////////////////////////////////////
 
 #ifdef D_GTK
-void handle_num_ok_clicked( GtkButton *button, gpointer user_data )
+gint handle_num_ok_clicked( GtkButton *button, gpointer user_data )
 {
 	gGuiNum.okClicked( (menu_num_t)(int)user_data );
+
+	return 0;
 }
 #endif // D_GTK
