@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: Key.cpp,v 1.17 2008/09/27 08:48:04 bowkenken Exp $
+* $Id: Key.cpp,v 1.20 2009/02/19 03:42:31 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -748,13 +748,13 @@ void Key::setStringKeyTab( WSCstring s )
 			bFlgTab = false;
 
 		if( bFlgTab ){
-			set_key_buf_str( tab[c] );
+			set_key_buf_str_tail( tab[c] );
 		} else {
 			WSCstring buf;
 			buf = s;
 			buf.cutString( 1 );
 
-			set_key_buf_str( buf );
+			set_key_buf_str_tail( buf );
 		}
 	}
 
@@ -818,34 +818,44 @@ bool Key::moveCrsrAbs( long mapX, long mapY )
 
 	crsr->x = mapX;
 	crsr->y = mapY;
+	CheckMoveCrsr();
+	setString( "|", true );
 
-	//
+	return true;
+}
 
+////////////////////////////////////////////////////////////////
+// 뤬ư˥ޥåפ򥹥뤹
+////////////////////////////////////////////////////////////////
+
+void Key::CheckMoveCrsr()
+{
 	long a = 1;
 #ifdef	D_MFC
 	a = 0;
 #endif	// D_MFC
 
+	pos_t *crsr = get_crsr();
+	if( crsr == NULL )
+		return;
+
 	pos_t *draw_gui = get_map_draw_pos_gui();
-	if( draw_gui != NULL ){
-		long w = gPcgDun.getScrollBarW();
-		long h = gPcgDun.getScrollBarH();
-		w /= gPcgDun.getTileSizeX( true );
-		h /= gPcgDun.getTileSizeY( true );
+	if( draw_gui == NULL )
+		return;
 
-		if( draw_gui->x > mapX )
-			draw_gui->x = mapX;
-		if( draw_gui->y > mapY )
-			draw_gui->y = mapY;
-		if( draw_gui->x < (mapX - w + a) )
-			draw_gui->x = (mapX - w + a);
-		if( draw_gui->y < (mapY - h + a) )
-			draw_gui->y = (mapY - h + a);
-	}
+	long w = gPcgDun.getScrollBarW();
+	long h = gPcgDun.getScrollBarH();
+	w /= gPcgDun.getTileSizeX( true );
+	h /= gPcgDun.getTileSizeY( true );
 
-	setString( "|", true );
-
-	return true;
+	if( draw_gui->x > crsr->x )
+		draw_gui->x = crsr->x;
+	if( draw_gui->y > crsr->y )
+		draw_gui->y = crsr->y;
+	if( draw_gui->x < (crsr->x - w + a) )
+		draw_gui->x = (crsr->x - w + a);
+	if( draw_gui->y < (crsr->y - h + a) )
+		draw_gui->y = (crsr->y - h + a);
 }
 
 ////////////////////////////////////////////////////////////////
@@ -895,27 +905,33 @@ bool Key::scrollAbs( long mapX, long mapY )
 
 	draw_gui->x = mapX;
 	draw_gui->y = mapY;
-
-	//
-
-	pos_t *crsr = get_crsr();
-	if( crsr != NULL ){
-		long w = gPcgDun.getScrollBarW();
-		long h = gPcgDun.getScrollBarH();
-		w /= gPcgDun.getTileSizeX( true );
-		h /= gPcgDun.getTileSizeY( true );
-
-		if( crsr->x < mapX )
-			crsr->x = mapX;
-		if( crsr->y < mapY )
-			crsr->y = mapY;
-		if( crsr->x > (mapX + w - 1) )
-			crsr->x = (mapX + w - 1);
-		if( crsr->y > (mapY + h - 1) )
-			crsr->y = (mapY + h - 1);
-	}
-
+	CheckScroll();
 	setString( "|", true );
 
 	return true;
 }
+
+////////////////////////////////////////////////////////////////
+// ޥåפ뤷˥ΤϤ߽Фå
+////////////////////////////////////////////////////////////////
+
+void Key::CheckScroll()
+{
+	pos_t *crsr = get_crsr();
+	if( crsr == NULL )
+		return;
+
+	long w = gPcgDun.getScrollBarW();
+	long h = gPcgDun.getScrollBarH();
+	w /= gPcgDun.getTileSizeX( true );
+	h /= gPcgDun.getTileSizeY( true );
+
+	if( crsr->x < crsr->x )
+		crsr->x = crsr->x;
+	if( crsr->y < crsr->y )
+		crsr->y = crsr->y;
+	if( crsr->x > (crsr->x + w - 1) )
+		crsr->x = (crsr->x + w - 1);
+	if( crsr->y > (crsr->y + h - 1) )
+		crsr->y = (crsr->y + h - 1);
+}
