@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: MouseMap.cpp,v 1.33 2008/09/20 01:20:41 bowkenken Exp $
+* $Id: MouseMap.cpp,v 1.35 2009/03/11 19:00:53 bowkenken Exp $
 ***************************************************************/
 
 #ifdef D_WS
@@ -278,8 +278,27 @@ void funcMotionPoint(
 
 	long x = gPcgDun.getScrollBarX();
 	long y = gPcgDun.getScrollBarY();
+	long w = gPcgDun.getScrollBarW();
+	long h = gPcgDun.getScrollBarH();
+
+	if( nCurX < 0 )
+		return;
+	if( nCurY < 0 )
+		return;
+	if( nCurX >= w )
+		return;
+	if( nCurY >= h )
+		return;
+
 	long mapX = (x + nCurX) / gPcgDun.getTileSizeX( true );
 	long mapY = (y + nCurY) / gPcgDun.getTileSizeY( true );
+	long mapX2 = (x + w) / gPcgDun.getTileSizeX( true );
+	long mapY2 = (y + h) / gPcgDun.getTileSizeY( true );
+
+	if( mapX >= mapX2 )
+		return;
+	if( mapY >= mapY2 )
+		return;
 
 	gKey.moveCrsrAbs( mapX, mapY );
 
