@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: Pcg.cpp,v 1.25 2008/05/13 06:21:21 bowkenken Exp $
+* $Id: Pcg.cpp,v 1.27 2009/02/19 02:11:23 bowkenken Exp $
 ***************************************************************/
 
 #include <time.h>
@@ -190,6 +190,21 @@ void Pcg::load( WSCstring path )
 	pImage->setTextureSize();
 	pImage->setImageSize( info.Width, info.Height );
 #endif // D_MFC
+
+#ifdef D_WS
+	nWidth = pImage->getImageWidth();
+	nHeight = pImage->getImageHeight();
+#endif // D_WS
+
+#ifdef D_GTK
+	nWidth = pImage->getImageWidth();
+	nHeight = pImage->getImageHeight();
+#endif // D_GTK
+
+#ifdef D_MFC
+	nWidth = pImage->getImageWidth();
+	nHeight = pImage->getImageHeight();
+#endif // D_MFC
 }
 
 ////////////////////////////////////////////////////////////////
@@ -242,19 +257,7 @@ long Pcg::getWidth()
 	if( pImage == NULL )
 		return 0;
 
-#ifdef D_WS
-	return pImage->getImageWidth();
-#endif // D_WS
-
-#ifdef D_GTK
-	return pImage->getImageWidth();
-#endif // D_GTK
-
-#ifdef D_MFC
-	return pImage->getImageWidth();
-#endif // D_MFC
-
-	return 0;
+	return nWidth;
 }
 
 ////////////////////////////////////////////////////////////////
@@ -267,19 +270,7 @@ long Pcg::getHeight()
 	if( pImage == NULL )
 		return 0;
 
-#ifdef D_WS
-	return pImage->getImageHeight();
-#endif // D_WS
-
-#ifdef D_GTK
-	return pImage->getImageHeight();
-#endif // D_GTK
-
-#ifdef D_MFC
-	return pImage->getImageHeight();
-#endif // D_MFC
-
-	return 0;
+	return nHeight;
 }
 
 ////////////////////////////////////////////////////////////////
