@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: call.cpp,v 1.100 2009/02/14 04:43:41 bowkenken Exp $
+* $Id: call.cpp,v 1.101 2009/05/13 23:36:57 bowkenken Exp $
 ***************************************************************/
 
 #define	CALL_CPP
@@ -732,7 +732,8 @@ bool_t	call_sel_mbr_graph_begin( mbr_t *mbr )
 
 	gui_begin();
 
-	gSelMbrGraph = new SelMbrGraph;
+	if( gSelMbrGraph == NULL )
+		gSelMbrGraph = new SelMbrGraph;
 	flgWait = gSelMbrGraph->exec( mbr );
 
 	gui_end();
@@ -759,6 +760,7 @@ void	call_sel_mbr_graph_end( void )
 	gui_begin();
 
 	delete gSelMbrGraph;
+	gSelMbrGraph = NULL;
 
 	gui_end();
 #endif
