@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: dun.c,v 1.114 2008/05/10 03:21:35 bowkenken Exp $
+* $Id: dun.c,v 1.147 2009/03/13 15:00:30 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -43,7 +43,35 @@
 /* ϩɽꥢμ */
 #define	AREA_PATH	-1
 
-/* Ψ */
+/* 곬ʤο */
+#define	STAIRS_UP_MAX_N	2
+
+/* 곬ʤο */
+#define	STAIRS_DOWN_MAX_N	2
+
+/* 饹ȡơγʤο */
+#define	STAIRS_LAST_BOSS_MAX_N	2
+
+/* 겼ȽγʤޤǤεΥ */
+#define	STAIRS_MAX_R	2
+
+/* ߤγؤƤ NPC ʿѿ */
+#define	DUN_NPC_AVE_N	6
+
+/* (NPC ʿѿ) - () / ? */
+#define	DUN_NPC_DIV_N	4
+
+/* 1ֶᤤɥõƱΥˤȽǤΥ */
+#define	DOOR_NEAR_R	4
+
+#define	LAST_BOSS_ROOM_PTN_MAX_N	3
+
+/***************************************************************
+* Ψ
+***************************************************************/
+
+/* ꥢ꤬ƤγΨ */
+#define	LIGHTED_ROOM_MAX_RATE	((rate_t)80)
 
 /* ꥢˤʤΨ */
 #define	RATE_ROOM	((rate_t)50)
@@ -61,36 +89,14 @@
 #define	RATE_HIDE_CROSS_PATH	((rate_t)80)
 
 /* 󥹥ΥߥߥåȢǤʤΨ */
-#define	MIMIC_RATE	50
-
-/***************************************************************/
-
-/* 곬ʤο */
-#define	STAIRS_UP_MAX_N	2
-
-/* 곬ʤο */
-#define	STAIRS_DOWN_MAX_N	2
-
-/* 겼ȽγʤޤǤεΥ */
-#define	STAIRS_MAX_R	2
-
-/* ߤγؤƤ NPC ʿѿ */
-#define	DUN_NPC_AVE_N	6
-
-/* (NPC ʿѿ) - () / ? */
-#define	DUN_NPC_DIV_N	4
-
-/* 1ֶᤤɥõƱΥˤȽǤΥ */
-#define	DOOR_NEAR_R	4
-
-/* ܥŪи볬ؿ */
-#define	DUN_LEV_BOSS	10
+#define	MIMIC_RATE	((rate_t)50)
 
 /***************************************************************
 * ѿ
 ***************************************************************/
 
 static dun_t	dun;
+
 static area_t	g_room_ptn_max_n, g_boss_room_ptn_max_n;
 
 static crsr_ptn_t	g_crsr_ptn, g_crsr_ptn_usr[CRSR_PTN_MAX_N];
@@ -117,6 +123,11 @@ void	init_dun( void )
 	g_nest_flg_dun = make_nest_flg();
 	bgn_nest_flg( g_nest_flg_dun );
 
+	g_room_ptn_max_n = sizeof( room_ptn )
+			/ sizeof( room_ptn_t );
+	g_boss_room_ptn_max_n = sizeof( boss_room_ptn )
+			/ sizeof( room_ptn_t );
+
 	reset_dun( FALSE );
 
 	/* cursor */
@@ -238,7 +249,8 @@ void	reset_dun( bool_t flg_wall )
 			} else {
 				dun.map.obj.mjr[y][x] = FACE_MJR_FLOOR;
 				dun.map.obj.mnr[y][x] = FACE_MNR_FLOOR;
-				dun.map.obj.flg[y][x] = FLG_MAP_OBJ_PASS;
+				dun.map.obj.flg[y][x] = (FLG_MAP_OBJ_PASS
+						| FLG_MAP_OBJ_LOOK);
 			}
 
 			dun.map.chr.mjr[y][x] = FACE_MJR_NULL;
@@ -264,6 +276,8 @@ void	reset_dun( bool_t flg_wall )
 
 	dun.door_n = 0;
 
+	reset_map_event();
+
 	end_nest_flg( g_nest_flg_dun );
 }
 
@@ -365,14 +379,20 @@ void	up_dun( long d )
 	if( sgn_l( dun.lev ) >= +1 ){
 		print_msg( FLG_NULL, MSG_UP_DOWN_DUN_FLOOR,
 				labs( dun.lev ) );
+		change_scene( SCENE_N_DUN );
 	} else if( sgn_l( dun.lev ) <= -1 ){
 		print_msg( FLG_NULL, MSG_UP_DOWN_DUN_BASE,
 				labs( dun.lev ) );
+		change_scene( SCENE_N_DUN );
 	} else {
 		print_msg( FLG_NULL, MSG_UP_DOWN_DUN_GROUND );
+		change_scene( SCENE_N_TOWN );
 	}
 
+	/* Сãؤ򹹿 */
+
 	for( i = 0; i < MBR_MAX_N; i++ ){
+		/* Ͼ */
 		if( sgn_l( dun.lev ) >= +1 ){
 			if( pty->mbr[i]->dun_max_lev_floor
 					< labs( dun.lev ) ){
@@ -380,6 +400,7 @@ void	up_dun( long d )
 						= labs( dun.lev );
 			}
 		}
+		/* ϲ */
 		if( sgn_l( dun.lev ) <= -1 ){
 			if( pty->mbr[i]->dun_max_lev_base
 					< labs( dun.lev ) ){
@@ -392,6 +413,17 @@ void	up_dun( long d )
 	reset_all( TRUE );
 }
 
+/***************************************************************
+* 饹ܥγؤ
+***************************************************************/
+
+void	enter_last_boss_dun( void )
+{
+	change_last_scene( LAST_SCENE_N_ENTER );
+	reset_all( TRUE );
+	set_map_event_tab( last_boss_map_event_tab );
+}
+
 /***************************************************************
 * µܤ(μ)
 * bool_t flg_appear : ѡƥνи򤹤뤫?
@@ -427,7 +459,10 @@ void	reset_all( bool_t flg_appear )
 	clr_map_all_mbr();
 	clr_map_all_pet();
 
-	if( dun.lev == 0 ){
+	if( get_scene() == SCENE_N_LAST_BOSS ){
+		make_dun_last_boss();
+		appear_party_last_boss();
+	} else if( dun.lev == 0 ){
 		make_town();
 		if( flg_appear ){
 			if( !appear_party_town() )
@@ -443,8 +478,7 @@ void	reset_all( bool_t flg_appear )
 
 	end_nest_flg( g_nest_flg_dun );
 
-	if( g_flg_gui )
-		call_pcg_dun_reset();
+	call_pcg_dun_reset();
 	redraw_all();
 }
 
@@ -464,20 +498,9 @@ void	make_dun( void )
 
 	bgn_nest_flg( g_nest_flg_dun );
 
-	reset_dun( TRUE );
-
-	g_room_ptn_max_n = sizeof( room_ptn )
-			/ sizeof( room_ptn_t );
-	g_boss_room_ptn_max_n = sizeof( boss_room_ptn )
-			/ sizeof( room_ptn_t );
-
 	/*  */
 
-	for( y = 0; y < AREA_MAP_MAX_Y; y++ ){
-		for( x = 0; x < AREA_MAP_MAX_X; x++ ){
-			dun.area[y][x] = AREA_PATH;
-		}
-	}
+	reset_dun( TRUE );
 
 	x = randm( AREA_MAP_MAX_X );
 	y = randm( AREA_MAP_MAX_Y );
@@ -551,6 +574,12 @@ void	make_dun( void )
 		}
 	}
 
+	/* 饹ܥؤγʤ¤ */
+
+	if( labs( dun.lev ) >= labs( DUN_LEV_LAST_BOSS_STAIRS ) )
+		for( i = 0; i < STAIRS_LAST_BOSS_MAX_N; i++ )
+			make_stairs_randm( FACE_MNR_STAIRS_LAST_BOSS );
+
 	/* ꥢƥ */
 
 	item_n = 0;
@@ -562,7 +591,8 @@ void	make_dun( void )
 
 			dun.map.obj.mjr[y][x] = FACE_MJR_FLOOR;
 			dun.map.obj.mnr[y][x] = FACE_MNR_FLOOR;
-			dun.map.obj.flg[y][x] = FLG_MAP_OBJ_PASS;
+			dun.map.obj.flg[y][x] = (FLG_MAP_OBJ_PASS
+					| FLG_MAP_OBJ_LOOK);
 			if( make_item( x, y, dun.lev )
 					!= ITEM_KIND_NULL ){
 				item_n++;
@@ -579,7 +609,8 @@ void	make_dun( void )
 
 			dun.map.obj.mjr[y][x] = FACE_MJR_FLOOR;
 			dun.map.obj.mnr[y][x] = FACE_MNR_FLOOR;
-			dun.map.obj.flg[y][x] |= FLG_MAP_OBJ_PASS;
+			dun.map.obj.flg[y][x] |= (FLG_MAP_OBJ_PASS
+					| FLG_MAP_OBJ_LOOK);
 			if( rate_randm( MIMIC_RATE ) ){
 				make_mnstr( x, y, TRUE, dun.lev,
 						MNSTR_KIND_MIMIC );
@@ -615,7 +646,8 @@ void	make_dun( void )
 
 			dun.map.obj.mjr[y][x] = FACE_MJR_FLOOR;
 			dun.map.obj.mnr[y][x] = FACE_MNR_FLOOR;
-			dun.map.obj.flg[y][x] |= FLG_MAP_OBJ_PASS;
+			dun.map.obj.flg[y][x] |= (FLG_MAP_OBJ_PASS
+					| FLG_MAP_OBJ_LOOK);
 
 			mnstr_kind = get_mnstr_kind_from_face( mjr, mnr );
 			if( mnstr_kind == MNSTR_KIND_NULL )
@@ -634,7 +666,8 @@ void	make_dun( void )
 
 			dun.map.obj.mjr[y][x] = FACE_MJR_FLOOR;
 			dun.map.obj.mnr[y][x] = FACE_MNR_FLOOR;
-			dun.map.obj.flg[y][x] |= FLG_MAP_OBJ_PASS;
+			dun.map.obj.flg[y][x] |= (FLG_MAP_OBJ_PASS
+					| FLG_MAP_OBJ_LOOK);
 
 			make_trap( x, y, dun.lev );
 		}
@@ -709,8 +742,12 @@ void	make_dun( void )
 		for( j = 0; j < LOOP_MAX_100; j++ ){
 			x = 1 + randm( MAP_MAX_X - 2 );
 			y = 1 + randm( MAP_MAX_Y - 2 );
-			if( dun.map.obj.mjr[y][x] == FACE_MJR_FLOOR )
-				break;
+			if( dun.map.obj.mjr[y][x] != FACE_MJR_FLOOR )
+				continue;
+			if( dun.map.obj.mnr[y][x] != FACE_MNR_FLOOR )
+				continue;
+
+			break;
 		}
 
 		trap = make_trap( x, y, dun.lev );
@@ -734,6 +771,70 @@ void	make_dun( void )
 	end_nest_flg( g_nest_flg_dun );
 }
 
+/***************************************************************
+* 饹ܥγؤ
+***************************************************************/
+
+void	make_dun_last_boss( void )
+{
+	long	x, y;
+	long	i;
+
+	bgn_nest_flg( g_nest_flg_dun );
+
+	/*  */
+
+	reset_dun( TRUE );
+
+	/* ¤ */
+
+	x = AREA_MAP_MAX_X / 2;
+	y = AREA_MAP_MAX_Y - LAST_BOSS_ROOM_PTN_MAX_N;
+	if( y < 0 )
+		y = 0;
+
+	for( i = 0; i < LAST_BOSS_ROOM_PTN_MAX_N; i++ ){
+		make_area_last_boss( &(last_boss_room_ptn[i]),
+				(area_t)1, x, y );
+		y++;
+	}
+
+	/* ޥåפüɤˤ */
+
+	make_fence();
+
+	/* 󥹥 */
+
+	for( y = 0; y < MAP_MAX_Y; y++ ){
+		for( x = 0; x < MAP_MAX_X; x++ ){
+			mnstr_kind_t	mnstr_kind;
+			char	mjr, mnr;
+
+			mjr = dun.map.obj.mjr[y][x];
+			mnr = dun.map.obj.mnr[y][x];
+
+			/* GOD ֤ʤ */
+			if( !isalpha( mjr ) )
+				continue;
+
+			dun.map.obj.mjr[y][x] = FACE_MJR_FLOOR;
+			dun.map.obj.mnr[y][x] = FACE_MNR_FLOOR;
+			dun.map.obj.flg[y][x] |= (FLG_MAP_OBJ_PASS
+					| FLG_MAP_OBJ_LOOK);
+
+			mnstr_kind = get_mnstr_kind_from_face( mjr, mnr );
+			if( mnstr_kind == MNSTR_KIND_NULL )
+				continue;
+
+			make_mnstr( x, y, TRUE, dun.lev, mnstr_kind );
+		}
+	}
+
+	/**/
+
+	end_nest_flg( g_nest_flg_dun );
+}
+
 /***************************************************************
 * µܤγȤɤ
 ***************************************************************/
@@ -748,7 +849,8 @@ void	make_fence( void )
 
 		dun.map.obj.mjr[n][0] = FACE_MJR_WALL;
 		dun.map.obj.mnr[n][0] = FACE_MNR_WALL;
-		dun.map.obj.flg[n][0] &= ~(FLG_MAP_OBJ_PASS);
+		dun.map.obj.flg[n][0] &= ~(FLG_MAP_OBJ_PASS
+				| FLG_MAP_OBJ_LOOK);
 	}
 	for( n = 0; n < MAP_MAX_Y; n++ ){
 		if( dun.map.obj.mnr[n][MAP_MAX_X - 1] == FACE_MNR_GATE )
@@ -756,7 +858,8 @@ void	make_fence( void )
 
 		dun.map.obj.mjr[n][MAP_MAX_X - 1] = FACE_MJR_WALL;
 		dun.map.obj.mnr[n][MAP_MAX_X - 1] = FACE_MNR_WALL;
-		dun.map.obj.flg[n][MAP_MAX_X - 1] &= ~(FLG_MAP_OBJ_PASS);
+		dun.map.obj.flg[n][MAP_MAX_X - 1] &= ~(FLG_MAP_OBJ_PASS
+				| FLG_MAP_OBJ_LOOK);
 	}
 
 	for( n = 0; n < MAP_MAX_X; n++ ){
@@ -765,7 +868,8 @@ void	make_fence( void )
 
 		dun.map.obj.mjr[0][n] = FACE_MJR_WALL;
 		dun.map.obj.mnr[0][n] = FACE_MNR_WALL;
-		dun.map.obj.flg[0][n] &= ~(FLG_MAP_OBJ_PASS);
+		dun.map.obj.flg[0][n] &= ~(FLG_MAP_OBJ_PASS
+				| FLG_MAP_OBJ_LOOK);
 	}
 	for( n = 0; n < MAP_MAX_X; n++ ){
 		if( dun.map.obj.mnr[MAP_MAX_Y - 1][n] == FACE_MNR_GATE )
@@ -773,7 +877,8 @@ void	make_fence( void )
 
 		dun.map.obj.mjr[MAP_MAX_Y - 1][n] = FACE_MJR_WALL;
 		dun.map.obj.mnr[MAP_MAX_Y - 1][n] = FACE_MNR_WALL;
-		dun.map.obj.flg[MAP_MAX_Y - 1][n] &= ~(FLG_MAP_OBJ_PASS);
+		dun.map.obj.flg[MAP_MAX_Y - 1][n] &= ~(FLG_MAP_OBJ_PASS
+				| FLG_MAP_OBJ_LOOK);
 	}
 }
 
@@ -840,6 +945,24 @@ bool_t	make_area_boss( room_ptn_t *ptn, area_t max_n, long x, long y )
 	return TRUE;
 }
 
+/***************************************************************
+* µܤΥ饹ܥ
+* room_ptn_t *ptn : Υѥ
+* area_t max_n : Υѥκ
+* long x : X ɸ
+* long y : Y ɸ
+***************************************************************/
+
+bool_t	make_area_last_boss( room_ptn_t *ptn, area_t max_n, long x, long y )
+{
+	if( dun.area[y][x] != AREA_PATH )
+		return FALSE;
+
+	set_room( ptn, (area_t)0, x, y, FLG_NULL );
+
+	return TRUE;
+}
+
 /***************************************************************
 * µܤγؤܥФ뤫å
 * long dun_lev : µܤγ
@@ -887,29 +1010,59 @@ void	set_room( room_ptn_t *room, area_t n, long x, long y, long flg_rev )
 			mx = x * AREA_MAX_X + jj;
 			my = y * AREA_MAX_Y + ii;
 
+			/* Υѥɤ߹ */
+
 			mjr = room[n].ptn[i][j * 2 + 0];
 			mnr = room[n].ptn[i][j * 2 + 1];
 			sect = room[n].sect[i][j];
 
+			/* Ϸˤ */
+
+			if( mjr == FACE_MJR_NULL ){
+				mjr = FACE_MJR_FLOOR;
+				mnr = FACE_MNR_HOLE;
+			}
+
+			/* Υѥ񤭹 */
+
 			dun.map.obj.mjr[my][mx] = mjr;
 			dun.map.obj.mnr[my][mx] = mnr;
 			dun.map.obj.flg[my][mx] = FLG_NULL;
 			dun.map.sect[my][mx] = sect;
 
+			/* ե饰񤭹 */
+
+			flg = FLG_MAP_OBJ_PASS;
 			switch( mjr ){
 			case FACE_MJR_FLOOR:
+				if( mnr == FACE_MNR_HOLE )
+					flg &= ~(FLG_MAP_OBJ_PASS);
+				else
+					flg |= FLG_MAP_OBJ_PASS;
+				flg |= FLG_MAP_OBJ_LOOK;
+				break;
 			case FACE_MJR_DOOR_OPEN:
-				flg = FLG_MAP_OBJ_PASS;
+				flg |= (FLG_MAP_OBJ_PASS
+						| FLG_MAP_OBJ_LOOK);
 				break;
 			case FACE_MJR_WALL:
 			case FACE_MJR_DOOR_CLOSE:
-				flg = FLG_NULL;
+				flg &= ~(FLG_MAP_OBJ_PASS
+						| FLG_MAP_OBJ_LOOK);
 				break;
 			default:
-				flg = FLG_MAP_OBJ_PASS;
+				flg |= (FLG_MAP_OBJ_PASS
+						| FLG_MAP_OBJ_LOOK);
 			}
 			dun.map.obj.flg[my][mx] = flg;
 
+			/* ޥåס٥Ȥκɸ */
+
+			if( (mjr == FACE_MJR_FLOOR) && isalnum( mnr ) )
+				set_map_event_pos( mnr, mx, my );
+
+			/*  */
+
 			if( flg_light )
 				dun.map.light_depth_obj[my][mx] = 1;
 			else
@@ -943,7 +1096,10 @@ bool_t	chk_lighted_room( void )
 {
 	rate_t	rate;
 
-	rate = 80 - (randm( labs( dun.lev ) ) * 2);
+	if( get_scene() == SCENE_N_LAST_BOSS )
+		return TRUE;
+
+	rate = LIGHTED_ROOM_MAX_RATE - (randm( labs( dun.lev ) ) * 2);
 
 	if( rate <= 0 )
 		return FALSE;
@@ -1486,7 +1642,7 @@ void	make_door_room( long mx, long my )
 	if( dy < 0 )
 		return;
 
-	make_door( mx, my, mx + dx, my + dy, FACE_MNR_NULL );
+	make_door( mx, my, mx + dx, my + dy, dun.map.obj.mnr[my][mx] );
 }
 
 /***************************************************************
@@ -1505,7 +1661,11 @@ door_t	*make_door( long bx, long by, long ex, long ey, char mnr )
 
 	flg = FLG_NULL;
 
-	if( mnr == FACE_MNR_NULL ){
+	if( get_scene() == SCENE_N_LAST_BOSS ){
+		flg |= FLG_DOOR_SECRET;
+		if( mnr == FACE_MNR_GATE )
+			flg |= FLG_DOOR_GATE;
+	} else if( mnr == FACE_MNR_NULL ){
 		if( chk_rate_door_open( dun.lev ) )
 			flg |= FLG_DOOR_OPEN;
 
@@ -1691,7 +1851,7 @@ void	set_face_door( long dr_n )
 
 	if( chk_flg( p->flg, FLG_DOOR_OPEN ) ){
 		mjr = FACE_MJR_DOOR_OPEN;
-		flg |= FLG_MAP_OBJ_PASS;
+		flg |= (FLG_MAP_OBJ_PASS | FLG_MAP_OBJ_LOOK);
 	}
 
 	if( chk_flg( p->flg, FLG_DOOR_JAMMED ) )
@@ -1706,7 +1866,7 @@ void	set_face_door( long dr_n )
 		p->flg |= FLG_DOOR_OPEN;
 		mjr = FACE_MJR_DOOR_OPEN;
 		mnr = FACE_MNR_DOOR_BROKEN;
-		flg |= FLG_MAP_OBJ_PASS;
+		flg |= (FLG_MAP_OBJ_PASS | FLG_MAP_OBJ_LOOK);;
 	}
 
 	if( chk_face_window( p->x, p->y,
@@ -1718,7 +1878,7 @@ void	set_face_door( long dr_n )
 		p->flg &= ~(FLG_DOOR_OPEN);
 		mjr = FACE_MJR_DOOR_CLOSE;
 		mnr = FACE_MNR_DOOR_SECRET;
-		flg &= ~FLG_MAP_OBJ_PASS;
+		flg &= ~(FLG_MAP_OBJ_PASS | FLG_MAP_OBJ_LOOK);
 		flg |= FLG_MAP_OBJ_LOOK_WALL;
 	}
 
@@ -1726,7 +1886,7 @@ void	set_face_door( long dr_n )
 		mjr = FACE_MJR_DOOR_CLOSE;
 		/* mnr  make_door() Ѥ */
 		mnr = p->mnr;
-		flg &= ~FLG_MAP_OBJ_PASS;
+		flg &= ~(FLG_MAP_OBJ_PASS | FLG_MAP_OBJ_LOOK);
 		flg |= FLG_MAP_OBJ_FIND;
 	}
 
@@ -1738,7 +1898,7 @@ void	set_face_door( long dr_n )
 	if( chk_flg( p->flg, FLG_DOOR_GATE ) ){
 		mjr = FACE_MJR_DOOR_CLOSE;
 		mnr = FACE_MNR_GATE;
-		flg &= ~FLG_MAP_OBJ_PASS;
+		flg &= ~(FLG_MAP_OBJ_PASS | FLG_MAP_OBJ_LOOK);
 		flg |= FLG_MAP_OBJ_FIND;
 	}
 
@@ -2026,10 +2186,46 @@ void	make_stairs_randm( char face )
 		x = randm( MAP_MAX_X );
 		y = randm( MAP_MAX_Y );
 
-		if( dun.map.obj.mjr[y][x] == FACE_MJR_FLOOR ){
-			make_stairs( x, y, face );
-			break;
-		}
+		if( dun.map.obj.mjr[y][x] != FACE_MJR_FLOOR )
+			continue;
+		if( dun.map.obj.mnr[y][x] != FACE_MNR_FLOOR )
+			continue;
+
+		make_stairs( x, y, face );
+		break;
+	}
+}
+
+/***************************************************************
+* 濴κɸꤷơõƤ鳬ʤ
+* long x : X ɸ
+* long y : Y ɸ
+* char face : ʤμδʸ
+***************************************************************/
+
+void	make_stairs( long x, long y, char face )
+{
+	const long	max_r = MAP_MAX_X;
+	long	r;
+
+	for( r = 0; r < max_r; r++ ){
+		long	dx, dy;
+
+		for( dx = -r, dy = -r; dx <= +r; dx++ )
+			if( make_stairs_sub( x + dx, y + dy, face ) )
+				return;
+
+		for( dx = +r, dy = -r; dy <= +r; dy++ )
+			if( make_stairs_sub( x + dx, y + dy, face ) )
+				return;
+
+		for( dx = +r, dy = +r; dx >= -r; dx-- )
+			if( make_stairs_sub( x + dx, y + dy, face ) )
+				return;
+
+		for( dx = -r, dy = +r; dy >= -r; dy-- )
+			if( make_stairs_sub( x + dx, y + dy, face ) )
+				return;
 	}
 }
 
@@ -2038,25 +2234,33 @@ void	make_stairs_randm( char face )
 * long x : X ɸ
 * long y : Y ɸ
 * char face : ʤμδʸ
+* return : 顼̵ä?
 ***************************************************************/
 
-void	make_stairs( long x, long y, char face )
+bool_t	make_stairs_sub( long x, long y, char face )
 {
 	char	mjr, mnr;
 
+	if( !clip_pos( x, y ) )
+		return FALSE;
 	if( dun.map.obj.mjr[y][x] != FACE_MJR_FLOOR )
-		return;
+		return FALSE;
+	if( dun.map.obj.mnr[y][x] != FACE_MNR_FLOOR )
+		return FALSE;
 
-	if( (face == FACE_MJR_STAIRS_DOWN)
+	if( face == FACE_MNR_STAIRS_LAST_BOSS ){
+		mjr = FACE_MJR_STAIRS_LAST_BOSS;
+		mnr = FACE_MNR_STAIRS_LAST_BOSS;
+	} else if( (face == FACE_MJR_STAIRS_DOWN)
 			|| (face == FACE_MNR_STAIRS_DOWN) ){
 		if( labs( dun.lev ) >= labs( DUN_MAX_LEV_BASE ) )
-			return;
+			return TRUE;
 
 		mjr = FACE_MJR_STAIRS_DOWN;
 		mnr = FACE_MNR_STAIRS_DOWN;
 	} else {
 		if( labs( dun.lev ) >= labs( DUN_MAX_LEV_FLOOR ) )
-			return;
+			return TRUE;
 
 		mjr = FACE_MJR_STAIRS_UP;
 		mnr = FACE_MNR_STAIRS_UP;
@@ -2064,6 +2268,8 @@ void	make_stairs( long x, long y, char face )
 
 	dun.map.obj.mjr[y][x] = mjr;
 	dun.map.obj.mnr[y][x] = mnr;
+
+	return TRUE;
 }
 
 /***************************************************************
@@ -2081,6 +2287,8 @@ bool_t	set_statue( long x, long y, long dun_lev, bool_t flg_self )
 
 	if( dun.map.obj.mjr[y][x] != FACE_MJR_FLOOR )
 		return FALSE;
+	if( dun.map.obj.mnr[y][x] != FACE_MNR_FLOOR )
+		return FALSE;
 	if( !flg_self && (dun.map.chr.mjr[y][x] != FACE_MJR_NULL) )
 		return FALSE;
 
@@ -2111,6 +2319,8 @@ void	set_map_total( long x, long y, long dx, long dy )
 	crsr_ptn_t	*sub_ptn = get_sub_crsr_ptn();
 
 	/* ط */
+	set_map_total_water( x, y, dx, dy );
+	set_map_total_last_boss_bg( x, y, dx, dy );
 	set_map_total_bg( x, y, dx, dy );
 
 	/* ° */
@@ -2125,12 +2335,69 @@ void	set_map_total( long x, long y, long dx, long dy )
 
 	/* 󥹥ȥС */
 	set_map_total_chr( x, y, dx, dy );
+	set_map_total_last_boss_fg( x, y, dx, dy );
 
 	/* Υѥ */
 	set_map_total_crsr_ptn( sub_crsr, sub_ptn, x, y, dx, dy );
 	set_map_total_crsr_ptn( crsr, ptn, x, y, dx, dy );
 }
 
+/***************************************************************
+* طʥޥåפοϷ쥤䡼򹹿
+* long x : X ɸ
+* long y : Y ɸ
+* long dx : 
+* long dy : ⤵
+***************************************************************/
+
+void	set_map_total_water( long x, long y, long dx, long dy )
+{
+	long	bx, by;
+	long	ex, ey;
+	long	xx, yy;
+	char	mjr, mnr;
+	curs_attr_n_t	attr_n_water, attr_n_lava;
+	curs_attr_t	*attr_dflt;
+
+	attr_n_water = CURS_ATTR_N_MAP_NORMAL;
+	attr_n_lava = CURS_ATTR_N_MAP_MNSTR;
+	attr_dflt = get_curs_attr();
+
+	bx = x;
+	by = y;
+	ex = x + dx - 1;
+	ey = y + dy - 1;
+	if( bx < 0 )
+		bx = 0;
+	if( by < 0 )
+		by = 0;
+	if( ex > MAP_MAX_X - 1 )
+		ex = MAP_MAX_X - 1;
+	if( ey > MAP_MAX_Y - 1 )
+		ey = MAP_MAX_Y - 1;
+
+	for( yy = by; yy <= ey; yy++ ){
+		for( xx = bx; xx <= ex; xx++ ){
+			set_face_from_map_obj(
+					TRUE, xx, yy, &mjr, &mnr,
+					FALSE );
+			if( mjr != FACE_MJR_WATER )
+				continue;
+
+			dun.map.total.mjr[yy][xx] = mjr;
+			dun.map.total.mnr[yy][xx] = mnr;
+			dun.map.total.flg[yy][xx] = FLG_NULL;
+			if( mnr == FACE_MNR_LAVA ){
+				dun.map.attr[yy][xx] = attr_dflt
+						[attr_n_lava];
+			} else {
+				dun.map.attr[yy][xx] = attr_dflt
+						[attr_n_water];
+			}
+		}
+	}
+}
+
 /***************************************************************
 * طʥޥåפ쥤䡼򹹿
 * long x : X ɸ
@@ -2141,7 +2408,8 @@ void	set_map_total( long x, long y, long dx, long dy )
 
 void	set_map_total_bg( long x, long y, long dx, long dy )
 {
-	long	i, j;
+	long	bx, by;
+	long	ex, ey;
 	long	xx, yy;
 	char	mjr, mnr;
 	curs_attr_n_t	attr_n;
@@ -2150,18 +2418,27 @@ void	set_map_total_bg( long x, long y, long dx, long dy )
 	attr_n = CURS_ATTR_N_MAP_NORMAL;
 	attr_dflt = get_curs_attr();
 
-	for( i = 0; i < dy; i++ ){
-		yy = y + i;
-		if( !clip_y( yy ) )
-			continue;
+	bx = x;
+	by = y;
+	ex = x + dx - 1;
+	ey = y + dy - 1;
+	if( bx < 0 )
+		bx = 0;
+	if( by < 0 )
+		by = 0;
+	if( ex > MAP_MAX_X - 1 )
+		ex = MAP_MAX_X - 1;
+	if( ey > MAP_MAX_Y - 1 )
+		ey = MAP_MAX_Y - 1;
 
-		for( j = 0; j < dx; j++ ){
-			xx = x + j;
-			if( !clip_x( xx ) )
+	for( yy = by; yy <= ey; yy++ ){
+		for( xx = bx; xx <= ex; xx++ ){
+			set_face_from_map_obj(
+					TRUE, xx, yy, &mjr, &mnr,
+					FALSE );
+			if( mjr == FACE_MJR_WATER )
 				continue;
 
-			set_face_from_map_obj( TRUE, xx, yy, &mjr, &mnr );
-
 			dun.map.total.mjr[yy][xx] = mjr;
 			dun.map.total.mnr[yy][xx] = mnr;
 			dun.map.total.flg[yy][xx] = FLG_NULL;
@@ -2172,6 +2449,7 @@ void	set_map_total_bg( long x, long y, long dx, long dy )
 
 /***************************************************************
 * طʥޥåפθδʸ֤
+* bool_t flg_chk_find : ĤäƤ뤫å뤫?
 * long x : X ɸ
 * long y : Y ɸ
 * char *mjr : ᥸㡼δʸ֤
@@ -2179,51 +2457,52 @@ void	set_map_total_bg( long x, long y, long dx, long dy )
 ***************************************************************/
 
 void	set_face_from_map_obj(
-	bool_t flg_chk_find, long x, long y, char *mjr, char *mnr
+	bool_t flg_chk_find,
+	long x, long y, char *mjr, char *mnr,
+	bool_t flg_gui
 )
 {
 	flg_map_t	flg;
 	long	dep;
 
-	if( mjr != NULL )
-		*mjr = FACE_MJR_NULL;
-	if( mnr != NULL )
-		*mnr = FACE_MNR_NULL;
-
+	if( mjr == NULL )
+		return;
+	if( mnr == NULL )
+		return;
 	if( !clip_pos( x, y ) )
 		return;
 
-	if( mjr != NULL )
-		*mjr = dun.map.obj.mjr[y][x];
-	if( mnr != NULL )
-		*mnr = dun.map.obj.mnr[y][x];
+	*mjr = dun.map.obj.mjr[y][x];
+	*mnr = dun.map.obj.mnr[y][x];
 	flg = dun.map.obj.flg[y][x];
 	dep = calc_light_depth( x, y );
 
+	if( (*mjr == FACE_MJR_FLOOR) && (*mnr == FACE_MNR_HOLE) ){
+		if( !flg_gui ){
+			*mjr = FACE_MJR_NULL;
+			*mnr = FACE_MNR_NULL;
+		}
+	}
 	if( chk_flg( flg, FLG_MAP_OBJ_LOOK_WALL ) ){
-		if( mjr != NULL )
-			*mjr = FACE_MJR_WALL;
-		if( mnr != NULL )
-			*mnr = FACE_MNR_WALL;
+		*mjr = FACE_MJR_WALL;
+		*mnr = FACE_MNR_WALL;
 	}
 	if( chk_flg( flg, FLG_MAP_OBJ_LOOK_FLOOR ) ){
-		if( mjr != NULL )
-			*mjr = FACE_MJR_FLOOR;
-		if( mnr != NULL )
-			*mnr = FACE_MNR_FLOOR;
+		*mjr = FACE_MJR_FLOOR;
+		*mnr = FACE_MNR_FLOOR;
 	}
+
+	if( (*mjr == FACE_MJR_FLOOR) && isalnum( *mnr ) )
+		*mnr = FACE_MNR_NULL;
+
 	if( flg_chk_find ){
 		if( (*mjr == FACE_MJR_FLOOR) && (dep <= 0) ){
-			if( mjr != NULL )
-				*mjr = FACE_MJR_NULL;
-			if( mnr != NULL )
-				*mnr = FACE_MNR_NULL;
+			*mjr = FACE_MJR_NULL;
+			*mnr = FACE_MNR_NULL;
 		}
 		if( !chk_flg( flg, FLG_MAP_OBJ_FIND ) ){
-			if( mjr != NULL )
-				*mjr = FACE_MJR_NULL;
-			if( mnr != NULL )
-				*mnr = FACE_MNR_NULL;
+			*mjr = FACE_MJR_NULL;
+			*mnr = FACE_MNR_NULL;
 		}
 	}
 }
@@ -2252,17 +2531,26 @@ void	set_map_total_crsr_attr(
 	if( !clip_pos( crsr->x, crsr->y ) )
 		return;
 
+	if( (crsr->x + ptn->x + ptn->x_len - 1) < x )
+		return;
+	if( (crsr->y + ptn->y + ptn->y_len - 1) < y )
+		return;
+	if( (crsr->x + ptn->x) > (x + dx - 1) )
+		return;
+	if( (crsr->y + ptn->y) > (y + dy - 1) )
+		return;
+
 	attr_dflt = get_curs_attr();
 	attr_n = CURS_ATTR_N_MAP_CRSR;
 	for( i = 0; i < ptn->y_len; i++ ){
-		yy = crsr->y + i + ptn->y;
+		yy = crsr->y + ptn->y + i;
 		if( !clip_y( yy ) )
 			continue;
 
 		for( j = 0; j < ptn->x_len; j++ ){
 			long	c;
 
-			xx = crsr->x + j + ptn->x;
+			xx = crsr->x + ptn->x + j;
 			if( !clip_x( xx ) )
 				continue;
 
@@ -2320,6 +2608,8 @@ void	set_map_total_obj( long x, long y, long dx, long dy )
 				continue;
 			if( mjr == FACE_MJR_WALL )
 				continue;
+			if( mjr == FACE_MJR_WATER )
+				continue;
 			if( chk_flg( flg, FLG_MAP_OBJ_LOOK_WALL ) )
 				continue;
 			if( chk_flg( flg, FLG_MAP_OBJ_LOOK_FLOOR ) )
@@ -2362,11 +2652,20 @@ void	set_map_total_square( long x, long y, long dx, long dy )
 	curs_attr_t	*attr_dflt;
 	party_t	*pty;
 
-	attr_dflt = get_curs_attr();
 	pty = get_party();
 
 	if( !clip_pos( pty->square.x, pty->square.y ) )
 		return;
+	if( (pty->square.x + 1) < x )
+		return;
+	if( (pty->square.y + 1) < y )
+		return;
+	if( (pty->square.x - 1) > (x + dx - 1) )
+		return;
+	if( (pty->square.y - 1) > (y + dy - 1) )
+		return;
+
+	attr_dflt = get_curs_attr();
 
 	for( i = -1; i <= +1; i++ ){
 		yy = pty->square.y + i;
@@ -2407,77 +2706,102 @@ void	set_map_total_square( long x, long y, long dx, long dy )
 
 void	set_map_total_chr( long x, long y, long dx, long dy )
 {
-	long	i, j;
+	long	bx, by;
+	long	ex, ey;
 	long	xx, yy;
+	curs_attr_t	*attr_dflt;
+
+	attr_dflt = get_curs_attr();
+
+	bx = x;
+	by = y;
+	ex = x + dx - 1;
+	ey = y + dy - 1;
+	if( bx < 0 )
+		bx = 0;
+	if( by < 0 )
+		by = 0;
+	if( ex > MAP_MAX_X - 1 )
+		ex = MAP_MAX_X - 1;
+	if( ey > MAP_MAX_Y - 1 )
+		ey = MAP_MAX_Y - 1;
+
+	for( yy = by; yy <= ey; yy++ ){
+		for( xx = bx; xx <= ex; xx++ ){
+			set_map_total_chr_1( xx, yy );
+		}
+	}
+}
+
+/***************************************************************
+* 󥹥ȥСΥޥåפ쥤䡼򹹿 (1 )
+* long x : X ɸ
+* long y : Y ɸ
+***************************************************************/
+
+void	set_map_total_chr_1( long x, long y )
+{
 	char	mjr, mnr;
 	flg_map_t	flg, flg_total;
+	bool_t	flg_rev_rev;
 	chr_t	*chr_p;
 	curs_attr_n_t	attr_n;
 	curs_attr_t	*attr_dflt;
 
 	attr_dflt = get_curs_attr();
 
-	for( i = 0; i < dy; i++ ){
-		yy = y + i;
-		if( !clip_y( yy ) )
-			continue;
-		for( j = 0; j < dx; j++ ){
-			bool_t	flg_rev_rev;
+	flg_total = dun.map.total.flg[y][x];
 
-			xx = x + j;
-			if( !clip_x( xx ) )
-				continue;
+	mjr = dun.map.chr.mjr[y][x];
+	mnr = dun.map.chr.mnr[y][x];
+	flg = dun.map.chr.flg[y][x];
+	chr_p = dun.map.chr_p[y][x];
+	attr_n = CURS_ATTR_N_NORMAL;
+	flg_rev_rev = FALSE;
 
-			flg_total = dun.map.total.flg[yy][xx];
+	if( mjr == FACE_MJR_NULL ){
+		return;
+	} else if( chr_p == NULL ){
+		return;
+	} else if( is_mbr( chr_p ) ){
+		mbr_t	*p;
 
-			mjr = dun.map.chr.mjr[yy][xx];
-			mnr = dun.map.chr.mnr[yy][xx];
-			flg = dun.map.chr.flg[yy][xx];
-			chr_p = dun.map.chr_p[yy][xx];
-			attr_n = CURS_ATTR_N_NORMAL;
-			flg_rev_rev = FALSE;
+		/* Сä */
 
-			if( mjr == FACE_MJR_NULL ){
-				continue;
-			} else if( chr_p == NULL ){
-				continue;
-			} else if( is_mbr( chr_p ) ){
-				mbr_t	*p;
-
-				/* Сä */
-				p = get_mbr( xx, yy );
-				if( p != NULL ){
-					attr_n = (curs_attr_n_t)
-							(CURS_ATTR_N_MBR_1
-							+ p->mbr_n);
-				}
-				if( chk_flg( flg, FLG_MAP_CHR_INVISIBLE ) ){
-					/* Ʃʤ */
-					flg_rev_rev = TRUE;
-				}
-			} else if( chr_p->kind == CHR_KIND_MNSTR ){
-				/* 󥹥ä */
-				if( !chk_flg( flg, FLG_MAP_CHR_FIND ) ){
-					/* ĤäƤʤ */
-					continue;
-				}
-				if( chk_flg( flg, FLG_MAP_CHR_NPC ) ){
-					attr_n = CURS_ATTR_N_MAP_NPC;
-				} else {
-					attr_n = CURS_ATTR_N_MAP_MNSTR;
-				}
-			} else {
-				continue;
-			}
-
-			dun.map.total.mjr[yy][xx] = mjr;
-			dun.map.total.mnr[yy][xx] = mnr;
-			dun.map.total.flg[yy][xx] = flg_total;
-			dun.map.attr[yy][xx] = attr_dflt[attr_n];
-			if( flg_rev_rev )
-				dun.map.attr[yy][xx].attr ^= A_REVERSE;
+		p = get_mbr( x, y );
+		if( p != NULL ){
+			attr_n = (curs_attr_n_t)
+					(CURS_ATTR_N_MBR_1 + p->mbr_n);
 		}
+		/* Ʃʤ */
+		if( chk_flg( flg, FLG_MAP_CHR_INVISIBLE ) ){
+			flg_rev_rev = TRUE;
+		}
+	} else if( chr_p->kind == CHR_KIND_MNSTR ){
+		/* 󥹥ä */
+
+		/* ĤäƤʤ */
+		if( !chk_flg( flg, FLG_MAP_CHR_FIND ) )
+			return;
+		/* Ʃʤ */
+		if( chk_flg( flg, FLG_MAP_CHR_INVISIBLE ) )
+			return;
+
+		if( chk_flg( flg, FLG_MAP_CHR_NPC ) ){
+			attr_n = CURS_ATTR_N_MAP_NPC;
+		} else {
+			attr_n = CURS_ATTR_N_MAP_MNSTR;
+		}
+	} else {
+		return;
 	}
+
+	dun.map.total.mjr[y][x] = mjr;
+	dun.map.total.mnr[y][x] = mnr;
+	dun.map.total.flg[y][x] = flg_total;
+	dun.map.attr[y][x] = attr_dflt[attr_n];
+	if( flg_rev_rev )
+		dun.map.attr[y][x].attr ^= A_REVERSE;
 }
 
 /***************************************************************
@@ -2503,15 +2827,24 @@ void	set_map_total_crsr_ptn(
 	if( !clip_pos( crsr->x, crsr->y ) )
 		return;
 
+	if( (crsr->x + ptn->x + ptn->x_len - 1) < x )
+		return;
+	if( (crsr->y + ptn->y + ptn->y_len - 1) < y )
+		return;
+	if( (crsr->x + ptn->x) > (x + dx - 1) )
+		return;
+	if( (crsr->y + ptn->y) > (y + dy - 1) )
+		return;
+
 	for( i = 0; i < ptn->y_len; i++ ){
-		yy = crsr->y + i + ptn->y;
+		yy = crsr->y + ptn->y + i;
 		if( !clip_y( yy ) )
 			continue;
 
 		for( j = 0; j < ptn->x_len; j++ ){
 			long	c;
 
-			xx = crsr->x + j + ptn->x;
+			xx = crsr->x + ptn->x + j;
 			if( !clip_x( xx ) )
 				continue;
 
@@ -2613,7 +2946,8 @@ void	put_path( long x, long y, long dx, long dy, sect_t sect )
 
 			dun.map.obj.mjr[yy][xx] = FACE_MJR_FLOOR;
 			dun.map.obj.mnr[yy][xx] = FACE_MNR_FLOOR;
-			dun.map.obj.flg[yy][xx] |= FLG_MAP_OBJ_PASS;
+			dun.map.obj.flg[yy][xx] |= (FLG_MAP_OBJ_PASS
+					| FLG_MAP_OBJ_LOOK);
 		}
 	}
 }
@@ -2874,8 +3208,9 @@ void	find_obj_fill( long x, long y )
 			if( dun.map.sect[sy][sx] != sect )
 				continue;
 			if( !chk_flg( dun.map.obj.flg[sy][sx],
-					FLG_MAP_OBJ_PASS ) )
+					FLG_MAP_OBJ_LOOK ) ){
 				continue;
+			}
 
 			find_obj_fill_field( sx, sy );
 		}
@@ -2992,7 +3327,7 @@ void	turn_light_field(
 				continue;
 
 			if( !chk_flg( dun.map.obj.flg[sy][sx],
-					FLG_MAP_OBJ_PASS ) )
+					FLG_MAP_OBJ_LOOK ) )
 				continue;
 
 			if( chk_flg( dun.map.obj.flg[sy][sx],
@@ -3128,10 +3463,8 @@ bool_t	chk_find( pos_t *pos1, pos_t *pos2 )
 
 	for( ; x <= x2; x++ ){
 		if( e < 0 ){
-			if( !chk_flg( dun.map.obj.flg[y][x],
-					FLG_MAP_OBJ_PASS ) ){
+			if( !chk_find_pos( x, y ) )
 				return FALSE;
-			}
 		} else {
 			do {
 				y += sgn_y;
@@ -3143,10 +3476,8 @@ bool_t	chk_find( pos_t *pos1, pos_t *pos2 )
 						break;
 				}
 				e -= dx2;
-				if( !chk_flg( dun.map.obj.flg[y][x],
-						FLG_MAP_OBJ_PASS ) ){
+				if( !chk_find_pos( x, y ) )
 					return FALSE;
-				}
 			} while( e >= 0 );
 		}
 		e += dy2;
@@ -3155,6 +3486,24 @@ bool_t	chk_find( pos_t *pos1, pos_t *pos2 )
 	return TRUE;
 }
 
+/***************************************************************
+* ̤뤫ʸ뤫Ĵ٤
+* long x : X ɸ
+* long y : Y ɸ
+* return : ̤뤫?
+***************************************************************/
+
+bool_t	chk_find_pos( long x, long y )
+{
+	if( !clip_pos( x, y ) )
+		return FALSE;
+
+	if( chk_flg( dun.map.obj.flg[y][x], FLG_MAP_OBJ_LOOK ) )
+		return TRUE;
+
+	return FALSE;
+}
+
 /***************************************************************
 * µܤΥǡ֤
 * return : µܤΥǡ
@@ -3585,6 +3934,33 @@ bool_t	down_stairs( void )
 	return TRUE;
 }
 
+/***************************************************************
+* 饹ܥؤγʤ򲼤
+* return : 줿?
+***************************************************************/
+
+bool_t	down_stairs_last_boss( void )
+{
+	if( !chk_party_no_mbr( FALSE ) )
+		return FALSE;
+
+	if( !chk_stairs( FACE_MNR_STAIRS_LAST_BOSS ) ){
+		print_msg( FLG_NULL, MSG_ERR_STAIRS_DOWN );
+		return FALSE;
+	}
+
+	if( !chk_enter_last_stage() ){
+		print_msg( FLG_NULL, MSG_ERR_STAIRS_DOWN_LAST_BOSS_1 );
+		print_msg( FLG_NULL, MSG_ERR_STAIRS_DOWN_LAST_BOSS_2 );
+		return FALSE;
+	}
+
+	print_msg( FLG_NULL, MSG_DOWN_DUN );
+	enter_last_boss_dun();
+
+	return TRUE;
+}
+
 /***************************************************************
 * ʤ겼뤫Ĵ٤
 * long face : ʤμδʸ
@@ -3593,16 +3969,22 @@ bool_t	down_stairs( void )
 
 bool_t	chk_stairs( long face )
 {
+	char	mjr, mnr;
 	party_t	*pty;
 	bool_t	flg;
 	long	i;
 	long	x, y;
 
-	if( (face == FACE_MJR_STAIRS_DOWN)
+	if( face == FACE_MNR_STAIRS_LAST_BOSS ){
+		mjr = FACE_MJR_STAIRS_LAST_BOSS;
+		mnr = FACE_MNR_STAIRS_LAST_BOSS;
+	} else if( (face == FACE_MJR_STAIRS_DOWN)
 			|| (face == FACE_MNR_STAIRS_DOWN) ){
-		face = FACE_MJR_STAIRS_DOWN;
+		mjr = FACE_MJR_STAIRS_DOWN;
+		mnr = FACE_MNR_STAIRS_DOWN;
 	} else {
-		face = FACE_MJR_STAIRS_UP;
+		mjr = FACE_MJR_STAIRS_UP;
+		mnr = FACE_MNR_STAIRS_UP;
 	}
 
 	pty = get_party();
@@ -3620,9 +4002,13 @@ bool_t	chk_stairs( long face )
 
 				mx = pty->mbr[i]->x + x;
 				my = pty->mbr[i]->y + y;
-				if( dun.map.obj.mjr[my][mx] == face ){
-					flg = TRUE;
-				}
+				if( dun.map.obj.mjr[my][mx] != mjr )
+					continue;
+				if( dun.map.obj.mnr[my][mx] != mnr )
+					continue;
+
+				flg = TRUE;
+				break;
 			}
 		}
 		if( !flg )
@@ -3632,6 +4018,24 @@ bool_t	chk_stairs( long face )
 	return TRUE;
 }
 
+/***************************************************************
+* ޥåפ򥹥
+* long x :  x ɸ
+* long y :  y ɸ
+***************************************************************/
+
+void	scroll_map( long x, long y )
+{
+	pos_t	*draw;
+
+	draw = get_map_draw_pos();
+	draw->x = x;
+	draw->y = y;
+
+	chk_scroll( TRUE );
+	redraw_map();
+}
+
 /***************************************************************
 * ʸꤷƥޥåפ򸡺
 * char face_mjr : ᥸㡼δʸ
@@ -3913,15 +4317,21 @@ char	get_chr_mnr_crsr( void )
 
 char	get_chr_crsr( bool_t flg_mjr )
 {
+	char	face;
 	pos_t	*crsr = get_crsr();
 
+	if( flg_mjr )
+		face = FACE_MJR_NULL;
+	else
+		face = FACE_MNR_NULL;
+
 	if( crsr == NULL )
-		return FACE_MJR_NULL;
+		return face;
 
 	if( !clip_x( crsr->x ) )
-		return FACE_MJR_NULL;
+		return face;
 	if( !clip_y( crsr->y ) )
-		return FACE_MJR_NULL;
+		return face;
 
 	if( flg_mjr )
 		return( dun.map.chr.mjr[crsr->y][crsr->x] );
@@ -3953,4 +4363,3 @@ bool_t	save_dun( void )
 
 	return TRUE;
 }
-
