@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: dun.h,v 1.45 2008/10/03 11:11:16 bowkenken Exp $
+* $Id: dun.h,v 1.52 2009/02/24 09:52:41 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	DUN_H
@@ -95,6 +95,7 @@ typedef unsigned long	flg_map_t;
 
 #define	FLG_MAP_OBJ_FIND	(1 << 0)	/* ȯ */
 #define	FLG_MAP_OBJ_PASS	(1 << 1)	/* ̹Բ */
+#define	FLG_MAP_OBJ_LOOK	(1 << 2)	/* ̤ */
 #define	FLG_MAP_OBJ_LOOK_FLOOR	(1 << 4)	/* ˸ */
 #define	FLG_MAP_OBJ_LOOK_WALL	(1 << 5)	/* ɤ˸ */
 
@@ -122,11 +123,22 @@ typedef unsigned long	flg_map_t;
 #define	FACE_MNR_WALL	'#'
 #define	FACE_MNR_STATUE	'@'
 #define	FACE_MNR_STREETLAMP	'*'
+#define	FACE_MNR_BOOT_UNIT	'&'
 
 #define	FACE_MJR_FLOOR	'.'
 #define	FACE_MNR_FLOOR	' '
 #define	FACE_MNR_HOLE	'^'
 
+#define	FACE_MJR_WATER	'~'
+#define	FACE_MNR_PUDDLE	'.'
+#define	FACE_MNR_SHALLOWS	' '
+#define	FACE_MNR_OFFING	'~'
+#define	FACE_MNR_LAVA	'^'
+
+#define	FACE_MJR_MOUNTAIN	'/'
+#define	FACE_MNR_MOUNTAIN	'\\'
+#define	FACE_MNR_HILL	')'
+
 #define	FACE_MJR_ITEM	'$'
 
 #define	FACE_MJR_DOOR_CLOSE	'+'
@@ -245,6 +257,9 @@ typedef struct {
 	map_t	chr;
 	/* 쥤䡼 */
 	map_t	total;
+	/* VFX Υ쥤䡼 */
+	char	vfx[MAP_MAX_Y][MAP_MAX_X * 2];
+
 	/*  */
 	sect_t	sect[MAP_MAX_Y][MAP_MAX_X];
 
@@ -258,6 +273,8 @@ typedef struct {
 
 	/* ɽ° */
 	curs_attr_t	attr[MAP_MAX_Y][MAP_MAX_X];
+	/* VFX° */
+	curs_attr_t	attr_vfx[MAP_MAX_Y][MAP_MAX_X * 2];
 } all_map_t;
 
 /***************************************************************
