@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: inc.h,v 1.109 2008/10/07 10:27:00 bowkenken Exp $
+* $Id: inc.h,v 1.136 2009/05/12 04:08:02 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	INC_H
@@ -47,6 +47,7 @@
 #include	"item.h"
 /*#include	"spell.h"*/
 /*#include	"chr.h"*/
+/*#include	"skill.h"*/
 /*#include	"party.h"*/
 /*#include	"mnstr.h"*/
 /*#include	"pet.h"*/
@@ -72,6 +73,7 @@
 #include	"item-prot.h"
 /*#include	"spell-prot.h"*/
 #include	"chr-prot.h"
+/*#include	"skill-prot.h"*/
 #include	"party-prot.h"
 #include	"mnstr-prot.h"
 /*#include	"pet-prot.h"*/
@@ -106,6 +108,7 @@
 #include	"item.h"
 #include	"spell.h"
 #include	"chr.h"
+#include	"skill.h"
 #include	"party.h"
 #include	"mnstr.h"
 #include	"pet.h"
@@ -131,6 +134,7 @@
 #include	"item-prot.h"
 #include	"spell-prot.h"
 #include	"chr-prot.h"
+#include	"skill-prot.h"
 #include	"party-prot.h"
 #include	"mnstr-prot.h"
 #include	"pet-prot.h"
@@ -152,6 +156,7 @@
 #include	"last-boss.h"
 #include	"last-boss-prot.h"
 
+#include	"sound-kind.h"
 #include	"win-kind.h"
 #include	"call-prot.h"
 
@@ -159,6 +164,67 @@
 
 /***************************************************************/
 
+#ifdef	SKILL_C
+
+#include	"gmain.h"
+#include	"misc.h"
+/*#include	"scene.h"*/
+/*#include	"turn.h"*/
+#include	"dun.h"
+/*#include	"map-event.h"*/
+/*#include	"town.h"*/
+#include	"item.h"
+/*#include	"spell.h"*/
+#include	"chr.h"
+#include	"skill.h"
+#include	"party.h"
+#include	"mnstr.h"
+#include	"pet.h"
+/*#include	"fight.h"*/
+/*#include	"fx.h"*/
+#include	"trap.h"
+/*#include	"replay.h"*/
+#include	"draw.h"
+/*#include	"curs.h"*/
+/*#include	"menu.h"*/
+/*#include	"amenu.h"*/
+/*#include	"request.h"*/
+/*#include	"gfile.h"*/
+/*#include	"msg.h"*/
+/*#include	"ver.h"*/
+/*#include	"gmain-prot.h"*/
+#include	"misc-prot.h"
+/*#include	"scene-prot.h"*/
+/*#include	"turn-prot.h"*/
+#include	"dun-prot.h"
+/*#include	"map-event-prot.h"*/
+/*#include	"town-prot.h"*/
+/*#include	"item-prot.h"*/
+/*#include	"spell-prot.h"*/
+#include	"chr-prot.h"
+#include	"skill-prot.h"
+#include	"party-prot.h"
+/*#include	"mnstr-prot.h"*/
+/*#include	"pet-prot.h"*/
+/*#include	"fight-prot.h"*/
+/*#include	"fx-prot.h"*/
+/*#include	"trap-prot.h"*/
+/*#include	"replay-prot.h"*/
+#include	"draw-prot.h"
+/*#include	"curs-prot.h"*/
+/*#include	"menu-prot.h"*/
+/*#include	"mmenu-prot.h"*/
+/*#include	"imenu-prot.h"*/
+/*#include	"tmenu-prot.h"*/
+/*#include	"amenu-prot.h"*/
+/*#include	"request-prot.h"*/
+/*#include	"gfile-prot.h"*/
+/*#include	"msg-prot.h"*/
+
+#endif	/* SKILL_C */
+
+/***************************************************************/
+
 #ifdef	CURS_C
 
 #include	"gmain.h"
@@ -171,6 +237,7 @@
 /*#include	"item.h"*/
 /*#include	"spell.h"*/
 /*#include	"chr.h"*/
+/*#include	"skill.h"*/
 /*#include	"party.h"*/
 /*#include	"mnstr.h"*/
 /*#include	"pet.h"*/
@@ -196,6 +263,7 @@
 /*#include	"item-prot.h"*/
 /*#include	"spell-prot.h"*/
 /*#include	"chr-prot.h"*/
+/*#include	"skill-prot.h"*/
 /*#include	"party-prot.h"*/
 /*#include	"mnstr-prot.h"*/
 /*#include	"pet-prot.h"*/
@@ -243,6 +311,7 @@
 /*#include	"item.h"*/
 /*#include	"spell.h"*/
 /*#include	"chr.h"*/
+/*#include	"skill.h"*/
 /*#include	"party.h"*/
 /*#include	"mnstr.h"*/
 /*#include	"pet.h"*/
@@ -268,6 +337,7 @@
 /*#include	"item-prot.h"*/
 /*#include	"spell-prot.h"*/
 /*#include	"chr-prot.h"*/
+/*#include	"skill-prot.h"*/
 /*#include	"party-prot.h"*/
 /*#include	"mnstr-prot.h"*/
 /*#include	"pet-prot.h"*/
@@ -296,7 +366,7 @@
 
 #include	"gmain.h"
 /*#include	"misc.h"*/
-/*#include	"scene.h"*/
+#include	"scene.h"
 /*#include	"turn.h"*/
 /*#include	"dun.h"*/
 /*#include	"map-event.h"*/
@@ -304,6 +374,7 @@
 #include	"item.h"
 #include	"spell.h"
 /*#include	"chr.h"*/
+#include	"skill.h"
 /*#include	"party.h"*/
 /*#include	"mnstr.h"*/
 #include	"pet.h"
@@ -321,7 +392,7 @@
 /*#include	"ver.h"*/
 #include	"gmain-prot.h"
 #include	"misc-prot.h"
-/*#include	"scene-prot.h"*/
+#include	"scene-prot.h"
 #include	"turn-prot.h"
 #include	"dun-prot.h"
 /*#include	"map-event-prot.h"*/
@@ -329,6 +400,7 @@
 #include	"item-prot.h"
 #include	"spell-prot.h"
 #include	"chr-prot.h"
+#include	"skill-prot.h"
 #include	"party-prot.h"
 #include	"mnstr-prot.h"
 #include	"pet-prot.h"
@@ -347,11 +419,11 @@
 #include	"gfile-prot.h"
 #include	"msg-prot.h"
 
+#include	"vfx-kind.h"
+#include	"sound-kind.h"
 #include	"win-kind.h"
 #include	"call-prot.h"
 
-#include	"vfx-kind.h"
-
 # ifdef	D_X68K
 #  include	<doslib.h>
 # endif
@@ -376,6 +448,7 @@
 #include	"item.h"
 #include	"spell.h"
 /*#include	"chr.h"*/
+/*#include	"skill.h"*/
 /*#include	"party.h"*/
 /*#include	"mnstr.h"*/
 #include	"pet.h"
@@ -401,6 +474,7 @@
 #include	"item-prot.h"
 /*#include	"spell-prot.h"*/
 #include	"chr-prot.h"
+/*#include	"skill-prot.h"*/
 #include	"party-prot.h"
 #include	"mnstr-prot.h"
 #include	"pet-prot.h"
@@ -419,6 +493,8 @@
 #include	"gfile-prot.h"
 /*#include	"msg-prot.h"*/
 
+#include	"key-item.h"
+#include	"key-item-prot.h"
 #include	"last-boss.h"
 #include	"last-boss-prot.h"
 
@@ -444,6 +520,7 @@
 /*#include	"item.h"*/
 /*#include	"spell.h"*/
 #include	"chr.h"
+/*#include	"skill.h"*/
 #include	"party.h"
 /*#include	"mnstr.h"*/
 /*#include	"pet.h"*/
@@ -469,6 +546,7 @@
 /*#include	"item-prot.h"*/
 /*#include	"spell-prot.h"*/
 /*#include	"chr-prot.h"*/
+/*#include	"skill-prot.h"*/
 /*#include	"party-prot.h"*/
 /*#include	"mnstr-prot.h"*/
 /*#include	"pet-prot.h"*/
@@ -503,6 +581,7 @@
 #include	"item.h"
 #include	"spell.h"
 /*#include	"chr.h"*/
+#include	"skill.h"
 #include	"party.h"
 /*#include	"mnstr.h"*/
 /*#include	"pet.h"*/
@@ -528,6 +607,7 @@
 #include	"item-prot.h"
 /*#include	"spell-prot.h"*/
 #include	"chr-prot.h"
+#include	"skill-prot.h"
 #include	"party-prot.h"
 #include	"mnstr-prot.h"
 /*#include	"pet-prot.h"*/
@@ -546,6 +626,9 @@
 /*#include	"gfile-prot.h"*/
 /*#include	"msg-prot.h"*/
 
+#include	"last-boss.h"
+#include	"last-boss-prot.h"
+
 #endif	/* FIGHT_C */
 
 /***************************************************************/
@@ -562,6 +645,7 @@
 #include	"item.h"
 #include	"spell.h"
 /*#include	"chr.h"*/
+/*#include	"skill.h"*/
 #include	"party.h"
 /*#include	"mnstr.h"*/
 #include	"pet.h"
@@ -587,6 +671,7 @@
 #include	"item-prot.h"
 #include	"spell-prot.h"
 #include	"chr-prot.h"
+/*#include	"skill-prot.h"*/
 #include	"party-prot.h"
 #include	"mnstr-prot.h"
 #include	"pet-prot.h"
@@ -625,6 +710,7 @@
 #include	"item.h"
 #include	"spell.h"
 #include	"chr.h"
+/*#include	"skill.h"*/
 #include	"party.h"
 #include	"mnstr.h"
 #include	"pet.h"
@@ -650,6 +736,7 @@
 #include	"item-prot.h"
 #include	"spell-prot.h"
 #include	"chr-prot.h"
+/*#include	"skill-prot.h"*/
 #include	"party-prot.h"
 #include	"mnstr-prot.h"
 #include	"pet-prot.h"
@@ -692,6 +779,7 @@
 #include	"item.h"
 #include	"spell.h"
 #include	"chr.h"
+#include	"skill.h"
 #include	"party.h"
 #include	"mnstr.h"
 #include	"pet.h"
@@ -717,6 +805,7 @@
 #include	"item-prot.h"
 #include	"spell-prot.h"
 #include	"chr-prot.h"
+#include	"skill-prot.h"
 #include	"party-prot.h"
 #include	"mnstr-prot.h"
 #include	"mnstr-act-prot.h"
@@ -765,8 +854,12 @@
 # include	"main-dows-prot.h"
 #endif	/* D_MFC */
 
+#include	"key-item.h"
+#include	"key-item-prot.h"
 #include	"last-boss.h"
 #include	"last-boss-prot.h"
+#include	"ending-ep.h"
+#include	"ending-ep-prot.h"
 #include	"win-kind.h"
 #include	"call-prot.h"
 
@@ -786,6 +879,7 @@
 #include	"item.h"
 #include	"spell.h"
 #include	"chr.h"
+/*#include	"skill.h"*/
 #include	"party.h"
 #include	"mnstr.h"
 #include	"pet.h"
@@ -811,6 +905,7 @@
 #include	"item-prot.h"
 /*#include	"spell-prot.h"*/
 #include	"chr-prot.h"
+/*#include	"skill-prot.h"*/
 #include	"party-prot.h"
 #include	"mnstr-prot.h"
 #include	"pet-prot.h"
@@ -829,6 +924,9 @@
 #include	"gfile-prot.h"
 #include	"msg-prot.h"
 
+#include	"key-item.h"
+#include	"key-item-prot.h"
+
 #include	"win-kind.h"
 #include	"joy-kind.h"
 #include	"call-prot.h"
@@ -849,6 +947,7 @@
 #include	"item.h"
 #include	"spell.h"
 /*#include	"chr.h"*/
+/*#include	"skill.h"*/
 /*#include	"party.h"*/
 /*#include	"mnstr.h"*/
 /*#include	"pet.h"*/
@@ -874,6 +973,7 @@
 #include	"item-prot.h"
 #include	"spell-prot.h"
 #include	"chr-prot.h"
+/*#include	"skill-prot.h"*/
 #include	"party-prot.h"
 #include	"mnstr-prot.h"
 /*#include	"pet-prot.h"*/
@@ -892,6 +992,9 @@
 /*#include	"gfile-prot.h"*/
 /*#include	"msg-prot.h"*/
 
+#include	"last-boss.h"
+#include	"last-boss-prot.h"
+
 #endif	/* ITEM_C */
 
 /***************************************************************/
@@ -908,6 +1011,7 @@
 /*#include	"item.h"*/
 /*#include	"spell.h"*/
 /*#include	"chr.h"*/
+/*#include	"skill.h"*/
 /*#include	"party.h"*/
 /*#include	"mnstr.h"*/
 /*#include	"pet.h"*/
@@ -933,6 +1037,7 @@
 /*#include	"item-prot.h"*/
 /*#include	"spell-prot.h"*/
 /*#include	"chr-prot.h"*/
+/*#include	"skill-prot.h"*/
 /*#include	"party-prot.h"*/
 /*#include	"mnstr-prot.h"*/
 /*#include	"pet-prot.h"*/
@@ -969,6 +1074,7 @@
 /*#include	"item.h"*/
 /*#include	"spell.h"*/
 /*#include	"chr.h"*/
+/*#include	"skill.h"*/
 /*#include	"party.h"*/
 /*#include	"mnstr.h"*/
 /*#include	"pet.h"*/
@@ -994,6 +1100,7 @@
 /*#include	"item-prot.h"*/
 /*#include	"spell-prot.h"*/
 /*#include	"chr-prot.h"*/
+/*#include	"skill-prot.h"*/
 /*#include	"party-prot.h"*/
 /*#include	"mnstr-prot.h"*/
 /*#include	"pet-prot.h"*/
@@ -1032,6 +1139,7 @@
 /*#include	"item.h"*/
 /*#include	"spell.h"*/
 /*#include	"chr.h"*/
+/*#include	"skill.h"*/
 #include	"party.h"
 /*#include	"mnstr.h"*/
 #include	"pet.h"
@@ -1057,6 +1165,7 @@
 /*#include	"item-prot.h"*/
 /*#include	"spell-prot.h"*/
 /*#include	"chr-prot.h"*/
+/*#include	"skill-prot.h"*/
 #include	"party-prot.h"
 /*#include	"mnstr-prot.h"*/
 #include	"pet-prot.h"
@@ -1097,6 +1206,7 @@
 /*#include	"item.h"*/
 /*#include	"spell.h"*/
 /*#include	"chr.h"*/
+/*#include	"skill.h"*/
 /*#include	"party.h"*/
 /*#include	"mnstr.h"*/
 /*#include	"pet.h"*/
@@ -1122,6 +1232,7 @@
 /*#include	"item-prot.h"*/
 /*#include	"spell-prot.h"*/
 /*#include	"chr-prot.h"*/
+/*#include	"skill-prot.h"*/
 /*#include	"party-prot.h"*/
 /*#include	"mnstr-prot.h"*/
 /*#include	"pet-prot.h"*/
@@ -1160,6 +1271,7 @@
 /*#include	"item.h"*/
 #include	"spell.h"
 /*#include	"chr.h"*/
+/*#include	"skill.h"*/
 /*#include	"party.h"*/
 /*#include	"mnstr.h"*/
 #include	"pet.h"
@@ -1185,6 +1297,7 @@
 #include	"item-prot.h"
 #include	"spell-prot.h"
 #include	"chr-prot.h"
+/*#include	"skill-prot.h"*/
 #include	"party-prot.h"
 #include	"mnstr-prot.h"
 #include	"pet-prot.h"
@@ -1203,6 +1316,9 @@
 #include	"gfile-prot.h"
 #include	"msg-prot.h"
 
+#include	"last-boss.h"
+#include	"last-boss-prot.h"
+
 #include	"win-kind.h"
 #include	"call-prot.h"
 
@@ -1214,7 +1330,7 @@
 
 #include	"gmain.h"
 #include	"misc.h"
-/*#include	"scene.h"*/
+#include	"scene.h"
 #include	"turn.h"
 #include	"dun.h"
 /*#include	"map-event.h"*/
@@ -1222,6 +1338,7 @@
 #include	"item.h"
 /*#include	"spell.h"*/
 #include	"chr.h"
+/*#include	"skill.h"*/
 #include	"party.h"
 #include	"mnstr.h"
 #include	"pet.h"
@@ -1239,7 +1356,7 @@
 /*#include	"ver.h"*/
 /*#include	"gmain-prot.h"*/
 #include	"misc-prot.h"
-/*#include	"scene-prot.h"*/
+#include	"scene-prot.h"
 #include	"turn-prot.h"
 #include	"dun-prot.h"
 /*#include	"map-event-prot.h"*/
@@ -1247,6 +1364,7 @@
 #include	"item-prot.h"
 /*#include	"spell-prot.h"*/
 #include	"chr-prot.h"
+/*#include	"skill-prot.h"*/
 #include	"party-prot.h"
 #include	"mnstr-prot.h"
 #include	"mnstr-act-prot.h"
@@ -1282,6 +1400,7 @@
 #include	"item.h"
 #include	"spell.h"
 /*#include	"chr.h"*/
+/*#include	"skill.h"*/
 /*#include	"party.h"*/
 /*#include	"mnstr.h"*/
 #include	"pet.h"
@@ -1307,6 +1426,7 @@
 #include	"item-prot.h"
 #include	"spell-prot.h"
 #include	"chr-prot.h"
+/*#include	"skill-prot.h"*/
 #include	"party-prot.h"
 #include	"mnstr-prot.h"
 #include	"pet-prot.h"
@@ -1325,6 +1445,12 @@
 /*#include	"gfile-prot.h"*/
 /*#include	"msg-prot.h"*/
 
+#include	"key-item.h"
+#include	"key-item-prot.h"
+
+#include	"last-boss.h"
+#include	"last-boss-prot.h"
+
 #endif	/* MNSTR_C */
 
 /***************************************************************/
@@ -1341,6 +1467,7 @@
 /*#include	"item.h"*/
 /*#include	"spell.h"*/
 /*#include	"chr.h"*/
+/*#include	"skill.h"*/
 /*#include	"party.h"*/
 /*#include	"mnstr.h"*/
 /*#include	"pet.h"*/
@@ -1366,6 +1493,7 @@
 /*#include	"item-prot.h"*/
 /*#include	"spell-prot.h"*/
 /*#include	"chr-prot.h"*/
+/*#include	"skill-prot.h"*/
 /*#include	"party-prot.h"*/
 /*#include	"mnstr-prot.h"*/
 /*#include	"pet-prot.h"*/
@@ -1400,6 +1528,7 @@
 #include	"item.h"
 #include	"spell.h"
 /*#include	"chr.h"*/
+/*#include	"skill.h"*/
 /*#include	"party.h"*/
 /*#include	"mnstr.h"*/
 #include	"pet.h"
@@ -1425,6 +1554,7 @@
 #include	"item-prot.h"
 #include	"spell-prot.h"
 #include	"chr-prot.h"
+/*#include	"skill-prot.h"*/
 #include	"party-prot.h"
 #include	"mnstr-prot.h"
 #include	"pet-prot.h"
@@ -1463,6 +1593,7 @@
 #include	"item.h"
 /*#include	"spell.h"*/
 #include	"chr.h"
+/*#include	"skill.h"*/
 #include	"party.h"
 #include	"mnstr.h"
 #include	"pet.h"
@@ -1488,6 +1619,7 @@
 /*#include	"item-prot.h"*/
 /*#include	"spell-prot.h"*/
 #include	"chr-prot.h"
+/*#include	"skill-prot.h"*/
 #include	"party-prot.h"
 #include	"mnstr-prot.h"
 #include	"pet-prot.h"
@@ -1523,6 +1655,7 @@
 #include	"item.h"
 /*#include	"spell.h"*/
 #include	"chr.h"
+/*#include	"skill.h"*/
 #include	"party.h"
 #include	"mnstr.h"
 #include	"pet.h"
@@ -1548,6 +1681,7 @@
 #include	"item-prot.h"
 /*#include	"spell-prot.h"*/
 #include	"chr-prot.h"
+/*#include	"skill-prot.h"*/
 #include	"party-prot.h"
 #include	"mnstr-prot.h"
 #include	"pet-prot.h"
@@ -1582,6 +1716,7 @@
 /*#include	"item.h"*/
 #include	"spell.h"
 /*#include	"chr.h"*/
+#include	"skill.h"
 /*#include	"party.h"*/
 /*#include	"mnstr.h"*/
 #include	"pet.h"
@@ -1607,6 +1742,7 @@
 #include	"item-prot.h"
 /*#include	"spell-prot.h"*/
 #include	"chr-prot.h"
+#include	"skill-prot.h"
 #include	"party-prot.h"
 #include	"mnstr-prot.h"
 #include	"pet-prot.h"
@@ -1625,6 +1761,9 @@
 /*#include	"gfile-prot.h"*/
 #include	"msg-prot.h"
 
+#include	"last-boss.h"
+#include	"last-boss-prot.h"
+
 #endif	/* SPELL_C */
 
 /***************************************************************/
@@ -1641,6 +1780,7 @@
 #include	"item.h"
 #include	"spell.h"
 /*#include	"chr.h"*/
+#include	"skill.h"
 /*#include	"party.h"*/
 #include	"mnstr.h"
 #include	"pet.h"
@@ -1666,6 +1806,7 @@
 #include	"item-prot.h"
 #include	"spell-prot.h"
 #include	"chr-prot.h"
+#include	"skill-prot.h"
 #include	"party-prot.h"
 #include	"mnstr-prot.h"
 #include	"pet-prot.h"
@@ -1685,6 +1826,7 @@
 /*#include	"msg-prot.h"*/
 
 #include	"music-kind.h"
+#include	"sound-kind.h"
 #include	"call-prot.h"
 
 #endif	/* TMENU_C */
@@ -1703,6 +1845,7 @@
 #include	"item.h"
 #include	"spell.h"
 /*#include	"chr.h"*/
+/*#include	"skill.h"*/
 /*#include	"party.h"*/
 #include	"mnstr.h"
 #include	"pet.h"
@@ -1728,6 +1871,7 @@
 #include	"item-prot.h"
 #include	"spell-prot.h"
 #include	"chr-prot.h"
+/*#include	"skill-prot.h"*/
 #include	"party-prot.h"
 #include	"mnstr-prot.h"
 #include	"pet-prot.h"
@@ -1762,6 +1906,7 @@
 #include	"item.h"
 #include	"spell.h"
 /*#include	"chr.h"*/
+/*#include	"skill.h"*/
 #include	"party.h"
 /*#include	"mnstr.h"*/
 #include	"pet.h"
@@ -1787,6 +1932,7 @@
 #include	"item-prot.h"
 #include	"spell-prot.h"
 #include	"chr-prot.h"
+/*#include	"skill-prot.h"*/
 #include	"party-prot.h"
 /*#include	"mnstr-prot.h"*/
 #include	"pet-prot.h"
@@ -1821,6 +1967,7 @@
 #include	"item.h"
 /*#include	"spell.h"*/
 /*#include	"chr.h"*/
+/*#include	"skill.h"*/
 #include	"party.h"
 #include	"mnstr.h"
 #include	"pet.h"
@@ -1846,6 +1993,7 @@
 #include	"item-prot.h"
 /*#include	"spell-prot.h"*/
 /*#include	"chr-prot.h"*/
+/*#include	"skill-prot.h"*/
 /*#include	"party-prot.h"*/
 #include	"mnstr-prot.h"
 /*#include	"pet-prot.h"*/
@@ -1880,6 +2028,7 @@
 /*#include	"item.h"*/
 /*#include	"spell.h"*/
 #include	"chr.h"
+/*#include	"skill.h"*/
 #include	"party.h"
 #include	"mnstr.h"
 /*#include	"pet.h"*/
@@ -1905,6 +2054,7 @@
 /*#include	"item-prot.h"*/
 /*#include	"spell-prot.h"*/
 #include	"chr-prot.h"
+/*#include	"skill-prot.h"*/
 #include	"party-prot.h"
 #include	"mnstr-prot.h"
 /*#include	"pet-prot.h"*/
@@ -1929,20 +2079,21 @@
 
 /***************************************************************/
 
-#ifdef	LAST_BOSS_C
+#ifdef	KEY_ITEM_C
 
 #include	"gmain.h"
-#include	"misc.h"
+/*#include	"misc.h"*/
 #include	"scene.h"
 /*#include	"turn.h"*/
 #include	"dun.h"
-#include	"map-event.h"
+/*#include	"map-event.h"*/
 /*#include	"town.h"*/
 /*#include	"item.h"*/
 /*#include	"spell.h"*/
 #include	"chr.h"
+/*#include	"skill.h"*/
 #include	"party.h"
-#include	"mnstr.h"
+/*#include	"mnstr.h"*/
 /*#include	"pet.h"*/
 /*#include	"fight.h"*/
 /*#include	"fx.h"*/
@@ -1961,13 +2112,14 @@
 #include	"scene-prot.h"
 /*#include	"turn-prot.h"*/
 #include	"dun-prot.h"
-#include	"map-event-prot.h"
+/*#include	"map-event-prot.h"*/
 /*#include	"town-prot.h"*/
 /*#include	"item-prot.h"*/
 /*#include	"spell-prot.h"*/
-#include	"chr-prot.h"
-#include	"party-prot.h"
-#include	"mnstr-prot.h"
+/*#include	"chr-prot.h"*/
+/*#include	"skill-prot.h"*/
+/*#include	"party-prot.h"*/
+/*#include	"mnstr-prot.h"*/
 /*#include	"pet-prot.h"*/
 /*#include	"fight-prot.h"*/
 /*#include	"fx-prot.h"*/
@@ -1984,6 +2136,72 @@
 /*#include	"gfile-prot.h"*/
 /*#include	"msg-prot.h"*/
 
+#include	"key-item.h"
+#include	"key-item-prot.h"
+#include	"last-boss.h"
+#include	"last-boss-prot.h"
+
+#endif	/* KEY_ITEM_C */
+
+/***************************************************************/
+
+#ifdef	LAST_BOSS_C
+
+#include	"gmain.h"
+#include	"misc.h"
+#include	"scene.h"
+/*#include	"turn.h"*/
+#include	"dun.h"
+#include	"map-event.h"
+/*#include	"town.h"*/
+/*#include	"item.h"*/
+#include	"spell.h"
+#include	"chr.h"
+/*#include	"skill.h"*/
+#include	"party.h"
+#include	"mnstr.h"
+/*#include	"pet.h"*/
+#include	"fight.h"
+#include	"fx.h"
+/*#include	"trap.h"*/
+/*#include	"replay.h"*/
+#include	"draw.h"
+#include	"curs.h"
+/*#include	"menu.h"*/
+/*#include	"amenu.h"*/
+/*#include	"request.h"*/
+/*#include	"gfile.h"*/
+/*#include	"msg.h"*/
+/*#include	"ver.h"*/
+#include	"gmain-prot.h"
+#include	"misc-prot.h"
+#include	"scene-prot.h"
+/*#include	"turn-prot.h"*/
+#include	"dun-prot.h"
+#include	"map-event-prot.h"
+/*#include	"town-prot.h"*/
+/*#include	"item-prot.h"*/
+#include	"spell-prot.h"
+#include	"chr-prot.h"
+/*#include	"skill-prot.h"*/
+#include	"party-prot.h"
+#include	"mnstr-prot.h"
+/*#include	"pet-prot.h"*/
+#include	"fight-prot.h"
+#include	"fx-prot.h"
+/*#include	"trap-prot.h"*/
+/*#include	"replay-prot.h"*/
+#include	"draw-prot.h"
+#include	"curs-prot.h"
+/*#include	"menu-prot.h"*/
+/*#include	"mmenu-prot.h"*/
+/*#include	"imenu-prot.h"*/
+/*#include	"tmenu-prot.h"*/
+/*#include	"amenu-prot.h"*/
+/*#include	"request-prot.h"*/
+/*#include	"gfile-prot.h"*/
+/*#include	"msg-prot.h"*/
+
 #include	"last-boss.h"
 #include	"last-boss-prot.h"
 
@@ -1991,6 +2209,136 @@
 
 #endif	/* LAST_BOSS_C */
 
+/***************************************************************/
+
+#ifdef	ENDING_EP_C
+
+#include	"gmain.h"
+#include	"misc.h"
+#include	"scene.h"
+/*#include	"turn.h"*/
+/*#include	"dun.h"*/
+/*#include	"map-event.h"*/
+/*#include	"town.h"*/
+/*#include	"item.h"*/
+/*#include	"spell.h"*/
+/*#include	"chr.h"*/
+/*#include	"skill.h"*/
+/*#include	"party.h"*/
+/*#include	"mnstr.h"*/
+/*#include	"pet.h"*/
+/*#include	"fight.h"*/
+/*#include	"fx.h"*/
+/*#include	"trap.h"*/
+/*#include	"replay.h"*/
+#include	"draw.h"
+#include	"curs.h"
+/*#include	"menu.h"*/
+/*#include	"amenu.h"*/
+/*#include	"request.h"*/
+/*#include	"gfile.h"*/
+#include	"msg.h"
+/*#include	"ver.h"*/
+#include	"gmain-prot.h"
+#include	"misc-prot.h"
+#include	"scene-prot.h"
+/*#include	"turn-prot.h"*/
+/*#include	"dun-prot.h"*/
+/*#include	"map-event-prot.h"*/
+/*#include	"town-prot.h"*/
+/*#include	"item-prot.h"*/
+/*#include	"spell-prot.h"*/
+/*#include	"chr-prot.h"*/
+/*#include	"skill-prot.h"*/
+/*#include	"party-prot.h"*/
+/*#include	"mnstr-prot.h"*/
+/*#include	"pet-prot.h"*/
+/*#include	"fight-prot.h"*/
+/*#include	"fx-prot.h"*/
+/*#include	"trap-prot.h"*/
+/*#include	"replay-prot.h"*/
+#include	"draw-prot.h"
+#include	"curs-prot.h"
+/*#include	"menu-prot.h"*/
+/*#include	"mmenu-prot.h"*/
+/*#include	"imenu-prot.h"*/
+/*#include	"tmenu-prot.h"*/
+/*#include	"amenu-prot.h"*/
+/*#include	"request-prot.h"*/
+/*#include	"gfile-prot.h"*/
+#include	"msg-prot.h"
+
+#include	"ending-ep.h"
+#include	"ending-ep-prot.h"
+#include	"ending-space.h"
+#include	"ending-space-prot.h"
+
+#endif	/* ENDING_EP_C */
+
+/***************************************************************/
+
+#ifdef	ENDING_SPACE_C
+
+#include	"gmain.h"
+#include	"misc.h"
+#include	"scene.h"
+/*#include	"turn.h"*/
+/*#include	"dun.h"*/
+/*#include	"map-event.h"*/
+/*#include	"town.h"*/
+/*#include	"item.h"*/
+/*#include	"spell.h"*/
+/*#include	"chr.h"*/
+/*#include	"skill.h"*/
+/*#include	"party.h"*/
+/*#include	"mnstr.h"*/
+/*#include	"pet.h"*/
+/*#include	"fight.h"*/
+/*#include	"fx.h"*/
+/*#include	"trap.h"*/
+/*#include	"replay.h"*/
+#include	"draw.h"
+#include	"curs.h"
+/*#include	"menu.h"*/
+/*#include	"amenu.h"*/
+/*#include	"request.h"*/
+/*#include	"gfile.h"*/
+#include	"msg.h"
+/*#include	"ver.h"*/
+#include	"gmain-prot.h"
+#include	"misc-prot.h"
+#include	"scene-prot.h"
+/*#include	"turn-prot.h"*/
+/*#include	"dun-prot.h"*/
+/*#include	"map-event-prot.h"*/
+/*#include	"town-prot.h"*/
+/*#include	"item-prot.h"*/
+/*#include	"spell-prot.h"*/
+/*#include	"chr-prot.h"*/
+/*#include	"skill-prot.h"*/
+/*#include	"party-prot.h"*/
+/*#include	"mnstr-prot.h"*/
+/*#include	"pet-prot.h"*/
+/*#include	"fight-prot.h"*/
+/*#include	"fx-prot.h"*/
+/*#include	"trap-prot.h"*/
+/*#include	"replay-prot.h"*/
+#include	"draw-prot.h"
+#include	"curs-prot.h"
+/*#include	"menu-prot.h"*/
+/*#include	"mmenu-prot.h"*/
+/*#include	"imenu-prot.h"*/
+/*#include	"tmenu-prot.h"*/
+/*#include	"amenu-prot.h"*/
+/*#include	"request-prot.h"*/
+/*#include	"gfile-prot.h"*/
+#include	"msg-prot.h"
+
+#include	"ending-space.h"
+#include	"ending-space-prot.h"
+
+#endif	/* ENDING_SPACE_C */
+
 /***************************************************************
 * xlnl
 ***************************************************************/
@@ -2007,6 +2355,7 @@
 /*#include	"item.h"*/
 /*#include	"spell.h"*/
 /*#include	"chr.h"*/
+/*#include	"skill.h"*/
 /*#include	"party.h"*/
 /*#include	"mnstr.h"*/
 /*#include	"pet.h"*/
@@ -2032,6 +2381,7 @@
 /*#include	"item-prot.h"*/
 /*#include	"spell-prot.h"*/
 /*#include	"chr-prot.h"*/
+/*#include	"skill-prot.h"*/
 /*#include	"party-prot.h"*/
 /*#include	"mnstr-prot.h"*/
 /*#include	"pet-prot.h"*/
@@ -2072,6 +2422,7 @@
 /*#include	"item.h"*/
 /*#include	"spell.h"*/
 /*#include	"chr.h"*/
+/*#include	"skill.h"*/
 /*#include	"party.h"*/
 /*#include	"mnstr.h"*/
 /*#include	"pet.h"*/
@@ -2097,6 +2448,7 @@
 /*#include	"item-prot.h"*/
 /*#include	"spell-prot.h"*/
 /*#include	"chr-prot.h"*/
+/*#include	"skill-prot.h"*/
 /*#include	"party-prot.h"*/
 /*#include	"mnstr-prot.h"*/
 /*#include	"pet-prot.h"*/
@@ -2142,6 +2494,7 @@
 /*#include	"item.h"*/
 /*#include	"spell.h"*/
 #include	"chr.h"
+/*#include	"skill.h"*/
 /*#include	"party.h"*/
 /*#include	"mnstr.h"*/
 /*#include	"pet.h"*/
@@ -2167,6 +2520,7 @@
 /*#include	"item-prot.h"*/
 /*#include	"spell-prot.h"*/
 /*#include	"chr-prot.h"*/
+/*#include	"skill-prot.h"*/
 /*#include	"party-prot.h"*/
 /*#include	"mnstr-prot.h"*/
 /*#include	"pet-prot.h"*/
@@ -2209,6 +2563,7 @@
 #  include "gmain.h"
 #  include "misc.h"
 #  include "chr.h"
+/*#include	"skill.h"*/
 #  include "draw.h"
 #  include "GameThread.h"
 #  include "GuiMenu.h"
@@ -2219,11 +2574,13 @@
 #  include "gmain-prot.h"
 #  include "misc-prot.h"
 #  include "chr-prot.h"
+/*#include	"skill-prot.h"*/
 #  include "draw-prot.h"
 # elif	defined( D_GTK )
 #  include "gmain.h"
 #  include "misc.h"
 #  include "chr.h"
+/*#include	"skill.h"*/
 #  include "draw.h"
 #  include "GameThread.h"
 #  include "GuiMenu.h"
@@ -2234,12 +2591,14 @@
 #  include "gmain-prot.h"
 #  include "misc-prot.h"
 #  include "chr-prot.h"
+/*#include	"skill-prot.h"*/
 #  include "draw-prot.h"
 #  include "main-gtk-prot.h"
 # elif	defined( D_MFC )
 #  include "gmain.h"
 #  include "misc.h"
 #  include "chr.h"
+/*#include	"skill.h"*/
 #  include "draw.h"
 #  include "GameThread.h"
 #  include "GuiMenu.h"
@@ -2250,16 +2609,21 @@
 #  include "gmain-prot.h"
 #  include "misc-prot.h"
 #  include "chr-prot.h"
+/*#include	"skill-prot.h"*/
 #  include "draw-prot.h"
 # else
 #  include "gmain.h"
 #  include "misc.h"
 #  include "chr.h"
+/*#include	"skill.h"*/
 #  include "draw.h"
 #  include "misc-prot.h"
 #  include "chr-prot.h"
+/*#include	"skill-prot.h"*/
 # endif
 
+# include "last-boss.h"
+
 # include "win-kind.h"
 # include "joy-kind.h"
 # include "call-prot.h"
@@ -2280,6 +2644,7 @@
 /*#include	"item.h"*/
 /*#include	"spell.h"*/
 /*#include	"chr.h"*/
+/*#include	"skill.h"*/
 /*#include	"party.h"*/
 /*#include	"mnstr.h"*/
 /*#include	"pet.h"*/
@@ -2305,6 +2670,7 @@
 /*#include	"item-prot.h"*/
 /*#include	"spell-prot.h"*/
 /*#include	"chr-prot.h"*/
+/*#include	"skill-prot.h"*/
 /*#include	"party-prot.h"*/
 /*#include	"mnstr-prot.h"*/
 /*#include	"pet-prot.h"*/
@@ -2363,6 +2729,7 @@
 #ifdef	PCG_DUN_CPP
 #include	"gmain.h"
 #include	"misc.h"
+#include	"scene.h"
 #include	"turn.h"
 #include	"dun.h"
 /*#include	"map-event.h"*/
@@ -2370,6 +2737,7 @@
 /*#include	"item.h"*/
 /*#include	"spell.h"*/
 #include	"chr.h"
+/*#include	"skill.h"*/
 #include	"party.h"
 #include	"mnstr.h"
 /*#include	"pet.h"*/
@@ -2386,6 +2754,7 @@
 /*#include	"ver.h"*/
 #include	"gmain-prot.h"
 #include	"misc-prot.h"
+#include	"scene-prot.h"
 #include	"turn-prot.h"
 #include	"dun-prot.h"
 /*#include	"map-event-prot.h"*/
@@ -2393,6 +2762,7 @@
 /*#include	"item-prot.h"*/
 /*#include	"spell-prot.h"*/
 #include	"chr-prot.h"
+/*#include	"skill-prot.h"*/
 #include	"party-prot.h"
 #include	"mnstr-prot.h"
 /*#include	"pet-prot.h"*/
@@ -2410,9 +2780,6 @@
 #include	"gfile-prot.h"
 #include	"msg-prot.h"
 
-#include	"scene.h"
-#include	"scene-prot.h"
-
 #include	"last-boss.h"
 #include	"last-boss-prot.h"
 
@@ -2454,6 +2821,7 @@
 /*#include	"item.h"*/
 /*#include	"spell.h"*/
 /*#include	"chr.h"*/
+/*#include	"skill.h"*/
 /*#include	"party.h"*/
 /*#include	"mnstr.h"*/
 /*#include	"pet.h"*/
@@ -2479,6 +2847,7 @@
 /*#include	"item-prot.h"*/
 /*#include	"spell-prot.h"*/
 /*#include	"chr-prot.h"*/
+/*#include	"skill-prot.h"*/
 /*#include	"party-prot.h"*/
 /*#include	"mnstr-prot.h"*/
 /*#include	"pet-prot.h"*/
@@ -2528,6 +2897,7 @@
 /*#include	"item.h"*/
 /*#include	"spell.h"*/
 /*#include	"chr.h"*/
+/*#include	"skill.h"*/
 /*#include	"party.h"*/
 /*#include	"mnstr.h"*/
 /*#include	"pet.h"*/
@@ -2553,6 +2923,7 @@
 /*#include	"item-prot.h"*/
 /*#include	"spell-prot.h"*/
 /*#include	"chr-prot.h"*/
+/*#include	"skill-prot.h"*/
 /*#include	"party-prot.h"*/
 /*#include	"mnstr-prot.h"*/
 /*#include	"pet-prot.h"*/
@@ -2604,6 +2975,7 @@
 /*#include	"item.h"*/
 /*#include	"spell.h"*/
 /*#include	"chr.h"*/
+/*#include	"skill.h"*/
 /*#include	"party.h"*/
 /*#include	"mnstr.h"*/
 /*#include	"pet.h"*/
@@ -2629,6 +3001,7 @@
 /*#include	"item-prot.h"*/
 /*#include	"spell-prot.h"*/
 /*#include	"chr-prot.h"*/
+/*#include	"skill-prot.h"*/
 /*#include	"party-prot.h"*/
 /*#include	"mnstr-prot.h"*/
 /*#include	"pet-prot.h"*/
@@ -2679,6 +3052,7 @@
 /*#include	"item.h"*/
 /*#include	"spell.h"*/
 /*#include	"chr.h"*/
+/*#include	"skill.h"*/
 /*#include	"party.h"*/
 /*#include	"mnstr.h"*/
 /*#include	"pet.h"*/
@@ -2704,6 +3078,7 @@
 /*#include	"item-prot.h"*/
 /*#include	"spell-prot.h"*/
 /*#include	"chr-prot.h"*/
+/*#include	"skill-prot.h"*/
 /*#include	"party-prot.h"*/
 /*#include	"mnstr-prot.h"*/
 /*#include	"pet-prot.h"*/
@@ -2753,6 +3128,7 @@
 /*#include	"item.h"*/
 /*#include	"spell.h"*/
 /*#include	"chr.h"*/
+/*#include	"skill.h"*/
 /*#include	"party.h"*/
 /*#include	"mnstr.h"*/
 /*#include	"pet.h"*/
@@ -2778,6 +3154,7 @@
 /*#include	"item-prot.h"*/
 /*#include	"spell-prot.h"*/
 /*#include	"chr-prot.h"*/
+/*#include	"skill-prot.h"*/
 /*#include	"party-prot.h"*/
 /*#include	"mnstr-prot.h"*/
 /*#include	"pet-prot.h"*/
@@ -2827,6 +3204,7 @@
 /*#include	"item.h"*/
 /*#include	"spell.h"*/
 /*#include	"chr.h"*/
+/*#include	"skill.h"*/
 /*#include	"party.h"*/
 /*#include	"mnstr.h"*/
 /*#include	"pet.h"*/
@@ -2852,6 +3230,7 @@
 /*#include	"item-prot.h"*/
 /*#include	"spell-prot.h"*/
 /*#include	"chr-prot.h"*/
+/*#include	"skill-prot.h"*/
 /*#include	"party-prot.h"*/
 /*#include	"mnstr-prot.h"*/
 /*#include	"pet-prot.h"*/
@@ -2870,6 +3249,8 @@
 /*#include	"gfile-prot.h"*/
 #include	"msg-prot.h"
 
+#include	"ending-space.h"
+
 #ifdef D_WS
 #endif /* D_WS */
 
@@ -2889,6 +3270,73 @@
 
 /***************************************************************/
 
+#ifdef	GUI_LAST_BOSS_CPP
+
+#include	"gmain.h"
+#include	"misc.h"
+/*#include	"scene.h"*/
+/*#include	"turn.h"*/
+#include	"dun.h"
+/*#include	"map-event.h"*/
+/*#include	"town.h"*/
+/*#include	"item.h"*/
+/*#include	"spell.h"*/
+#include	"chr.h"
+/*#include	"skill.h"*/
+#include	"party.h"
+#include	"mnstr.h"
+/*#include	"pet.h"*/
+/*#include	"fight.h"*/
+/*#include	"fx.h"*/
+/*#include	"trap.h"*/
+/*#include	"replay.h"*/
+/*#include	"draw.h"*/
+/*#include	"curs.h"*/
+/*#include	"menu.h"*/
+/*#include	"amenu.h"*/
+/*#include	"request.h"*/
+/*#include	"gfile.h"*/
+/*#include	"msg.h"*/
+/*#include	"ver.h"*/
+/*#include	"gmain-prot.h"*/
+/*#include	"misc-prot.h"*/
+/*#include	"scene-prot.h"*/
+/*#include	"turn-prot.h"*/
+#include	"dun-prot.h"
+/*#include	"map-event-prot.h"*/
+/*#include	"town-prot.h"*/
+/*#include	"item-prot.h"*/
+/*#include	"spell-prot.h"*/
+/*#include	"chr-prot.h"*/
+/*#include	"skill-prot.h"*/
+/*#include	"party-prot.h"*/
+/*#include	"mnstr-prot.h"*/
+/*#include	"pet-prot.h"*/
+/*#include	"fight-prot.h"*/
+/*#include	"fx-prot.h"*/
+/*#include	"trap-prot.h"*/
+/*#include	"replay-prot.h"*/
+/*#include	"draw-prot.h"*/
+/*#include	"curs-prot.h"*/
+/*#include	"menu-prot.h"*/
+/*#include	"mmenu-prot.h"*/
+/*#include	"imenu-prot.h"*/
+/*#include	"tmenu-prot.h"*/
+/*#include	"amenu-prot.h"*/
+/*#include	"request-prot.h"*/
+/*#include	"gfile-prot.h"*/
+/*#include	"msg-prot.h"*/
+
+#include	"last-boss.h"
+#include	"last-boss-prot.h"
+
+#include "GuiLastBoss.h"
+#include "GlobalVar.h"
+
+#endif	/* GUI_LAST_BOSS_CPP */
+
+/***************************************************************/
+
 #ifdef	GAME_MUSIC_CPP
 
 #include	"gmain.h"
@@ -2901,6 +3349,7 @@
 #include	"item.h"
 /*#include	"spell.h"*/
 #include	"chr.h"
+/*#include	"skill.h"*/
 #include	"party.h"
 /*#include	"mnstr.h"*/
 /*#include	"pet.h"*/
@@ -2926,6 +3375,7 @@
 /*#include	"item-prot.h"*/
 /*#include	"spell-prot.h"*/
 /*#include	"chr-prot.h"*/
+/*#include	"skill-prot.h"*/
 /*#include	"party-prot.h"*/
 /*#include	"mnstr-prot.h"*/
 /*#include	"pet-prot.h"*/
@@ -2952,6 +3402,71 @@
 
 /***************************************************************/
 
+#ifdef	GAME_SOUND_CPP
+
+#include	"gmain.h"
+#include	"misc.h"
+/*#include	"scene.h"*/
+/*#include	"turn.h"*/
+/*#include	"dun.h"*/
+/*#include	"map-event.h"*/
+/*#include	"town.h"*/
+/*#include	"item.h"*/
+/*#include	"spell.h"*/
+/*#include	"chr.h"*/
+/*#include	"skill.h"*/
+/*#include	"party.h"*/
+/*#include	"mnstr.h"*/
+/*#include	"pet.h"*/
+/*#include	"fight.h"*/
+/*#include	"fx.h"*/
+/*#include	"trap.h"*/
+/*#include	"replay.h"*/
+/*#include	"draw.h"*/
+/*#include	"curs.h"*/
+/*#include	"menu.h"*/
+/*#include	"amenu.h"*/
+/*#include	"request.h"*/
+/*#include	"gfile.h"*/
+/*#include	"msg.h"*/
+/*#include	"ver.h"*/
+/*#include	"gmain-prot.h"*/
+/*#include	"misc-prot.h"*/
+/*#include	"scene-prot.h"*/
+/*#include	"turn-prot.h"*/
+/*#include	"dun-prot.h"*/
+/*#include	"map-event-prot.h"*/
+/*#include	"town-prot.h"*/
+/*#include	"item-prot.h"*/
+/*#include	"spell-prot.h"*/
+/*#include	"chr-prot.h"*/
+/*#include	"skill-prot.h"*/
+/*#include	"party-prot.h"*/
+/*#include	"mnstr-prot.h"*/
+/*#include	"pet-prot.h"*/
+/*#include	"fight-prot.h"*/
+/*#include	"fx-prot.h"*/
+/*#include	"trap-prot.h"*/
+/*#include	"replay-prot.h"*/
+/*#include	"draw-prot.h"*/
+/*#include	"curs-prot.h"*/
+/*#include	"menu-prot.h"*/
+/*#include	"mmenu-prot.h"*/
+/*#include	"imenu-prot.h"*/
+/*#include	"tmenu-prot.h"*/
+/*#include	"amenu-prot.h"*/
+/*#include	"request-prot.h"*/
+/*#include	"gfile-prot.h"*/
+/*#include	"msg-prot.h"*/
+
+#include "FileList.h"
+#include "GameSound.h"
+#include "GlobalVar.h"
+
+#endif	/* GAME_SOUND_CPP */
+
+/***************************************************************/
+
 #ifdef	GAME_JOYSTICK_CPP
 
 #include	"gmain.h"
@@ -2964,6 +3479,7 @@
 /*#include	"item.h"*/
 /*#include	"spell.h"*/
 /*#include	"chr.h"*/
+/*#include	"skill.h"*/
 /*#include	"party.h"*/
 /*#include	"mnstr.h"*/
 /*#include	"pet.h"*/
@@ -2989,6 +3505,7 @@
 /*#include	"item-prot.h"*/
 /*#include	"spell-prot.h"*/
 /*#include	"chr-prot.h"*/
+/*#include	"skill-prot.h"*/
 /*#include	"party-prot.h"*/
 /*#include	"mnstr-prot.h"*/
 /*#include	"pet-prot.h"*/
@@ -3026,6 +3543,7 @@
 /*#include	"item.h"*/
 /*#include	"spell.h"*/
 /*#include	"chr.h"*/
+/*#include	"skill.h"*/
 /*#include	"party.h"*/
 /*#include	"mnstr.h"*/
 /*#include	"pet.h"*/
@@ -3051,6 +3569,7 @@
 /*#include	"item-prot.h"*/
 /*#include	"spell-prot.h"*/
 /*#include	"chr-prot.h"*/
+/*#include	"skill-prot.h"*/
 /*#include	"party-prot.h"*/
 /*#include	"mnstr-prot.h"*/
 /*#include	"pet-prot.h"*/
@@ -3091,13 +3610,14 @@
 #include	"gmain.h"
 #include	"misc.h"
 /*#include	"scene.h"*/
-/*#include	"turn.h"*/
+#include	"turn.h"
 /*#include	"dun.h"*/
 /*#include	"map-event.h"*/
 /*#include	"town.h"*/
 /*#include	"item.h"*/
 /*#include	"spell.h"*/
 /*#include	"chr.h"*/
+/*#include	"skill.h"*/
 #include	"party.h"
 /*#include	"mnstr.h"*/
 /*#include	"pet.h"*/
@@ -3115,13 +3635,14 @@
 #include	"gmain-prot.h"
 #include	"misc-prot.h"
 /*#include	"scene-prot.h"*/
-/*#include	"turn-prot.h"*/
+#include	"turn-prot.h"
 /*#include	"dun-prot.h"*/
 /*#include	"map-event-prot.h"*/
 /*#include	"town-prot.h"*/
 /*#include	"item-prot.h"*/
 /*#include	"spell-prot.h"*/
 /*#include	"chr-prot.h"*/
+/*#include	"skill-prot.h"*/
 #include	"party-prot.h"
 /*#include	"mnstr-prot.h"*/
 /*#include	"pet-prot.h"*/
@@ -3169,6 +3690,7 @@
 /*#include	"item.h"*/
 /*#include	"spell.h"*/
 /*#include	"chr.h"*/
+/*#include	"skill.h"*/
 /*#include	"party.h"*/
 /*#include	"mnstr.h"*/
 /*#include	"pet.h"*/
@@ -3194,6 +3716,7 @@
 /*#include	"item-prot.h"*/
 /*#include	"spell-prot.h"*/
 /*#include	"chr-prot.h"*/
+/*#include	"skill-prot.h"*/
 /*#include	"party-prot.h"*/
 /*#include	"mnstr-prot.h"*/
 /*#include	"pet-prot.h"*/
@@ -3242,6 +3765,7 @@
 /*#include	"item.h"*/
 /*#include	"spell.h"*/
 /*#include	"chr.h"*/
+/*#include	"skill.h"*/
 /*#include	"party.h"*/
 /*#include	"mnstr.h"*/
 /*#include	"pet.h"*/
@@ -3267,6 +3791,7 @@
 /*#include	"item-prot.h"*/
 /*#include	"spell-prot.h"*/
 /*#include	"chr-prot.h"*/
+/*#include	"skill-prot.h"*/
 /*#include	"party-prot.h"*/
 /*#include	"mnstr-prot.h"*/
 /*#include	"pet-prot.h"*/
@@ -3318,6 +3843,7 @@
 /*#include	"item.h"*/
 /*#include	"spell.h"*/
 /*#include	"chr.h"*/
+/*#include	"skill.h"*/
 /*#include	"party.h"*/
 /*#include	"mnstr.h"*/
 /*#include	"pet.h"*/
@@ -3343,6 +3869,7 @@
 /*#include	"item-prot.h"*/
 /*#include	"spell-prot.h"*/
 /*#include	"chr-prot.h"*/
+/*#include	"skill-prot.h"*/
 /*#include	"party-prot.h"*/
 /*#include	"mnstr-prot.h"*/
 /*#include	"pet-prot.h"*/
@@ -3399,6 +3926,7 @@
 /*#include	"item.h"*/
 /*#include	"spell.h"*/
 /*#include	"chr.h"*/
+/*#include	"skill.h"*/
 /*#include	"party.h"*/
 /*#include	"mnstr.h"*/
 /*#include	"pet.h"*/
@@ -3424,6 +3952,7 @@
 /*#include	"item-prot.h"*/
 /*#include	"spell-prot.h"*/
 /*#include	"chr-prot.h"*/
+/*#include	"skill-prot.h"*/
 /*#include	"party-prot.h"*/
 /*#include	"mnstr-prot.h"*/
 /*#include	"pet-prot.h"*/
@@ -3479,6 +4008,7 @@
 /*#include	"item.h"*/
 /*#include	"spell.h"*/
 #include	"chr.h"
+/*#include	"skill.h"*/
 /*#include	"party.h"*/
 /*#include	"mnstr.h"*/
 /*#include	"pet.h"*/
@@ -3504,6 +4034,7 @@
 /*#include	"item-prot.h"*/
 /*#include	"spell-prot.h"*/
 #include	"chr-prot.h"
+/*#include	"skill-prot.h"*/
 /*#include	"party-prot.h"*/
 /*#include	"mnstr-prot.h"*/
 /*#include	"pet-prot.h"*/
@@ -3547,6 +4078,88 @@
 
 /***************************************************************/
 
+#ifdef	GUI_SKILL_EDIT_CPP
+
+#include	"gmain.h"
+#include	"misc.h"
+/*#include	"scene.h"*/
+/*#include	"turn.h"*/
+/*#include	"dun.h"*/
+/*#include	"map-event.h"*/
+#include	"town.h"
+/*#include	"item.h"*/
+/*#include	"spell.h"*/
+#include	"chr.h"
+#include	"skill.h"
+/*#include	"party.h"*/
+/*#include	"mnstr.h"*/
+/*#include	"pet.h"*/
+/*#include	"fight.h"*/
+/*#include	"fx.h"*/
+/*#include	"trap.h"*/
+/*#include	"replay.h"*/
+#include	"draw.h"
+/*#include	"curs.h"*/
+#include	"menu.h"
+/*#include	"amenu.h"*/
+/*#include	"request.h"*/
+/*#include	"gfile.h"*/
+/*#include	"msg.h"*/
+/*#include	"ver.h"*/
+/*#include	"gmain-prot.h"*/
+#include	"misc-prot.h"
+/*#include	"scene-prot.h"*/
+/*#include	"turn-prot.h"*/
+/*#include	"dun-prot.h"*/
+/*#include	"map-event-prot.h"*/
+/*#include	"town-prot.h"*/
+/*#include	"item-prot.h"*/
+/*#include	"spell-prot.h"*/
+#include	"chr-prot.h"
+#include	"skill-prot.h"
+/*#include	"party-prot.h"*/
+/*#include	"mnstr-prot.h"*/
+/*#include	"pet-prot.h"*/
+/*#include	"fight-prot.h"*/
+/*#include	"fx-prot.h"*/
+/*#include	"trap-prot.h"*/
+/*#include	"replay-prot.h"*/
+#include	"draw-prot.h"
+/*#include	"curs-prot.h"*/
+/*#include	"menu-prot.h"*/
+/*#include	"mmenu-prot.h"*/
+/*#include	"imenu-prot.h"*/
+#include	"tmenu-prot.h"
+/*#include	"amenu-prot.h"*/
+/*#include	"request-prot.h"*/
+/*#include	"gfile-prot.h"*/
+/*#include	"msg-prot.h"*/
+
+#ifdef D_WS
+#endif /* D_WS */
+
+#ifdef D_GTK
+# include <gtk/gtk.h>
+# include "GuiMisc.h"
+#endif /* D_GTK */
+
+#ifdef D_MFC
+# include "xlnl-dows/stdafx.h"
+# include "xlnl-dows/xlnl-dows.h"
+# include "xlnl-dows/SkillEditDlg.h"
+#endif // D_MFC
+
+#include "GuiSkillEdit.h"
+#include "GlobalVar.h"
+
+#ifdef D_GTK
+# include "main-gtk-prot.h"
+#endif /* D_GTK */
+
+#endif	/* GUI_SKILL_EDIT_CPP */
+
+/***************************************************************/
+
 #ifdef	GUI_CHR_SHEET_CPP
 
 #include	"gmain.h"
@@ -3559,6 +4172,7 @@
 #include	"item.h"
 /*#include	"spell.h"*/
 #include	"chr.h"
+#include	"skill.h"
 #include	"party.h"
 /*#include	"mnstr.h"*/
 /*#include	"pet.h"*/
@@ -3584,6 +4198,7 @@
 #include	"item-prot.h"
 /*#include	"spell-prot.h"*/
 #include	"chr-prot.h"
+#include	"skill-prot.h"
 #include	"party-prot.h"
 /*#include	"mnstr-prot.h"*/
 /*#include	"pet-prot.h"*/
@@ -3635,6 +4250,7 @@
 /*#include	"item.h"*/
 /*#include	"spell.h"*/
 /*#include	"chr.h"*/
+/*#include	"skill.h"*/
 /*#include	"party.h"*/
 /*#include	"mnstr.h"*/
 /*#include	"pet.h"*/
@@ -3660,6 +4276,7 @@
 /*#include	"item-prot.h"*/
 /*#include	"spell-prot.h"*/
 /*#include	"chr-prot.h"*/
+/*#include	"skill-prot.h"*/
 /*#include	"party-prot.h"*/
 /*#include	"mnstr-prot.h"*/
 /*#include	"pet-prot.h"*/
