@@ -86,11 +86,35 @@ item_t	*make_item_wpn_rand( long dun_lev );
 item_t	*make_item_wpn( long dun_lev, long n, bool_t curse );
 rate_t	gen_slayer_rate( long dun_lev );
 bool_t	add_slayer( wpn_t *wpn, long dun_lev );
+void	make_item_wpn_randm_art( wpn_t *wpn, long dun_lev );
+void	make_item_wpn_randm_art_n( wpn_t *wpn, long max_n );
+long	gen_wpn_randm_art_n( long dun_lev );
+void	add_wpn_randm_art(
+	wpn_randm_art_kind_t kind,
+	wpn_randm_art_t *art
+);
+void	gen_wpn_randm_art_face(
+	wpn_randm_art_kind_t kind,
+	char *mjr, char *mnr
+);
+bool_t	chk_dup_wpn_randm_art( wpn_t *wpn, long n );
 item_t	*make_item_armor_rand( long dun_lev );
 item_t	*make_item_armor( long dun_lev, long n, bool_t curse );
 rate_t	gen_armor_resi_rate( long dun_lev );
 bool_t	add_armor_resi( item_t *p, long dun_lev, resi_kind_t resi );
 resi_kind_t	gen_armor_resi_kind( long dun_lev );
+void	make_item_armor_randm_art( armor_t *armor, long dun_lev );
+void	make_item_armor_randm_art_n( armor_t *armor, long max_n );
+long	gen_armor_randm_art_n( long dun_lev );
+void	add_armor_randm_art(
+	armor_randm_art_kind_t kind,
+	armor_randm_art_t *art
+);
+void	gen_armor_randm_art_face(
+	armor_randm_art_kind_t kind,
+	char *mjr, char *mnr
+);
+bool_t	chk_dup_armor_randm_art( armor_t *armor, long n );
 item_t	*make_item_potion_rand( long dun_lev );
 item_t	*make_item_potion( long dun_lev, long n );
 item_t	*make_item_scroll_rand( long dun_lev );
@@ -141,12 +165,17 @@ item_t	*make_item_sel(
 	long k1, long k2, long k3,
 	long dun_lev
 );
+bool_t	fx_wish_artifact_wpn( chr_t *chr, wish_level_t wish_level );
+bool_t	fx_wish_artifact_armor( chr_t *chr, wish_level_t wish_level );
 void	set_item_face( item_t *item );
 void	set_item_name( item_t *item );
 bool_t	set_item_name_wpn( item_t *item );
+const char	*get_wpn_randm_art_name( item_t *item );
 bool_t	set_item_name_armor( item_t *item );
+const char	*get_armor_randm_art_name( item_t *item );
 bool_t	set_item_name_potion( item_t *item );
 bool_t	set_item_name_scroll( item_t *item );
+long	get_scroll_nin_lev( scroll_kind_t scroll_kind );
 bool_t	set_item_name_stick( item_t *item );
 bool_t	set_item_name_acce( item_t *item );
 bool_t	set_item_name_inst( item_t *item );
@@ -176,7 +205,16 @@ bool_t	put_item_sub( item_t *item, long x, long y, long *np );
 bool_t	put_item_in_chest( item_t *p, long x, long y );
 bool_t	drop_item( long x, long y, item_t *item, long n );
 bool_t	pick_up_item( mbr_t *mbr, long x, long y );
-bool_t	give_mbr_item( mbr_t *mbr, item_t *item, bool_t flg_force );
+bool_t	give_party_item( item_t *item, bool_t flg_force, bool_t flg_print );
+bool_t	give_mbr_item(
+	mbr_t *mbr, item_t *item,
+	bool_t flg_force
+);
+bool_t	give_mbr_item_print(
+	mbr_t *mbr, item_t *item,
+	bool_t flg_force,
+	bool_t flg_print
+);
 bool_t	give_mbr_item_sub( mbr_t *mbr, item_t *item );
 bool_t	equip_item_sel( mbr_t *mbr, item_t *item );
 bool_t	equip_item( mbr_t *mbr, item_t *item, equip_kind_t kind );
@@ -191,13 +229,25 @@ bool_t	take_off_item( mbr_t *mbr, equip_kind_t kind );
 bool_t	take_off_item_sub( mbr_t *mbr, equip_kind_t kind );
 bool_t	break_item_fragile( item_t *item, bool_t flg_mbr );
 void	break_item_contents( item_t *chest, mbr_t *mbr );
-void	break_item( item_t *item, bool_t flg_mbr );
+bool_t	break_item( item_t *item, bool_t flg_mbr );
+bool_t	chk_can_break_item( item_t *item );
 bool_t	open_item( item_t *item, mbr_t *mbr );
 bool_t	open_item_pos( long x, long y, item_t *item, mbr_t *mbr );
 bool_t	disarm_item( item_t *item );
+void	set_item_alias( item_t *item );
 void	chk_item_data( item_t *item );
 void	chk_item_data_wpn( item_t *item );
+void	chk_item_data_wpn_randm_art_ls( item_t *item );
+void	chk_item_data_wpn_randm_art( wpn_randm_art_t *art );
+const char	*get_wpn_randm_art_add_stat_name( char mnr );
+fx_kind_t	get_wpn_randm_art_add_stat_fx( char mnr );
+const char	*get_wpn_randm_art_drain_name( char mnr );
 void	chk_item_data_armor( item_t *item );
+void	chk_item_data_armor_randm_art_ls( item_t *item );
+void	chk_item_data_armor_randm_art( armor_randm_art_t *art );
+const char	*get_armor_randm_art_resi_stat_name( char mnr );
+const char	*get_armor_randm_art_healing_name( char mnr );
+char	cv_flg_stat_to_armor_randm_art_mnr( flg_stat_t stat );
 rate_t	calc_rate_abl_equip( mbr_t *mbr, abl_kind_t abl );
 bool_t	teleport_item( item_t *item );
 void	detect_item( long x, long y, long r );
@@ -287,6 +337,10 @@ bool_t	chk_item_is_equip( item_t *p );
 bool_t	chk_dagger( const wpn_tab_t *arw_tab );
 bool_t	chk_bow( const wpn_tab_t *arw_tab, const wpn_tab_t *bow_tab );
 long	count_ls_item( item_t *ls, item_kind_t kind );
+void	arrange_item_1( long n, long d );
+void	arrange_item( long n, long d );
+void	arrange_equip_1( long n, long d );
+void	arrange_equip( long n, long d );
 item_t	*get_item_free_next( void );
 item_t	*get_mbr_item_asgn( mbr_t *mbr );
 item_t	*get_mbr_item_asgn_equip( mbr_t *mbr );
@@ -301,6 +355,29 @@ item_t	*get_shop_grocery_item_asgn( void );
 item_t	*get_shop_restaurant_item_asgn( void );
 item_t	*get_shop_tearoom_item_asgn( void );
 item_t	*get_shop_tobacco_item_asgn( void );
+bool_t	chk_wpn_randm_art(
+	wpn_randm_art_kind_t kind,
+	char mnr,
+	chr_t *o_p,
+	chr_t *d_p,
+	bool_t flg_throw
+);
+bool_t	chk_armor_randm_art(
+	armor_randm_art_kind_t kind,
+	char mnr,
+	chr_t *o_p,
+	chr_t *d_p
+);
+bool_t	chk_wpn_randm_art_item(
+	wpn_randm_art_kind_t kind,
+	char mnr,
+	item_t *item
+);
+bool_t	chk_armor_randm_art_item(
+	armor_randm_art_kind_t kind,
+	char mnr,
+	item_t *item
+);
 rate_t	get_resi_armor( mbr_t *p, resi_kind_t resi );
 bool_t	chk_wear_armor( mbr_t *mbr );
 spell_kind_t	get_inst_spell_kind( mbr_t *mbr );
