@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: main-gtk.cpp,v 1.62 2009/01/04 00:26:03 bowkenken Exp $
+* $Id: main-gtk.cpp,v 1.63 2009/05/13 23:37:14 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -698,29 +698,6 @@ gint	handle_map_draw( gpointer p )
 {
 	gJoystick.checkEvent();
 
-#if 0
-//@@@
-	GtkWidget *drawingArea = (GtkWidget *)p;
-	GdkGC *gc = drawingArea->style->fg_gc[GTK_STATE_NORMAL];
-
-	GtkAdjustment *hAdj = GTK_ADJUSTMENT( gMapHScrollBarAdjustment );
-	GtkAdjustment *vAdj = GTK_ADJUSTMENT( gMapVScrollBarAdjustment );
-
-	long x = (long)hAdj->value;
-	long y = (long)vAdj->value;
-	long w = (long)hAdj->page_size;
-	long h = (long)vAdj->page_size;
-
-	// طʤ
-
-	gdk_draw_pixmap(
-			drawingArea->window,
-			gc,
-			gPcgDun.getWBuf()->getPixMap(),
-			x, y,
-			0, 0,
-			w, h );
-#else
 	if( get_scene() == SCENE_N_LAST_BOSS ){
 		if( !gPcgDun.drawLastBoss() )
 			return TRUE;
@@ -730,9 +707,11 @@ gint	handle_map_draw( gpointer p )
 		gPcgDun.drawEnding();
 	} else if( chk_scene_group( SCENE_GROUP_N_GAME_OVER ) ){
 		gPcgDun.drawGameOver();
+#if	0
 	} else if( chk_scene_group( SCENE_GROUP_N_SEL_GRAPH ) ){
 		if( gSelMbrGraph != NULL )
 			gSelMbrGraph->redraw();
+#endif
 	} else {
 		return TRUE;
 	}
@@ -744,7 +723,6 @@ gint	handle_map_draw( gpointer p )
 	rect.width = drawingArea->allocation.width;
 	rect.height = drawingArea->allocation.height;
 	gtk_widget_draw( GTK_WIDGET( drawingArea ), &rect );
-#endif
 
 	return TRUE;
 }
