@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: mmenu-tab.h,v 1.31 2008/09/08 01:20:12 bowkenken Exp $
+* $Id: mmenu-tab.h,v 1.44 2009/02/15 01:59:38 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	MMENU_TAB_H
@@ -34,6 +34,7 @@
 /* ᥤ󡦥˥塼 */
 
 #include	"request.h"
+#include	"joy-kind.h"
 
 #include	"request-prot.h"
 
@@ -95,9 +96,9 @@ menu_t	ls_menu_main_race[] = {
 		FLG_NULL,
 	},
 	{
-		"/main race/bibit",
+		"/main race/vivid",
 		"<Item>",
-		'B',
+		'V',
 		"",
 		N_MSG_MAIN_RACE_VIVID, "",
 		cb_menu_main_race, (void *)MAIN_RACE_VIVID,
@@ -431,6 +432,15 @@ menu_t	ls_menu_main[] = {
 		cb_menu_ls_msg, NULL,
 		FLG_NULL,
 	},
+	{
+		"/misc/info/list key item",
+		"<Item>",
+		'K',
+		"",
+		N_MSG_MENU_LS_KEY_ITEM, "",
+		cb_menu_ls_key_item, NULL,
+		FLG_NULL,
+	},
 	{
 		"/misc/info/list monster",
 		"<Item>",
@@ -485,6 +495,15 @@ menu_t	ls_menu_main[] = {
 		cb_menu_stairs_down, NULL,
 		FLG_NULL,
 	},
+	{
+		"/misc/stairs/last boss",
+		"<Item>",
+		'D',
+		"",
+		N_MSG_MENU_STAIRS_LAST_BOSS, "",
+		cb_menu_stairs_last_boss, NULL,
+		FLG_NULL,
+	},
 	{
 		"/misc/search",
 		"<Branch>",
@@ -1030,6 +1049,78 @@ menu_t	ls_menu_main[] = {
 		cb_menu_func, NULL,
 		FLG_NULL,
 	},
+	{
+		"/misc/config/gui",
+		"<Branch>",
+		'G',
+		"",
+		N_MSG_MENU_GUI, "",
+		NULL, NULL,
+		FLG_NULL,
+	},
+	{
+		"/misc/config/gui/replay music",
+		"<Item>",
+		'M',
+		"p",
+		N_MSG_MENU_REPLAY_MUSIC, "",
+		cb_menu_replay_music, NULL,
+		FLG_NULL,
+	},
+	{
+		"/misc/config/gui/joystick",
+		"<Branch>",
+		'J',
+		"",
+		N_MSG_MENU_JOYSTICK, "",
+		NULL, NULL,
+		FLG_NULL,
+	},
+	{
+		"/misc/config/gui/joystick/select joystick",
+		"<Branch>",
+		'D',
+		"",
+		N_MSG_MENU_JOYSTICK_SEL_N, "",
+		cb_menu_joystick_sel_n_init, NULL,
+		FLG_NULL,
+	},
+	{
+		"/misc/config/gui/joystick/select kind",
+		"<Branch>",
+		'T',
+		"",
+		N_MSG_MENU_JOYSTICK_SEL_KIND, "",
+		cb_menu_joystick_sel_kind_init, NULL,
+		FLG_NULL,
+	},
+	{
+		"/misc/config/gui/joystick/select kind/ps",
+		"<RadioItem>",
+		'P',
+		"",
+		N_MSG_MENU_JOYSTICK_PS, "",
+		cb_menu_joystick_sel_kind, (void *)JOY_KIND_PS,
+		FLG_NULL,
+	},
+	{
+		"/misc/config/gui/joystick/select kind/saturn",
+		"<RadioItem>",
+		'S',
+		"",
+		N_MSG_MENU_JOYSTICK_SATURN, "",
+		cb_menu_joystick_sel_kind, (void *)JOY_KIND_SATURN,
+		FLG_NULL,
+	},
+	{
+		"/misc/config/gui/joystick/select kind/rap3",
+		"<RadioItem>",
+		'R',
+		"",
+		N_MSG_MENU_JOYSTICK_RAP3, "",
+		cb_menu_joystick_sel_kind, (void *)JOY_KIND_RAP3,
+		FLG_NULL,
+	},
 	{
 		"/misc/config/user menu select",
 		"<Branch>",
@@ -1215,6 +1306,69 @@ menu_t	ls_menu_main[] = {
 		NULL, NULL,
 		FLG_NULL,
 	},
+	{
+		"/misc/system/wizard/scene/last boss",
+		"<Branch>",
+		'L',
+		"",
+		N_MSG_MENU_WIZARD_SCENE_LAST_BOSS, "",
+		NULL, NULL,
+		FLG_NULL,
+	},
+	{
+		"/misc/system/wizard/scene/last boss/enter",
+		"<Item>",
+		'A',
+		"",
+		N_MSG_MENU_WIZARD_LAST_SCENE_ENTER, "",
+		cb_menu_wizard_last_scene, (void *)LAST_SCENE_N_ENTER,
+		FLG_NULL,
+	},
+	{
+		"/misc/system/wizard/scene/last boss/encounter",
+		"<Item>",
+		'B',
+		"",
+		N_MSG_MENU_WIZARD_LAST_SCENE_ENCOUNTER, "",
+		cb_menu_wizard_last_scene, (void *)LAST_SCENE_N_ENCOUNTER,
+		FLG_NULL,
+	},
+	{
+		"/misc/system/wizard/scene/last boss/exel",
+		"<Item>",
+		'C',
+		"",
+		N_MSG_MENU_WIZARD_LAST_SCENE_EXEL, "",
+		cb_menu_wizard_last_scene, (void *)LAST_SCENE_N_EXEL,
+		FLG_NULL,
+	},
+	{
+		"/misc/system/wizard/scene/last boss/exeler",
+		"<Item>",
+		'D',
+		"",
+		N_MSG_MENU_WIZARD_LAST_SCENE_EXELER, "",
+		cb_menu_wizard_last_scene, (void *)LAST_SCENE_N_EXELER,
+		FLG_NULL,
+	},
+	{
+		"/misc/system/wizard/scene/last boss/xex",
+		"<Item>",
+		'E',
+		"",
+		N_MSG_MENU_WIZARD_LAST_SCENE_XEX, "",
+		cb_menu_wizard_last_scene, (void *)LAST_SCENE_N_XEX,
+		FLG_NULL,
+	},
+	{
+		"/misc/system/wizard/scene/last boss/xx",
+		"<Item>",
+		'F',
+		"",
+		N_MSG_MENU_WIZARD_LAST_SCENE_XX, "",
+		cb_menu_wizard_last_scene, (void *)LAST_SCENE_N_XX_WORDS,
+		FLG_NULL,
+	},
 	{
 		"/misc/system/wizard/scene/game over",
 		"<Item>",
@@ -1225,7 +1379,7 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/misc/system/wizard/scene/game over",
+		"/misc/system/wizard/scene/ending",
 		"<Item>",
 		'E',
 		"",
@@ -1892,6 +2046,15 @@ menu_t	ls_menu_item_sel[] = {
 		cb_menu_item_drop, (void *)ACT_KIND_ITEM_DROP,
 		FLG_NULL,
 	},
+	{
+		"/item sel/alias",
+		"<OpenWinItem>",
+		'N',
+		"",
+		N_MSG_MENU_ITEM_ALIAS, "",
+		cb_menu_item_alias, (void *)ACT_KIND_NULL,
+		FLG_NULL,
+	},
 	{
 		"/item sel/check",
 		"<Item>",
