@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: tmenu.c,v 1.120 2008/04/16 16:12:34 bowkenken Exp $
+* $Id: tmenu.c,v 1.143 2009/05/14 00:26:39 bowkenken Exp $
 ***************************************************************/
 
 #define	TMENU_C
@@ -53,7 +53,7 @@
 		/ LS_MBR_MAX_N_PER_PAGE)
 
 #define	ORDER_MILK_MAX_LEV	100
-#define	ORDER_MILK_MIN_RATE	((rate_t)1)
+#define	ORDER_MILK_MIN_RATE	((rate_t)10)
 #define	ORDER_MILK_MAX_RATE	((rate_t)_100_PERCENT)
 
 /**/
@@ -74,6 +74,10 @@ static menu_t	*g_navi_dflt;
 /**/
 
 static edit_class_t	static_exec_edit_class__n;
+static edit_skill_t	static_exec_edit_skill__n;
+
+skill_kind_t	g_sel_skill_kind;
+edit_skill_t	g_skill_slot_n;
 
 /**/
 
@@ -88,6 +92,9 @@ void	init_town_menu( void )
 	g_sel_class_n = 0;
 
 	g_navi_dflt = NULL;
+
+	g_sel_skill_kind = SKILL_KIND_NULL;
+	g_skill_slot_n = EDIT_SKILL_NEXT;
 }
 
 /***************************************************************
@@ -115,6 +122,7 @@ void	reset_static_town_menu( void )
 	/**/
 
 	static_exec_edit_class__n = EDIT_CLASS_NEXT;
+	static_exec_edit_skill__n = EDIT_SKILL_NEXT;
 }
 
 /**/
@@ -135,7 +143,7 @@ char	*menu_shop_sel_mbr( shop_n_t shop_n, bool_t flg_pet )
 		char	ttl[MENU_MSG_MAX_LEN + 1];
 		char	*str_goto;
 
-		sprintf( ttl, MSG_MENU_SHOP_SEL_MBR,
+		sn_printf( ttl, MENU_MSG_MAX_LEN, MSG_MENU_SHOP_SEL_MBR,
 				get_shop_name( g_shop_n ) );
 
 		str_goto = exec_menu_sel_mbr(
@@ -191,22 +199,22 @@ char	*menu_shop_sel_mbr( shop_n_t shop_n, bool_t flg_pet )
 
 char	*cb_menu_temple_init( menu_t **pp, menu_t **dflt )
 {
-	long	len;
+	long	len, max_len;
 	menu_t	*p;
 	gold_t	price;
 
-	len = 0;
+	max_len = 1;
 	for( p = *pp; p->path[0] != '\0'; p++ ){
 		long	tmp_len;
 
 		tmp_len = str_len_std( MSG( p->n_msg ) );
-		len = max_l( len, tmp_len );
+		max_len = max_l( max_len, tmp_len );
 	}
 
 	p = srch_menu( *pp, "title" );
 	if( p == NULL )
 		return STR_MENU_ERR;
-	sprintf( p->msg, MSG_TTL_MENU_TEMPLE,
+	sn_printf( p->msg, MENU_MSG_MAX_LEN, MSG_TTL_MENU_TEMPLE,
 			get_shop_name( SHOP_N_TEMPLE ),
 			g_sel_mbr->name, fmt_gold( g_sel_mbr->gold ) );
 
@@ -214,21 +222,24 @@ char	*cb_menu_temple_init( menu_t **pp, menu_t **dflt )
 	p = srch_menu( *pp, "remove curse" );
 	if( p == NULL )
 		return STR_MENU_ERR;
-	sprintf( p->msg, MSG_FMT_MENU_TEMPLE,
+	len = get_pading_len( MSG( p->n_msg ), max_len );
+	sn_printf( p->msg, MENU_MSG_MAX_LEN, MSG_FMT_MENU_TEMPLE,
 			len, MSG( p->n_msg ), fmt_gold( price ) );
 
 	price = get_price_temple_cure_status( g_sel_mbr );
 	p = srch_menu( *pp, "cure status" );
 	if( p == NULL )
 		return STR_MENU_ERR;
-	sprintf( p->msg, MSG_FMT_MENU_TEMPLE,
+	len = get_pading_len( MSG( p->n_msg ), max_len );
+	sn_printf( p->msg, MENU_MSG_MAX_LEN, MSG_FMT_MENU_TEMPLE,
 			len, MSG( p->n_msg ), fmt_gold( price ) );
 
 	price = get_price_temple_resurrection( g_sel_mbr );
 	p = srch_menu( *pp, "resurrection" );
 	if( p == NULL )
 		return STR_MENU_ERR;
-	sprintf( p->msg, MSG_FMT_MENU_TEMPLE,
+	len = get_pading_len( MSG( p->n_msg ), max_len );
+	sn_printf( p->msg, MENU_MSG_MAX_LEN, MSG_FMT_MENU_TEMPLE,
 			len, MSG( p->n_msg ), fmt_gold( price ) );
 
 	return NULL;
@@ -264,6 +275,8 @@ char	*cb_menu_temple_remove_curse( menu_t **pp, menu_t **dflt )
 		return STR_MENU_ERR;
 	}
 
+	call_game_music_play( MUSIC_KIND_EFFECT, ME_KIND_TEMPLE );
+
 	if( remove_curse( NULL, g_sel_mbr, 0 ) ){
 		add_chr_gold( chr_pay, -price );
 
@@ -309,6 +322,8 @@ char	*cb_menu_temple_cure_status( menu_t **pp, menu_t **dflt )
 		return STR_MENU_ERR;
 	}
 
+	call_game_music_play( MUSIC_KIND_EFFECT, ME_KIND_TEMPLE );
+
 	if( fx_cure_all_stat( g_sel_mbr ) ){
 		add_chr_gold( chr_pay, -price );
 
@@ -359,6 +374,8 @@ char	*cb_menu_temple_resurrection( menu_t **pp, menu_t **dflt )
 		return STR_MENU_ERR;
 	}
 
+	call_game_music_play( MUSIC_KIND_EFFECT, ME_KIND_TEMPLE );
+
 	if( !chk_flg( g_sel_mbr->stat, FLG_STAT_DEAD ) ){
 		print_msg( FLG_MSG_ERR,
 				MSG_MENU_RESURRECTION_ERR,
@@ -414,6 +431,8 @@ char	*cb_menu_temple_contribution( menu_t **pp, menu_t **dflt )
 		return STR_MENU_ERR;
 	}
 
+	call_game_music_play( MUSIC_KIND_EFFECT, ME_KIND_TEMPLE );
+
 	add_chr_gold( chr_pay, -price );
 	print_msg( FLG_NULL, MSG_MENU_CONTRIBUTION,
 			g_sel_mbr->name, fmt_gold( price ) );
@@ -433,11 +452,11 @@ char	*menu_restaurant( void )
 
 /**/
 
-bool_t	chk_shop_order( shop_n_t g_shop_n )
+bool_t	chk_shop_order( shop_n_t shop_n )
 {
-	if( g_shop_n == SHOP_N_BAR )
+	if( shop_n == SHOP_N_BAR )
 		return TRUE;
-	if( g_shop_n == SHOP_N_RESTAURANT )
+	if( shop_n == SHOP_N_RESTAURANT )
 		return TRUE;
 
 	return FALSE;
@@ -457,6 +476,8 @@ char	*menu_order( void )
 		g_mbr_order[i] = NULL;
 
 	while( 1 ){
+		next_g_sel_mbr( FALSE );
+
 		str_goto = menu_order_sel_mbr();
 		if( str_goto != NULL ){
 			if( strcmp( str_goto, STR_MENU_ERR ) == 0 )
@@ -520,7 +541,7 @@ char	*menu_order_sel_mbr( void )
 		if( (g_sel_mbr != NULL) && (g_sel_mbr->mbr_n == i) )
 			dflt = &(p[k]);
 
-		sprintf( p[k].path, "/order/%ld", i );
+		sn_printf( p[k].path, MENU_PATH_MAX_LEN, "/order/%ld", i );
 		str_nz_cpy( p[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
 		p[k].accel_key = (char)('A' + i);
 		p[k].short_key[0] = '\0';
@@ -528,7 +549,8 @@ char	*menu_order_sel_mbr( void )
 			name = MSG_MENU_ORDER_NULL;
 		else
 			name = g_mbr_order[i]->name;
-		sprintf( p[k].msg, MSG_MENU_ORDER_MBR, mbr[i]->name, name );
+		sn_printf( p[k].msg, MENU_MSG_MAX_LEN,
+				MSG_MENU_ORDER_MBR, mbr[i]->name, name );
 		p[k].call_back = cb_menu_order_sel;
 		p[k].arg = mbr[i];
 		p[k].flg = FLG_NULL;
@@ -537,6 +559,9 @@ char	*menu_order_sel_mbr( void )
 		mbr_n++;
 	}
 
+	if( g_sel_mbr == NULL )
+		dflt = &(p[k]);
+
 	str_nz_cpy( p[k].path, "/order/chose", MENU_PATH_MAX_LEN );
 	str_nz_cpy( p[k].kind, "<Item>", MENU_KIND_MAX_LEN );
 	p[k].accel_key = 'Z';
@@ -566,18 +591,52 @@ char	*cb_menu_order_sel( menu_t **pp, menu_t **dflt )
 	g_sel_mbr = (mbr_t *)((*pp)->arg);
 
 	str_goto = menu_shop( g_shop_n, g_sel_mbr, NULL );
-	if( strcmp( str_goto, STR_MENU_CANCEL ) == 0 )
-		return STR_MENU_CANCEL;
+	if( str_goto != NULL )
+		if( strcmp( str_goto, STR_MENU_CANCEL ) == 0 )
+			return STR_MENU_CANCEL;
 
 	if( g_sel_mbr == NULL )
 		return STR_MENU_ERR;
-	g_mbr_order[g_sel_mbr->mbr_n] = g_sel_art;
 
+	g_mbr_order[g_sel_mbr->mbr_n] = g_sel_art;
 	return str_goto;
 }
 
 /**/
 
+void	next_g_sel_mbr( bool_t flg_loop )
+{
+	party_t	*pty;
+	long	n, m;
+	long	i;
+
+	pty = get_party();
+	if( g_sel_mbr == NULL )
+		n = 0;
+	else
+		n = g_sel_mbr->mbr_n + 1;
+
+	for( i = 0; i < MBR_MAX_N; i++ ){
+		m = n + i;
+		if( !flg_loop && (m >= MBR_MAX_N) )
+			break;
+		m %= MBR_MAX_N;
+
+		if( chk_flg_or( pty->mbr[m]->stat,
+				FLG_STAT_NOT_EXIST
+				| FLG_STAT_DEAD ) ){
+			continue;
+		}
+
+		g_sel_mbr = pty->mbr[m];
+		return;
+	}
+
+	g_sel_mbr = NULL;
+}
+
+/**/
+
 char	*cb_menu_order_chose( menu_t **pp, menu_t **dflt )
 {
 	party_t	*pty = get_party();
@@ -603,6 +662,7 @@ char	*cb_menu_order_chose( menu_t **pp, menu_t **dflt )
 			continue;
 
 		add_chr_gold( pty->mbr[i], -price );
+		call_game_sound_play( SOUND_KIND_SHOP_DRINK, 2 );
 
 		tmp = alloc_item();
 		if( tmp == NULL )
@@ -754,7 +814,8 @@ char	*menu_shop( shop_n_t shop_n, mbr_t *mbr, char *str_goto )
 					MENU_KIND_MAX_LEN );
 			ls[k].accel_key = '\0';
 			ls[k].short_key[0] = '\0';
-			sprintf( ls[k].msg,
+			sn_printf( ls[k].msg,
+					MENU_MSG_MAX_LEN,
 					MSG_FMT_MENU_SHOP,
 					get_shop_name( shop_n ),
 					mbr->name, buy_sale,
@@ -777,7 +838,8 @@ char	*menu_shop( shop_n_t shop_n, mbr_t *mbr, char *str_goto )
 		if( art == g_sel_art )
 			dflt = &(ls[k]);
 
-		sprintf( ls[k].path, "/shop/%ld", key_n );
+		sn_printf( ls[k].path, MENU_PATH_MAX_LEN,
+				"/shop/%ld", key_n );
 		str_nz_cpy( ls[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
 		ls[k].accel_key = (char)('A' + key_n);
 		ls[k].short_key[0] = '\0';
@@ -803,7 +865,8 @@ char	*menu_shop( shop_n_t shop_n, mbr_t *mbr, char *str_goto )
 				MENU_KIND_MAX_LEN );
 		ls[k].accel_key = '\0';
 		ls[k].short_key[0] = '\0';
-		sprintf( ls[k].msg,
+		sn_printf( ls[k].msg,
+				MENU_MSG_MAX_LEN,
 				MSG_FMT_MENU_SHOP,
 				get_shop_name( shop_n ),
 				mbr->name, buy_sale,
@@ -824,7 +887,8 @@ char	*menu_shop( shop_n_t shop_n, mbr_t *mbr, char *str_goto )
 		if( ls[i].arg == NULL )
 			continue;
 
-		sprintf( ls[i].msg,
+		sn_printf( ls[i].msg,
+				MENU_MSG_MAX_LEN,
 				MSG_FMT_ART_NAME,
 				max_len, ls_art[j]->art_name,
 				fmt_gold( get_price(
@@ -1090,6 +1154,7 @@ char	*cb_menu_shop( menu_t **pp, menu_t **dflt )
 
 		add_chr_gold( g_sel_mbr, +(price * deal_n / n) );
 	}
+	call_game_sound_play( SOUND_KIND_SHOP_PAY, 1 );
 
 	return "/shop";
 }
@@ -1140,7 +1205,7 @@ long	menu_shop_buy(
 		return 0;
 
 	/* 㤦ǧ */
-	ask = exec_menu_ask( MSG_TTL_MENU_BUY, ASK_NO, TRUE );
+	ask = exec_menu_ask_no_msg( MSG_TTL_MENU_BUY, ASK_NO, TRUE );
 	switch( ask ){
 	case ASK_YES:
 		break;
@@ -1212,7 +1277,8 @@ long	menu_shop_sale(
 
 		/* 뤫ǧ */
 
-		ask = exec_menu_ask( MSG_TTL_MENU_SALE, ASK_NO, TRUE );
+		ask = exec_menu_ask_no_msg( MSG_TTL_MENU_SALE,
+				ASK_NO, TRUE );
 		switch( ask ){
 		case ASK_YES:
 			break;
@@ -1235,6 +1301,8 @@ long	menu_shop_sale(
 	case SHOP_N_RESTAURANT:
 	case SHOP_N_TEAROOM:
 	case SHOP_N_TOBACCO:
+		print_msg( FLG_MSG_NO_MORE_PREV | FLG_MSG_NO_MORE_NEXT,
+				MSG_NO_DEAL, item->name );
 		return 0;
 	case SHOP_N_TEMPLE:
 		asgn = get_shop_temple_item_asgn();
@@ -1615,7 +1683,8 @@ char	*cb_menu_bar_form( menu_t **pp, menu_t **dflt )
 				break;
 			}
 
-			sprintf( p[k].path, "/bar form/%ld", ls_mbr_n );
+			sn_printf( p[k].path, MENU_PATH_MAX_LEN,
+					"/bar form/%ld", ls_mbr_n );
 			str_nz_cpy( p[k].kind, "<CheckItem>",
 					MENU_KIND_MAX_LEN );
 			p[k].accel_key = (char)('A' + j);
@@ -1710,7 +1779,8 @@ char	*cb_menu_bar_form_sub_init( menu_t **pp, menu_t **dflt )
 
 	clr_flg_menu( *pp, NULL, FLG_MENU_ALL );
 
-	sprintf( sub_path, "%ld", g_sel_ls_mbr->ls_mbr_n );
+	sn_printf( sub_path, MENU_PATH_MAX_LEN,
+			"%ld", g_sel_ls_mbr->ls_mbr_n );
 
 	if( g_sel_ls_mbr->mbr_n == MBR_N_NOT_JOIN ){
 		set_chk_off_menu( ls_menu_bar_form, sub_path );
@@ -1762,12 +1832,12 @@ char	*cb_menu_bar_join( menu_t **pp, menu_t **dflt )
 
 	n = 0;
 	for( i = 0; i < MBR_MAX_N; i++ ){
-		sprintf( p[k].path, "/join/%ld", i );
+		sn_printf( p[k].path, MENU_PATH_MAX_LEN, "/join/%ld", i );
 		str_nz_cpy( p[k].kind, "<Item>",
 				MENU_KIND_MAX_LEN );
 		p[k].accel_key = (char)('A' + i);
 		p[k].short_key[0] = '\0';
-		sprintf( p[k].msg, "%ld", i + 1 );
+		sn_printf( p[k].msg, MENU_MSG_MAX_LEN, "%ld", i + 1 );
 		p[k].call_back = cb_menu_bar_join_sub;
 		p[k].arg = (void *)i;
 		p[k].flg = FLG_NULL;
@@ -1825,7 +1895,8 @@ char	*cb_menu_bar_join_sub( menu_t **pp, menu_t **dflt )
 	mbr_n = (long)((*pp)->arg);
 	join_mbr( g_sel_ls_mbr->ls_mbr_n, mbr_n );
 
-	sprintf( sub_path, "%ld", g_sel_ls_mbr->ls_mbr_n );
+	sn_printf( sub_path, MENU_PATH_MAX_LEN,
+			"%ld", g_sel_ls_mbr->ls_mbr_n );
 	set_chk_off_menu( ls_menu_bar_form, sub_path );
 
 	next_g_sel_ls_mbr();
@@ -1844,7 +1915,8 @@ char	*cb_menu_bar_not_join( menu_t **pp, menu_t **dflt )
 
 	not_join_mbr( g_sel_ls_mbr->ls_mbr_n, g_sel_ls_mbr->mbr_n );
 
-	sprintf( sub_path, "%ld", g_sel_ls_mbr->ls_mbr_n );
+	sn_printf( sub_path, MENU_PATH_MAX_LEN,
+			"%ld", g_sel_ls_mbr->ls_mbr_n );
 	set_chk_on_menu( ls_menu_bar_form, sub_path );
 
 	next_g_sel_ls_mbr();
@@ -1923,7 +1995,8 @@ char	*cb_menu_bar_edit_mbr( menu_t **pp, menu_t **dflt )
 				break;
 			}
 
-			sprintf( p[k].path, "/edit member/%ld",
+			sn_printf( p[k].path, MENU_PATH_MAX_LEN,
+					"/edit member/%ld",
 					ls_mbr_n );
 			str_nz_cpy( p[k].kind, "<Branch>",
 					MENU_KIND_MAX_LEN );
@@ -1998,7 +2071,8 @@ char	*cb_menu_bar_edit_mbr_sub( menu_t **pp, menu_t **dflt )
 	p = srch_menu( *pp, "title" );
 	if( p == NULL )
 		return STR_MENU_ERR;
-	sprintf( p->msg, MSG_TTL_MENU_BAR_EDIT_MBR_SUB,
+	sn_printf( p->msg, MENU_MSG_MAX_LEN,
+			MSG_TTL_MENU_BAR_EDIT_MBR_SUB,
 			g_sel_ls_mbr->name );
 
 	return NULL;
@@ -2024,6 +2098,20 @@ char	*cb_menu_bar_data_edit( menu_t **pp, menu_t **dflt )
 
 /**/
 
+char	*cb_menu_bar_arrange_up( menu_t **pp, menu_t **dflt )
+{
+	return cb_menu_bar_arrange_1( -1 );
+}
+
+/**/
+
+char	*cb_menu_bar_arrange_down( menu_t **pp, menu_t **dflt )
+{
+	return cb_menu_bar_arrange_1( +1 );
+}
+
+/**/
+
 char	*cb_menu_bar_arrange_top( menu_t **pp, menu_t **dflt )
 {
 	return cb_menu_bar_arrange( -1 );
@@ -2038,6 +2126,46 @@ char	*cb_menu_bar_arrange_bottom( menu_t **pp, menu_t **dflt )
 
 /**/
 
+char	*cb_menu_bar_arrange_1( long d )
+{
+	long	trgt_ls_mbr_n;
+	mbr_t	**ls_mbr, *tmp_mbr;
+
+	if( g_sel_ls_mbr == NULL )
+		return STR_MENU_ERR;
+
+	ls_mbr = get_ls_mbr();
+	trgt_ls_mbr_n = g_sel_ls_mbr->ls_mbr_n;
+	if( (trgt_ls_mbr_n + d) < 0 )
+		return "/bar/form/edit member/edit member";
+	if( (trgt_ls_mbr_n + d) >= LS_MBR_MAX_N )
+		return "/bar/form/edit member/edit member";
+	if( chk_flg( ls_mbr[trgt_ls_mbr_n + d]->stat,
+			FLG_STAT_NOT_EXIST ) ){
+		return "/bar/form/edit member/edit member";
+	}
+
+	arrange_cast_tab_1( trgt_ls_mbr_n, d );
+	arrange_auto_mark_mbr_1( trgt_ls_mbr_n, d );
+	arrange_item_1( trgt_ls_mbr_n, d );
+	arrange_equip_1( trgt_ls_mbr_n, d );
+
+	/**/
+
+	tmp_mbr = ls_mbr[trgt_ls_mbr_n];
+
+	ls_mbr[trgt_ls_mbr_n] = ls_mbr[trgt_ls_mbr_n + d];
+	ls_mbr[trgt_ls_mbr_n]->ls_mbr_n = trgt_ls_mbr_n;
+
+	ls_mbr[trgt_ls_mbr_n + d] = tmp_mbr;
+	ls_mbr[trgt_ls_mbr_n + d]->ls_mbr_n = trgt_ls_mbr_n + d;
+
+	g_sel_ls_mbr = ls_mbr[0];
+	return "/bar/form/edit member/edit member";
+}
+
+/**/
+
 char	*cb_menu_bar_arrange( long d )
 {
 	long	trgt_ls_mbr_n;
@@ -2052,6 +2180,8 @@ char	*cb_menu_bar_arrange( long d )
 
 	arrange_cast_tab( trgt_ls_mbr_n, d );
 	arrange_auto_mark_mbr( trgt_ls_mbr_n, d );
+	arrange_item( trgt_ls_mbr_n, d );
+	arrange_equip( trgt_ls_mbr_n, d );
 
 	tmp_mbr = g_sel_ls_mbr;
 	if( d <= -1 ){
@@ -2124,8 +2254,8 @@ bool_t	exec_menu_new_mbr( void )
 		menu_mbr_data( ls_mbr[n], &page_n, &data_n,
 				MBR_DATA_EDIT_KIND_NEW );
 
-		ask = exec_menu_ask(
-				MSG_TTL_MENU_ASK_NEW_MBR, ASK_NO, TRUE );
+		ask = exec_menu_ask( MSG_TTL_MENU_ASK_NEW_MBR,
+				ASK_NO, TRUE );
 		if( (ask == ASK_YES) || (ask == ASK_NO) )
 			break;
 		if( ask == ASK_ERR )
@@ -2139,6 +2269,8 @@ bool_t	exec_menu_new_mbr( void )
 	ls_mbr[n]->fx.prev = &(ls_mbr[n]->fx);
 	ls_mbr[n]->fx.next = &(ls_mbr[n]->fx);
 
+	call_pcg_dun_reload_all_mbr();
+
 	return TRUE;
 }
 
@@ -2194,7 +2326,8 @@ char	*cb_menu_bar_remove_mbr( menu_t **pp, menu_t **dflt )
 				break;
 			}
 
-			sprintf( p[k].path, "/bar remove member/%ld",
+			sn_printf( p[k].path, MENU_PATH_MAX_LEN,
+					"/bar remove member/%ld",
 					ls_mbr_n );
 			str_nz_cpy( p[k].kind, "<OpenWinItem>",
 					MENU_KIND_MAX_LEN );
@@ -2336,6 +2469,24 @@ char	*menu_edit_class( long n )
 
 /**/
 
+char	*cb_menu_bar_arrange_up_class( menu_t **pp, menu_t **dflt )
+{
+	arrange_class_1( g_sel_class_n, -1 );
+
+	return NULL;
+}
+
+/**/
+
+char	*cb_menu_bar_arrange_down_class( menu_t **pp, menu_t **dflt )
+{
+	arrange_class_1( g_sel_class_n, +1 );
+
+	return NULL;
+}
+
+/**/
+
 char	*cb_menu_bar_arrange_top_class( menu_t **pp, menu_t **dflt )
 {
 	arrange_class( g_sel_class_n, -1 );
@@ -2354,10 +2505,59 @@ char	*cb_menu_bar_arrange_bottom_class( menu_t **pp, menu_t **dflt )
 
 /**/
 
+char	*cb_menu_bar_edit_skill( menu_t **pp, menu_t **dflt )
+{
+	char	*str_goto;
+
+	while( 1 ){
+		str_goto = exec_menu_class( &g_sel_class_n );
+		if( str_goto != NULL )
+			return str_goto;
+
+		menu_edit_skill( g_sel_class_n );
+	}
+}
+
+/**/
+
+char	*menu_edit_skill( long n )
+{
+	class_t	*p;
+	long	add;
+
+	p = get_class_tab();
+	if( p == NULL )
+		return STR_MENU_ERR;
+
+	while( 1 ){
+		add = exec_edit_skill( &(p[n]), FALSE );
+		if( add == 0 )
+			break;
+
+		if( add > 0 ){
+			n++;
+			if( p[n].name[0] == '\0' )
+				n = 0;
+		} else {
+			n--;
+			if( n < 0 ){
+				for( n = 0; n < CLASS_MAX_N; n++ )
+					if( p[n + 1].name[0] == '\0' )
+						break;
+			}
+		}
+	}
+
+	return NULL;
+}
+
+/**/
+
 char	*cb_menu_bar_new_class( menu_t **pp, menu_t **dflt )
 {
 	class_t	*p;
 	long	n;
+	long	i;
 
 	p = get_class_tab();
 	if( p == NULL )
@@ -2372,6 +2572,10 @@ char	*cb_menu_bar_new_class( menu_t **pp, menu_t **dflt )
 	}
 
 	str_nz_cpy( p[n].name, MSG_MENU_NEW_CLASS, CLASS_NAME_MAX_LEN );
+	for( i = 0; i < ABL_KIND_MAX_N; i++ )
+		p[n].abl_rate[i] = (rate_t)0;
+	for( i = 0; i < SKILL_MAX_N; i++ )
+		p[n].skill[i] = SKILL_KIND_NULL;
 
 	menu_new_class( n );
 
@@ -2430,17 +2634,24 @@ long	exec_edit_class( class_t *org, bool_t flg_new )
 		draw_edit_class( org, work, n, TRUE, flg_sel_add );
 		prev_n = n;
 
+		call_gui_class_edit_draw( work );
+
 		switch( get_key( g_flg_clr_key_buf_menu ) ){
 		case CASE_CANCEL:
 		case CASE_EXEC:
-			if( exec_menu_ask_edit_class( org, work, flg_new ) )
+			if( exec_menu_ask_edit_class(
+					org, work, flg_new ) ){
+				call_gui_class_edit_wipe();
+				static_exec_edit_class__n = n;
 				return 0;
+			}
 			draw_edit_class_all( org, work, n, flg_sel_add );
 			break;
 		case CASE_ENTER:
 			if( n == EDIT_CLASS_NEXT ){
 				if( exec_menu_ask_edit_class(
 						org, work, flg_new ) ){
+					static_exec_edit_class__n = n;
 					return +1;
 				}
 				draw_edit_class_all( org, work, n,
@@ -2449,6 +2660,7 @@ long	exec_edit_class( class_t *org, bool_t flg_new )
 			} else if( n == EDIT_CLASS_PREV ){
 				if( exec_menu_ask_edit_class(
 						org, work, flg_new ) ){
+					static_exec_edit_class__n = n;
 					return -1;
 				}
 				draw_edit_class_all( org, work, n,
@@ -2480,16 +2692,280 @@ long	exec_edit_class( class_t *org, bool_t flg_new )
 		case CASE_CRSR_UP:
 			n = (edit_class_t)(n - 1);
 			break;
+		case 'g':
+			exec_back_log();
+			break;
 		default:
 			break;
 		}
 	}
 
+	static_exec_edit_class__n = n;
 	return 0;
 }
 
 /**/
 
+long	exec_edit_skill( class_t *org, bool_t flg_new )
+{
+	edit_skill_t	*pn, prev_n;
+	class_t	edit, *work;
+	long	slot;
+
+	g_skill_slot_n = static_exec_edit_skill__n;
+
+	if( org == NULL )
+		return 0;
+
+	work = &edit;
+	*work = *org;
+
+	pn = &g_skill_slot_n;
+	prev_n = *pn;
+
+	draw_edit_skill_all( org, work, *pn );
+
+	while( 1 ){
+		if( *pn > EDIT_SKILL_MAX_N - 1 )
+			*pn = (edit_skill_t)(EDIT_SKILL_NULL + 1);
+		if( *pn < EDIT_SKILL_NULL + 1 )
+			*pn = (edit_skill_t)(EDIT_SKILL_MAX_N - 1);
+
+		draw_edit_skill( org, work, prev_n, FALSE );
+		draw_edit_skill( org, work, *pn, TRUE );
+		prev_n = *pn;
+
+		call_gui_skill_edit_draw( work );
+
+		switch( get_key( g_flg_clr_key_buf_menu ) ){
+		case CASE_CANCEL:
+		case CASE_EXEC:
+			if( exec_menu_ask_edit_skill(
+					org, work, flg_new ) ){
+				call_gui_skill_edit_wipe();
+				static_exec_edit_skill__n = *pn;
+				return 0;
+			}
+			draw_edit_skill_all( org, work, *pn );
+			break;
+		case CASE_ENTER:
+			if( *pn == EDIT_SKILL_NEXT ){
+				if( exec_menu_ask_edit_skill(
+						org, work, flg_new ) ){
+					static_exec_edit_skill__n = *pn;
+					return +1;
+				}
+				draw_edit_skill_all( org, work, *pn );
+				break;
+			} else if( *pn == EDIT_SKILL_PREV ){
+				if( exec_menu_ask_edit_skill(
+						org, work, flg_new ) ){
+					static_exec_edit_skill__n = *pn;
+					return -1;
+				}
+				draw_edit_skill_all( org, work, *pn );
+				break;
+			} else if( *pn == EDIT_SKILL_CLASS_NAME ){
+				draw_edit_skill( org, work, *pn, FALSE );
+				gets_class_name( work->name );
+				break;
+			} else if( (EDIT_SKILL_A_00 <= *pn)
+					&& (*pn <= EDIT_SKILL_A_09) ){
+				slot = *pn - EDIT_SKILL_A_00;
+
+				exec_sel_skill_edit( work, slot );
+				draw_edit_skill_all( org, work, *pn );
+				break;
+			} else if( (EDIT_SKILL_B_00 <= *pn)
+					&& (*pn <= EDIT_SKILL_B_09) ){
+				slot = *pn - EDIT_SKILL_B_00
+						+ SKILL_PER_PAGE_MAX_N;
+
+				exec_sel_skill_edit( work, slot );
+				draw_edit_skill_all( org, work, *pn );
+				break;
+			}
+			break;
+		case CASE_CRSR_LEFT:
+		case CASE_CRSR_RIGHT:
+			break;
+		case CASE_CRSR_DOWN:
+			*pn = (edit_skill_t)(*pn + 1);
+			break;
+		case CASE_CRSR_UP:
+			*pn = (edit_skill_t)(*pn - 1);
+			break;
+		case 'g':
+			exec_back_log();
+			break;
+		default:
+			break;
+		}
+	}
+
+	static_exec_edit_skill__n = *pn;
+	return 0;
+}
+
+/**/
+
+void	set_edit_skill_n( edit_skill_t n )
+{
+	g_skill_slot_n = n;
+}
+
+/**/
+
+edit_skill_t	get_edit_skill_n( void )
+{
+	return g_skill_slot_n;
+}
+
+/**/
+
+char	*exec_sel_skill_edit( class_t *work, long slot )
+{
+	char	*ret;
+	long	i;
+
+	if( work == NULL )
+		return NULL;
+	if( slot < 0 )
+		return NULL;
+	if( slot >= SKILL_MAX_N )
+		return NULL;
+
+	ret = exec_sel_skill( &(work->skill[slot]) );
+
+	if( ret != NULL )
+		return ret;
+	if( work->skill[slot] == SKILL_KIND_NULL )
+		return NULL;
+
+	for( i = 0; i < SKILL_MAX_N; i++ ){
+		if( i == slot )
+			continue;
+
+		if( work->skill[i] == work->skill[slot] )
+			work->skill[i] = SKILL_KIND_NULL;
+	}
+
+	return NULL;
+}
+
+/**/
+
+char	*exec_sel_skill( skill_kind_t *ret_kind )
+{
+	long	i, j, k;
+	menu_t	*p, *dflt;
+	skill_kind_t	kind;
+	char	*ret;
+
+	p = ls_menu_sel_skill;
+	dflt = NULL;
+
+	k = 0;
+	str_nz_cpy( p[k].path, "/select skill",
+			MENU_PATH_MAX_LEN );
+	str_nz_cpy( p[k].kind, "<Branch>",
+			MENU_KIND_MAX_LEN );
+	p[k].accel_key = '\0';
+	p[k].short_key[0] = '\0';
+	p[k].msg[0] = '\0';
+	p[k].call_back = NULL;
+	p[k].arg = NULL;
+	p[k].flg = FLG_NULL;
+	k++;
+
+	for( i = SKILL_GROUP_KIND_NULL + 1;
+			i < SKILL_GROUP_KIND_MAX_N; i++ ){
+		str_nz_cpy( p[k].path, "/select skill/--",
+				MENU_PATH_MAX_LEN );
+		str_nz_cpy( p[k].kind, "<Title>",
+				MENU_KIND_MAX_LEN );
+		p[k].accel_key = '\0';
+		p[k].short_key[0] = '\0';
+		str_nz_cpy( p[k].msg,
+				get_skill_group_name( (skill_group_kind_t)i ),
+				MENU_MSG_MAX_LEN );
+		p[k].call_back = NULL;
+		p[k].arg = NULL;
+		p[k].flg = FLG_NULL;
+		k++;
+
+		kind = SKILL_KIND_NULL;
+		sn_printf( p[k].path, MENU_PATH_MAX_LEN,
+				"/select skill/%ld", k );
+		str_nz_cpy( p[k].kind, "<Item>",
+				MENU_KIND_MAX_LEN );
+		p[k].accel_key = 'Z';
+		p[k].short_key[0] = '\0';
+		str_nz_cpy( p[k].msg,
+				get_skill_name_from_kind( kind ),
+				MENU_MSG_MAX_LEN );
+		p[k].call_back = cb_menu_sel_skill;
+		p[k].arg = (void *)kind;
+		p[k].flg = FLG_NULL;
+		k++;
+
+		for( j = 0; j < SKILL_PER_GROUP_MAX_N; j++ ){
+			kind = get_skill_kind_from_group(
+					(skill_group_kind_t)i, j );
+			if( kind == SKILL_KIND_NULL )
+				break;
+
+			if( kind == g_sel_skill_kind )
+				dflt = &(p[k]);
+
+			sn_printf( p[k].path, MENU_PATH_MAX_LEN,
+					"/select skill/%ld", k );
+			str_nz_cpy( p[k].kind, "<Item>",
+					MENU_KIND_MAX_LEN );
+			p[k].accel_key = (char)('A' + j);
+			p[k].short_key[0] = '\0';
+			str_nz_cpy( p[k].msg,
+					get_skill_name_from_kind( kind ),
+					MENU_MSG_MAX_LEN );
+			p[k].call_back = cb_menu_sel_skill;
+			p[k].arg = (void *)kind;
+			p[k].flg = FLG_NULL;
+			k++;
+		}
+
+		str_nz_cpy( p[k].path, "/select skill/--",
+				MENU_PATH_MAX_LEN );
+		str_nz_cpy( p[k].kind, "<PageSeparator>",
+				MENU_KIND_MAX_LEN );
+		p[k].accel_key = '\0';
+		p[k].short_key[0] = '\0';
+		p[k].msg[0] = '\0';
+		p[k].call_back = NULL;
+		p[k].arg = NULL;
+		p[k].flg = FLG_NULL;
+		k++;
+	}
+	p[k].path[0] = '\0';
+
+	ret = exec_menu( p, dflt, NULL );
+	if( ret != NULL )
+		return ret;
+
+	if( ret_kind != NULL )
+		*ret_kind = g_sel_skill_kind;
+	return NULL;
+}
+
+/**/
+
+char	*cb_menu_sel_skill( menu_t **pp, menu_t **dflt )
+{
+	g_sel_skill_kind = (skill_kind_t)(long)((*pp)->arg);
+	return NULL;
+}
+
+/**/
+
 char	*cb_menu_bar_remove_class( menu_t **pp, menu_t **dflt )
 {
 	long	class_n;
@@ -2576,6 +3052,33 @@ bool_t	exec_menu_ask_edit_class(
 
 /**/
 
+bool_t	exec_menu_ask_edit_skill(
+	class_t *org, class_t *work, bool_t flg_new
+)
+{
+	ask_t	ask;
+
+	if( cmp_class( org, work ) )
+		return TRUE;
+
+	ask = exec_menu_ask( MSG_TTL_MENU_ASK_EDIT_CLASS, ASK_NO, TRUE );
+	switch( ask ){
+	case ASK_YES:
+		*org = *work;
+		break;
+	case ASK_NO:
+		*work = *org;
+		break;
+	case ASK_CANCEL:
+	case ASK_ERR:
+		return FALSE;	/* Cancel */
+	}
+
+	return TRUE;
+}
+
+/**/
+
 void	menu_edit_class_inc_abl(
 	class_t *p, edit_class_t n, long add
 )
@@ -2691,9 +3194,17 @@ char	*cb_menu_save_bar( menu_t **pp, menu_t **dflt )
 
 /**/
 
+void	menu_load_start( void )
+{
+	if( menu_load( FALSE, TRUE ) )
+		reset_all_save( FALSE );
+}
+
+/**/
+
 void	menu_load_bar( void )
 {
-	if( menu_load( FALSE ) )
+	if( menu_load( FALSE, FALSE ) )
 		reset_all_save( FALSE );
 }
 
@@ -2716,7 +3227,7 @@ char	*menu_inn( void )
 	p = srch_menu( ls_menu_inn, "stay" );
 	if( p == NULL )
 		return STR_MENU_ERR;
-	sprintf( p->msg, MSG_MENU_INN_STAY,
+	sn_printf( p->msg, MENU_MSG_MAX_LEN, MSG_MENU_INN_STAY,
 			fmt_gold( get_price_inn( FALSE ) ) );
 
 	/* ٷ */
@@ -2724,7 +3235,7 @@ char	*menu_inn( void )
 	p = srch_menu( ls_menu_inn, "short stay" );
 	if( p == NULL )
 		return STR_MENU_ERR;
-	sprintf( p->msg, MSG_MENU_INN_SHORT_STAY,
+	sn_printf( p->msg, MENU_MSG_MAX_LEN, MSG_MENU_INN_SHORT_STAY,
 			fmt_gold( get_price_inn( TRUE ) ) );
 
 	/* Ͼǰ */
@@ -2732,7 +3243,7 @@ char	*menu_inn( void )
 	p = srch_menu( ls_menu_inn, "stay in mews" );
 	if( p == NULL )
 		return STR_MENU_ERR;
-	sprintf( p->msg, MSG_MENU_INN_STAY_IN_MEWS,
+	sn_printf( p->msg, MENU_MSG_MAX_LEN, MSG_MENU_INN_STAY_IN_MEWS,
 			fmt_gold( 0 ) );
 
 	/**/
@@ -2780,9 +3291,10 @@ char	*cb_menu_inn_stay( menu_t **pp, menu_t **dflt )
 		add_chr_gold( pty->mbr[mbr_n], -price );
 	}
 
+	call_game_music_play( MUSIC_KIND_EFFECT, ME_KIND_INN );
 	stay_inn( flg_short, FALSE );
 
-	return NULL;
+	return STR_MENU_CANCEL;
 }
 
 /**/
@@ -2796,9 +3308,10 @@ char	*cb_menu_inn_short_stay( menu_t **pp, menu_t **dflt )
 
 char	*cb_menu_inn_stay_in_mews( menu_t **pp, menu_t **dflt )
 {
+	call_game_music_play( MUSIC_KIND_EFFECT, ME_KIND_INN );
 	stay_inn( FALSE, TRUE );
 
-	return NULL;
+	return STR_MENU_CANCEL;
 }
 
 /**/
@@ -2842,7 +3355,7 @@ char	*cb_menu_magic_guild_init( menu_t **pp, menu_t **dflt )
 	p = srch_menu( *pp, "title" );
 	if( p == NULL )
 		return STR_MENU_ERR;
-	sprintf( p->msg, MSG_TTL_MENU_MAGIC_GUILD,
+	sn_printf( p->msg, MENU_MSG_MAX_LEN, MSG_TTL_MENU_MAGIC_GUILD,
 			get_shop_name( SHOP_N_MAGIC ),
 			g_sel_mbr->name,
 			fmt_gold( g_sel_mbr->gold ) );
@@ -2875,11 +3388,13 @@ char	*cb_menu_magic_guild_init( menu_t **pp, menu_t **dflt )
 		tab = get_spell_tab( kind );
 		if( tab == NULL ){
 			gold = 0;
-			sprintf( ls[i].msg, MSG_FMT_MENU_MAGIC_GUILD,
+			sn_printf( ls[i].msg, MENU_MSG_MAX_LEN,
+					MSG_FMT_MENU_MAGIC_GUILD,
 					"", 0, fmt_gold( 0 ) );
 		} else {
 			gold = get_price_spell( kind );
-			sprintf( ls[i].msg, MSG_FMT_MENU_MAGIC_GUILD,
+			sn_printf( ls[i].msg, MENU_MSG_MAX_LEN,
+					MSG_FMT_MENU_MAGIC_GUILD,
 					tab->name, tab->lev,
 					fmt_gold( gold ) );
 		}
@@ -2973,7 +3488,7 @@ char	*cb_menu_magic_guild( menu_t **pp, menu_t **dflt )
 	print_msg( FLG_NULL, MSG_MENU_BUY, tab->name );
 
 	/* 㤦ǧ */
-	ask = exec_menu_ask( MSG_TTL_MENU_BUY, ASK_NO, TRUE );
+	ask = exec_menu_ask_no_msg( MSG_TTL_MENU_BUY, ASK_NO, TRUE );
 	switch( ask ){
 	case ASK_YES:
 		break;
@@ -2984,6 +3499,7 @@ char	*cb_menu_magic_guild( menu_t **pp, menu_t **dflt )
 	}
 
 	add_chr_gold( g_sel_mbr, -get_price_spell( kind ) );
+	call_game_sound_play( SOUND_KIND_SHOP_PAY, 1 );
 	set_chr_learned_spell( g_sel_mbr, kind, TRUE );
 
 	return "/magic guild";
@@ -3008,7 +3524,7 @@ char	*cb_menu_pet_shop_init( menu_t **pp, menu_t **dflt )
 	p = srch_menu( *pp, "title" );
 	if( p == NULL )
 		return STR_MENU_ERR;
-	sprintf( p->msg, MSG_TTL_MENU_PET_SHOP,
+	sn_printf( p->msg, MENU_MSG_MAX_LEN, MSG_TTL_MENU_PET_SHOP,
 			get_shop_name( SHOP_N_PET_SHOP ),
 			g_sel_mbr->name,
 			fmt_gold( g_sel_mbr->gold ) );
@@ -3050,7 +3566,7 @@ char	*cb_menu_pet_shop_take( menu_t **pp, menu_t **dflt )
 	ls[k].accel_key = '\0';
 	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
-	sprintf( ls[k].msg, MSG_TTL_MENU_PET_SHOP_TAKE,
+	sn_printf( ls[k].msg, MENU_MSG_MAX_LEN, MSG_TTL_MENU_PET_SHOP_TAKE,
 			get_shop_name( SHOP_N_PET_SHOP ),
 			g_sel_mbr->name );
 	ls[k].call_back = NULL;
@@ -3066,7 +3582,8 @@ char	*cb_menu_pet_shop_take( menu_t **pp, menu_t **dflt )
 		if( !chk_can_join_pet( ls_pet[i] ) )
 			continue;
 
-		sprintf( ls[k].path, "/pet shop take/%ld", (long)(i + 1) );
+		sn_printf( ls[k].path, MENU_PATH_MAX_LEN,
+				"/pet shop take/%ld", (long)(i + 1) );
 		str_nz_cpy( ls[k].kind, "<Item>", MENU_KIND_MAX_LEN );
 		ls[k].accel_key = key;
 		ls[k].short_key[0] = '\0';
@@ -3163,7 +3680,7 @@ char	*cb_menu_pet_shop_leave( menu_t **pp, menu_t **dflt )
 	ls[k].accel_key = '\0';
 	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
-	sprintf( ls[k].msg, MSG_TTL_MENU_PET_SHOP_LEAVE,
+	sn_printf( ls[k].msg, MENU_MSG_MAX_LEN, MSG_TTL_MENU_PET_SHOP_LEAVE,
 			get_shop_name( SHOP_N_PET_SHOP ),
 			g_sel_mbr->name );
 	ls[k].call_back = NULL;
@@ -3179,7 +3696,8 @@ char	*cb_menu_pet_shop_leave( menu_t **pp, menu_t **dflt )
 		if( !chk_can_not_join_pet( party_pet[i] ) )
 			continue;
 
-		sprintf( ls[k].path, "/pet shop leave/%ld", (long)(i + 1) );
+		sn_printf( ls[k].path, MENU_PATH_MAX_LEN,
+				"/pet shop leave/%ld", (long)(i + 1) );
 		str_nz_cpy( ls[k].kind, "<Item>", MENU_KIND_MAX_LEN );
 		ls[k].accel_key = key;
 		ls[k].short_key[0] = '\0';
@@ -3276,7 +3794,7 @@ char	*cb_menu_pet_shop_name( menu_t **pp, menu_t **dflt )
 	ls[k].accel_key = '\0';
 	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
-	sprintf( ls[k].msg, MSG_TTL_MENU_PET_SHOP_NAME,
+	sn_printf( ls[k].msg, MENU_MSG_MAX_LEN, MSG_TTL_MENU_PET_SHOP_NAME,
 			get_shop_name( SHOP_N_PET_SHOP ),
 			g_sel_mbr->name );
 	ls[k].call_back = NULL;
@@ -3295,12 +3813,14 @@ char	*cb_menu_pet_shop_name( menu_t **pp, menu_t **dflt )
 		else
 			mnstr_name = ls_pet[i]->mnstr_tab->name;
 
-		sprintf( ls[k].path, "/pet shop name/%ld", (long)(i + 1) );
+		sn_printf( ls[k].path, MENU_PATH_MAX_LEN,
+				"/pet shop name/%ld", (long)(i + 1) );
 		str_nz_cpy( ls[k].kind, "<Item>", MENU_KIND_MAX_LEN );
 		ls[k].accel_key = key;
 		ls[k].short_key[0] = '\0';
 		ls[k].n_msg = N_MSG_NULL,
-		sprintf( ls[k].msg, MSG_MENU_PET_SHOP_NAME_LS,
+		sn_printf( ls[k].msg, MENU_MSG_MAX_LEN,
+				MSG_MENU_PET_SHOP_NAME_LS,
 				ls_pet[i]->name, mnstr_name );
 		ls[k].call_back = cb_menu_pet_shop_name_sel;
 		ls[k].arg = (void *)(ls_pet[i]);
@@ -3396,7 +3916,8 @@ char	*cb_menu_pet_shop_remove( menu_t **pp, menu_t **dflt )
 	ls[k].accel_key = '\0';
 	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
-	sprintf( ls[k].msg, MSG_TTL_MENU_PET_SHOP_REMOVE,
+	sn_printf( ls[k].msg, MENU_MSG_MAX_LEN,
+			MSG_TTL_MENU_PET_SHOP_REMOVE,
 			get_shop_name( SHOP_N_PET_SHOP ),
 			g_sel_mbr->name );
 	ls[k].call_back = NULL;
@@ -3410,7 +3931,8 @@ char	*cb_menu_pet_shop_remove( menu_t **pp, menu_t **dflt )
 		if( chk_flg( ls_pet[i]->stat, FLG_STAT_NOT_EXIST ) )
 			continue;
 
-		sprintf( ls[k].path, "/pet shop remove/%ld", (long)(i + 1) );
+		sn_printf( ls[k].path, MENU_PATH_MAX_LEN,
+				"/pet shop remove/%ld", (long)(i + 1) );
 		str_nz_cpy( ls[k].kind, "<Item>", MENU_KIND_MAX_LEN );
 		ls[k].accel_key = key;
 		ls[k].short_key[0] = '\0';
@@ -3471,7 +3993,7 @@ char	*cb_menu_pet_shop_remove_sel( menu_t **pp, menu_t **dflt )
 	print_msg( FLG_NULL, MSG_MENU_PET_SHOP_ASK_REMOVE, pet->name );
 	curs_attrset_dflt();
 
-	ask = exec_menu_ask( MSG_TTL_MENU_PET_SHOP_ASK_REMOVE,
+	ask = exec_menu_ask_no_msg( MSG_TTL_MENU_PET_SHOP_ASK_REMOVE,
 			ASK_NO, TRUE );
 	switch( ask ){
 	case ASK_YES:
@@ -3524,7 +4046,7 @@ char	*cb_menu_pet_shop_buy( menu_t **pp, menu_t **dflt )
 	ls[k].accel_key = '\0';
 	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
-	sprintf( ls[k].msg, MSG_TTL_MENU_PET_SHOP,
+	sn_printf( ls[k].msg, MENU_MSG_MAX_LEN, MSG_TTL_MENU_PET_SHOP,
 			get_shop_name( SHOP_N_PET_SHOP ),
 			g_sel_mbr->name,
 			fmt_gold( g_sel_mbr->gold ) );
@@ -3555,12 +4077,14 @@ char	*cb_menu_pet_shop_buy( menu_t **pp, menu_t **dflt )
 			key = 'A';
 		}
 
-		sprintf( ls[k].path, "/pet shop buy/%ld", (long)(i + 1) );
+		sn_printf( ls[k].path, MENU_PATH_MAX_LEN,
+				"/pet shop buy/%ld", (long)(i + 1) );
 		str_nz_cpy( ls[k].kind, "<Item>", MENU_KIND_MAX_LEN );
 		ls[k].accel_key = key;
 		ls[k].short_key[0] = '\0';
 		ls[k].n_msg = N_MSG_NULL,
-		sprintf( ls[k].msg, MSG_FMT_MENU_PET_SHOP,
+		sn_printf( ls[k].msg, MENU_MSG_MAX_LEN,
+				MSG_FMT_MENU_PET_SHOP,
 				get_mnstr_name( art_ls_pet_shop[i].kind ),
 				fmt_gold( art_ls_pet_shop[i].price ) );
 		ls[k].call_back = cb_menu_pet_shop_buy_sel;
@@ -3607,7 +4131,7 @@ char	*cb_menu_pet_shop_buy_sel( menu_t **pp, menu_t **dflt )
 	print_msg( FLG_NULL, MSG_MENU_PET_SHOP_ASK_BUY,
 			get_mnstr_name( kind ) );
 
-	ask = exec_menu_ask( MSG_TTL_MENU_PET_SHOP_ASK_BUY,
+	ask = exec_menu_ask_no_msg( MSG_TTL_MENU_PET_SHOP_ASK_BUY,
 			ASK_NO, TRUE );
 	switch( ask ){
 	case ASK_YES:
@@ -3631,6 +4155,7 @@ char	*cb_menu_pet_shop_buy_sel( menu_t **pp, menu_t **dflt )
 	print_msg( FLG_NULL, MSG_MENU_PET_SHOP_BUY_SUCCESS, pet->name );
 
 	add_chr_gold( g_sel_mbr, (gold_t)(-price) );
+	call_game_sound_play( SOUND_KIND_SHOP_PAY, 1 );
 
 	return "/pet shop";
 }
@@ -3696,7 +4221,8 @@ char	*cb_menu_navi_init( menu_t **pp, menu_t **dflt )
 		n = (shop_n_t)i;
 		mnr = get_shop_mnr_face( n );
 
-		sprintf( ls[k].path, "/navi/%c", (char)mnr );
+		sn_printf( ls[k].path, MENU_PATH_MAX_LEN,
+				"/navi/%c", (char)mnr );
 		str_nz_cpy( ls[k].kind, "<Item>", MENU_KIND_MAX_LEN );
 		ls[k].accel_key = toupper( mnr );
 		ls[k].short_key[0] = '\0';
@@ -3802,7 +4328,8 @@ bool_t	set_menu_auto_sale( menu_t *ls, mbr_t *mbr )
 	ls[k].accel_key = '\0';
 	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
-	sprintf( ls[k].msg, MSG_TTL_MENU_AUTO_SALE, mbr->name );
+	sn_printf( ls[k].msg, MENU_MSG_MAX_LEN,
+			MSG_TTL_MENU_AUTO_SALE, mbr->name );
 	ls[k].call_back = NULL;
 	ls[k].arg = NULL;
 	ls[k].flg = FLG_NULL;
@@ -3838,12 +4365,14 @@ bool_t	set_menu_auto_sale( menu_t *ls, mbr_t *mbr )
 				item, DEAL_KIND_SALE_ITEM );
 		price = get_price( shop_n, item, DEAL_KIND_SALE_ITEM );
 
-		sprintf( ls[k].path, "/auto sale/%ld", i );
+		sn_printf( ls[k].path, MENU_PATH_MAX_LEN,
+				"/auto sale/%ld", i );
 		str_nz_cpy( ls[k].kind, "<CheckItem>", MENU_KIND_MAX_LEN );
 		ls[k].accel_key = toupper( (char)('A' + i) );
 		ls[k].short_key[0] = '\0';
 		ls[k].n_msg = N_MSG_NULL,
-		sprintf( ls[k].msg,
+		sn_printf( ls[k].msg,
+				MENU_MSG_MAX_LEN,
 				MSG_FMT_ART_NAME,
 				max_len,
 				item->art_name,
@@ -3876,7 +4405,7 @@ bool_t	set_menu_auto_sale( menu_t *ls, mbr_t *mbr )
 
 char	*cb_menu_auto_sale_chk( menu_t **pp, menu_t **dflt )
 {
-	set_key_buf_str( "2" );
+	set_key_buf_str_head( "2" );
 
 	return STR_MENU_CANCEL;
 }
@@ -3890,6 +4419,7 @@ char	*cb_menu_auto_sale_exec( menu_t **pp, menu_t **dflt )
 	item_t	*item;
 	shop_n_t	shop_n;
 	gold_t	price;
+	long	sale_n, sale_sum;
 	long	i;
 
 	ask = exec_menu_ask( MSG_TTL_MENU_AUTO_SALE_ASK, ASK_NO, TRUE );
@@ -3904,6 +4434,8 @@ char	*cb_menu_auto_sale_exec( menu_t **pp, menu_t **dflt )
 
 	ls = ls_menu_auto_sale;
 
+	sale_sum = 0;
+
 	for( i = 0; i < LOOP_MAX_1000; i++ ){
 		if( ls[i].path[0] == '\0' )
 			break;
@@ -3916,13 +4448,23 @@ char	*cb_menu_auto_sale_exec( menu_t **pp, menu_t **dflt )
 		shop_n = get_shop_deal_article( item, DEAL_KIND_SALE_ITEM );
 		price = get_price( shop_n, item, DEAL_KIND_SALE_ITEM );
 
-		menu_shop_sale( shop_n, g_sel_mbr, item,
+		sale_n = menu_shop_sale( shop_n, g_sel_mbr, item,
 				DEAL_KIND_SALE_ITEM, TRUE );
 
-		if( price > 0 )
-			add_chr_gold( g_sel_mbr, +price );
+		if( sale_n <= 0 )
+			continue;
+		if( price <= 0 )
+			continue;
+
+		add_chr_gold( g_sel_mbr, +price );
+		sale_sum += sale_n;
 	}
 
+	if( sale_sum <= 0 )
+		return NULL;
+
+	call_game_sound_play( SOUND_KIND_SHOP_PAY, 1 );
+
 	add_turn( NAVI_ADD_TURN_N + SHOP_ADD_TURN_N );
 
 	return NULL;
@@ -3930,3 +4472,17 @@ char	*cb_menu_auto_sale_exec( menu_t **pp, menu_t **dflt )
 
 /**/
 
+shop_n_t	get_cur_shop_n( void )
+{
+	return g_shop_n;
+}
+
+/**/
+
+void	set_cur_shop_n( shop_n_t n )
+{
+	g_shop_n = n;
+}
+
+/**/
+
