@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: trap.c,v 1.70 2008/04/16 16:12:34 bowkenken Exp $
+* $Id: trap.c,v 1.75 2009/01/31 01:40:40 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -232,9 +232,12 @@ trap_t	*make_trap( long x, long y, long dun_lev )
 
 	flg_boss = chk_boss_dun_lev( dun->lev );
 
-	if( clip_pos( x, y ) )
+	if( clip_pos( x, y ) ){
 		if( dun->map.obj.mjr[y][x] != FACE_MJR_FLOOR )
 			return NULL;
+		if( dun->map.obj.mnr[y][x] != FACE_MNR_FLOOR )
+			return NULL;
+	}
 
 	n = 0;
 	for( i = LOOP_MAX_100; i > 0; i-- ){
@@ -388,13 +391,15 @@ bool_t	set_trap( long x, long y, trap_t *trap )
 		return FALSE;
 	if( dun->map.obj.mjr[y][x] != FACE_MJR_FLOOR )
 		return FALSE;
+	if( dun->map.obj.mnr[y][x] != FACE_MNR_FLOOR )
+		return FALSE;
 
 	trap->x = x;
 	trap->y = y;
 
 	dun->map.obj.mjr[y][x] = FACE_MJR_TRAP;
 	dun->map.obj.mnr[y][x] = FACE_MNR_NULL;
-	dun->map.obj.flg[y][x] |= FLG_MAP_OBJ_PASS;
+	dun->map.obj.flg[y][x] |= FLG_MAP_OBJ_PASS | FLG_MAP_OBJ_LOOK;
 	dun->map.obj.flg[y][x] |= FLG_MAP_OBJ_LOOK_FLOOR;
 
 	set_trap_face_mnr( trap );
@@ -489,6 +494,8 @@ void	make_trap_room( long area_x, long area_y, long dun_lev )
 
 		if( dun->map.obj.mjr[my][mx] != FACE_MJR_FLOOR )
 			continue;
+		if( dun->map.obj.mnr[my][mx] != FACE_MNR_FLOOR )
+			continue;
 
 		trap = make_trap( mx, my, dun_lev );
 		if( trap != NULL )
@@ -517,6 +524,8 @@ void	make_trap_room( long area_x, long area_y, long dun_lev )
 
 void	chk_trap_chest( item_t *chest, chr_t *chr, rate_t rate )
 {
+	bool_t	flg_free;
+
 	if( chr == NULL )
 		return;
 	if( chk_flg_or( chr->stat, FLG_STAT_NOT_EXIST | FLG_STAT_DEAD ) )
@@ -529,9 +538,15 @@ void	chk_trap_chest( item_t *chest, chr_t *chr, rate_t rate )
 	if( !rate_randm( rate ) )
 		return;
 
+	flg_free = TRUE;
+	if( chest->dat.chest.trap != NULL )
+		if( chest->dat.chest.trap->kind == TRAP_KIND_CHUTE )
+			flg_free = FALSE;
+
 	caught_trap( chest->dat.chest.trap, chr );
 
-	free_trap_chest( chest );
+	if( flg_free )
+		free_trap_chest( chest );
 }
 
 /***************************************************************
